@@ -55,7 +55,6 @@ OC.L10N.register(
     "On events happening in a <strong>team</strong> of which you are a member" : "Vid händelser i ett <strong>team</strong> där du är medlem",
     "Any important event in a <strong>team</strong> you are moderating" : "Alla viktiga händelser i ett <strong>team</strong> du modererar",
     "On global events happening in any <strong>team</strong>" : "Vid globala händelser som händer i något <strong>team</strong>",
-    "Shared to Circles" : "Delad med Cirklar",
     "Single" : "Singel",
     "Personal" : "Personlig",
     "System" : "System",
@@ -83,17 +82,17 @@ OC.L10N.register(
     "Moderator" : "Moderator",
     "Admin" : "Administratör",
     "Owner" : "Ägare",
-    "%s shared »%s« with you." : "%s delade »%s« med dig.",
-    "%s shared »%s« with \"%s\"." : "%s delade »%s« med \"%s\".",
+    "%s shared »%s« with you." : "%s delade \"%s\" med dig.",
+    "%s shared »%s« with \"%s\"." : "%s delade \"%s\" med \"%s\".",
     "%s on %s" : "%s på %s",
-    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delade »%2$s« med dig.\nDu borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.\n",
-    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s delade »%2$s« med dig. Du borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.",
-    "Password to access »%1$s« shared to you by %2$s" : "Lösenord för access till »%1$s« delad med dig av %2$s",
-    "Password to access »%s«" : "Lösenord för att nå »%s«",
+    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delade \"%2$s\" med dig.\nDu bör redan ha fått ett separat e-postmeddelande med en länk för åtkomst.\n",
+    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s delade \"%2$s\" med dig. Du bör redan ha fått ett separat e-postmeddelande med en länk för åtkomst.",
+    "Password to access »%1$s« shared to you by %2$s" : "Lösenord för åtkomst till \"%1$s\" delad med dig av %2$s",
+    "Password to access »%s«" : "Lösenord för åtkomst till \"%s\"",
     "It is protected with the following password:" : "Den är skyddad med följande lösenord:",
     "%1$s via %2$s" : "%1$s via %2$s",
     "Click the button below to open it." : "Klicka på knappen nedan för att öppna det.",
-    "Open »%s«" : "Öppna »%s«",
+    "Open »%s«" : "Öppna \"%s\"",
     "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s delade flera filer med dig.\nDu borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.\n",
     "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s delade flera filer med dig. Du borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.",
     "Password to access files shared to you by %1$s" : "Lösenord för åtkomst till filer delade med dig av %1$s",
@@ -123,12 +122,12 @@ OC.L10N.register(
     "The account is already a member of this circle" : "Kontot är redan medlem av denna cirkel",
     "The account has already been invited into this circle" : "Kontot har redan bjudits in till denna cirkel",
     "%s (Team owned by %s)" : "%s (Team ägs av %s)",
-    "You are now a member of the Circle \"%2$s\"" : "Du är nu medlem i cirkel \"%2$s\"",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "Du har blivit inbjuden av %1$s till cirkel \"%2$s\"",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s skickade en förfrågan att bli medlem i cirkel \"%2$s\"",
+    "You are now a member of the Team \"%2$s\"" : "Du är nu medlem i Team \"%2$s\"",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "Du har blivit inbjuden av %1$s till Team \"%2$s\"",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s skickade en förfrågan att bli medlem i Team \"%2$s\"",
     "Accept" : "Acceptera",
     "Refuse" : "Neka",
-    "Leave the circle" : "Lämna cirkeln",
+    "Leave the team" : "Lämna team",
     "%s" : "%s",
     "Personal team" : "Personligt team",
     "%s owned by %s" : "%s ägd av %s",
@@ -147,54 +146,16 @@ OC.L10N.register(
     "Name" : "Namn",
     "Size" : "Storlek",
     "Modified" : "Ändrad",
-    "Circles" : "Cirklar",
-    "Circles' files" : "Cirklars filer",
-    "Select circles to filter by" : "Välj cirklar att filtrera efter",
-    "No circles found" : "Inga cirklar hittade",
-    "Please select circles to filter by" : "Vänligen välj cirklar att filtrera",
-    "No files found for the selected circles" : "Inga filer hittade för de valda cirklarna",
-    "You created the circle {circle}" : "Du skapade cirkeln {circle}",
-    "{author} created the circle {circle}" : "{author} skapade cirkeln {circle}",
-    "You added circle {member} as member to {circle}" : "Du lade till cirkel {member} som medlem till {circle}",
-    "{author} added circle {member} has been added as member to {circle}" : "{author} lade till cirkel {member} har lagts till som medlem i {circle}",
-    "You removed {member} leave {circle}" : "Du tog bort {member} lämna {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "Vid händelser i en <strong>Cirkel</strong> där du är medlem",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Någon viktig händelse i en <strong>Cirkel</strong> du modererar",
-    "On global events happening in any <strong>Circle</strong>" : "Vid globala händelser som händer i någon <strong>Cirkel</strong>",
-    "Join Request" : "Anslutningsbegäran",
-    "Password Protected" : "Lösenordsskyddad",
-    "Circle Invite" : "Cirkel-inbjudan",
-    "Email Address" : "E-postadress",
-    "Circle not found" : "Cirkel kunde inte hittas",
-    "Circle not found " : "Cirkel kunde inte hittas",
-    "This account is already a member of the circle" : "Detta konto är redan medlem av denna cirkel",
-    "Federated link not found" : "Federerad länk hittades inte",
-    "The circle is not federated" : "Cirkeln är inte federerad",
-    "You cannot join this circle" : "Du kan inte gå med i denna cirkel",
-    "This member is the owner of the circle" : "Medlemmen är ägare av cirkeln",
-    "%s (Circle owned by %s)" : "1%s (Cirkel ägs av 1%s)",
-    "Personal Circle" : "Personlig cirkel",
-    "You need a specify a type of circle" : "Du behöver specificera en cirkeltyp",
-    "A circle with that name exists" : "En cirkel med det namnet finns",
-    "This member is not the owner of the circle" : "Medlemmen är inte ägaren av cirkeln",
-    "This member is not an admin of the circle" : "Denna medlem är inte administratör för cirkeln",
-    "Group contains too many members" : "Gruppen innehåller för många medlemmar",
-    "This group does not exist" : "Denna grupp finns inte",
-    "This group is already linked to the circle" : "Gruppen är redan länkad till cirkeln",
-    "You cannot edit level in a personal circle" : "Du kan inte ändra nivå i en personlig cirkel",
-    "Group cannot be set as owner of a circle" : "Grupp kan inte sättas som ägare av en cirkel",
-    "now" : "nu",
-    "This account does not exist" : "Kontot existerar inte",
-    "Email format is not valid" : "E-postformat är inte giltigt",
-    "This contact is not available" : "Denna kontakt är inte tillgänglig",
-    "You have no permission to create a new circle" : "Du har inte behörighet att skapa en ny cirkel",
-    "This item is already shared with this circle" : "Detta objektet delas redan med denna cirkeln.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Cirklar låter användare att skapa deras egna grupper av användare/kollegor/vänner.\nDessa grupper av användare (eller \"cirklar\") kan användas av alla andra appar vid delning.",
     "Teams' files" : "Teams filer",
     "Select team to filter by" : "Välj team att filtrera efter",
     "No teams found" : "Inga team hittades",
     "Please select teams to filter by" : "Välj team att filtrera efter",
     "No files found for the selected teams" : "Inga filer hittade för valda team",
-    "{author} added team {member} has been added as member to {circle}" : "{author} lade till team {member} som medlem i {circle}"
+    "{author} added team {member} has been added as member to {circle}" : "{author} lade till team {member} som medlem i {circle}",
+    "Shared to Circles" : "Delad med Cirklar",
+    "You are now a member of the Circle \"%2$s\"" : "Du är nu medlem i cirkel \"%2$s\"",
+    "You have been invited by %1$s into the Circle \"%2$s\"" : "Du har blivit inbjuden av %1$s till cirkel \"%2$s\"",
+    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s skickade en förfrågan att bli medlem i cirkel \"%2$s\"",
+    "Leave the circle" : "Lämna cirkeln"
 },
 "nplurals=2; plural=(n != 1);");
