@@ -189,12 +189,12 @@ OC.L10N.register(
     "Second" : "Sekund",
     "Third" : "Třetí",
     "Fourth" : "Čtvrtý",
-    "Fifty" : "Pátý",
+    "Fifth" : "Páté",
     "Last" : "Poslední",
     "Second Last" : "Druhý poslední",
     "Third Last" : "Třetí poslední",
     "Fourth Last" : "Čtvrtý poslední",
-    "Fifty Last" : "Pátý poslední",
+    "Fifth Last" : "Pátý poslední",
     "Contacts" : "Kontakty",
     "{actor} created address book {addressbook}" : "{actor} vytvořil(a) adresář kontaktů {addressbook}",
     "You created address book {addressbook}" : "Vytvořili jste adresář kontaktů {addressbook}",
@@ -250,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "Dokončeno %s",
     "Due on %s by %s" : "Termín do %s od %s",
     "Due on %s" : "Termín do %s",
+    "System Address Book" : "Systémový adresář kontaktů",
+    "The system address book contains contact information for all users in your instance." : "Systémový adresář kontaktů obsahuje informace pro všechny uživatele ve vámi využívané instanci.",
+    "Enable System Address Book" : "Zapnout systémový adresář kontaktů",
     "DAV system address book" : "Systémový DAV adresář kontaktů",
     "No outstanding DAV system address book sync." : "Žádná zbývající synchronizace systémového DAV adresáře kontaktů.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV synchronizace systémového adresáře kontaktů ještě nebyla spuštěná protože vámi využívaná instance má více než 1 000 uživatelů nebo protože došlo k chybě. Spusťte ji ručně  příkazem „occ dav:sync-system-addressbook“.",
@@ -261,6 +264,10 @@ OC.L10N.register(
     "Calendars including events, details and attendees" : "Kalendáře včetně událostí, podrobností a účastníků",
     "Contacts and groups" : "Kontakty a skupiny",
     "WebDAV" : "WebDAV",
+    "Absence saved" : "Nepřítomnost uložena",
+    "Failed to save your absence settings" : "Nepodařilo se uložit nastavení vaší nepřítomnosti",
+    "Absence cleared" : "Nepřítomnost vyčištěna",
+    "Failed to clear your absence settings" : "Nepodařilo se vymazat nastavení vaší nepřítomnosti",
     "First day" : "První den",
     "Last day (inclusive)" : "Poslední den (včetně)",
     "Out of office replacement (optional)" : "Zástup když mimo kancelář (volitelné)",
@@ -271,10 +278,9 @@ OC.L10N.register(
     "Long absence Message" : "Zpráva pro dlouhou nepřítomnost",
     "Save" : "Uložit",
     "Disable absence" : "Vypnout nepřítomnost",
-    "Absence saved" : "Nepřítomnost uložena",
-    "Failed to save your absence settings" : "Nepodařilo se uložit nastavení vaší nepřítomnosti",
-    "Absence cleared" : "Nepřítomnost vyčištěna",
-    "Failed to clear your absence settings" : "Nepodařilo se vymazat nastavení vaší nepřítomnosti",
+    "Failed to load availability" : "Nepodařilo se načíst dostupnost",
+    "Saved availability" : "Uložena dostupnost",
+    "Failed to save availability" : "Nepodařilo se uložit dostupnost",
     "Time zone:" : "Časové pásmo:",
     "to" : "do",
     "Delete slot" : "Smazat slot",
@@ -283,14 +289,13 @@ OC.L10N.register(
     "Weekdays" : "Dny v týdnu",
     "Pick a start time for {dayName}" : "Vyberte začátek pro {dayName}",
     "Pick a end time for {dayName}" : "Vyberte konec pro {dayName}",
-    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "V době, kdy není k dispozici, automaticky nastavit stav uživatele jako „Nerušit“ a ztlumit tak veškerá upozornění pro něho.",
-    "Failed to load availability" : "Nepodařilo se načíst dostupnost",
-    "Saved availability" : "Uložena dostupnost",
-    "Failed to save availability" : "Nepodařilo se uložit dostupnost",
+    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "V době, kdy není k dispozici, automaticky nastavit stav uživatele na „Nerušit“ a ztlumit tak veškerá upozornění.",
     "Availability" : "Dostupnost",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Když sem zadáte svou pracovní dobu, ostatní lidé při rezervování schůzky uvidí, kdy jste mimo kancelář.",
     "Absence" : "Nepřítomnost",
     "Configure your next absence period." : "Nastavte období své nepřítomnosti.",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Také nainstalujte {calendarappstoreopen}aplikaci Kalendář{linkclose}, nebo {calendardocopen}připojte svůj počítač a telefon pro synchronizaci ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Ověřte, že jste správně nastavili {emailopen}e-mailový server{linkclose}.",
     "Calendar server" : "Kalendářový server",
     "Send invitations to attendees" : "Poslat účastníkům pozvánky",
     "Automatically generate a birthday calendar" : "Automaticky vytvořit kalendář s narozeninami",
@@ -301,28 +306,27 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Poslat připomínky také těm, kteří mají tento sdílený kalendář připojený",
     "Reminders are always sent to organizers and attendees." : "Připomínky jsou vždy poslány organizátorům a účastníkům.",
     "Enable notifications for events via push" : "Upozorňovat na události prostřednictvím služby push",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Také nainstalujte {calendarappstoreopen}aplikaci Kalendář{linkclose}, nebo {calendardocopen}připojte svůj počítač a telefon pro synchronizaci ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Ověřte, že jste správně nastavili {emailopen}e-mailový server{linkclose}.",
+    "Cancel" : "Storno",
+    "Import" : "Naimportovat",
+    "Error while saving settings" : "Chyba při ukládání nastavení",
+    "Contact reset successfully" : "Kontakt úspěšně resetován",
+    "Error while resetting contact" : "Chyba při resetování kontaktu",
+    "Contact imported successfully" : "Kontakt úspěšně naimportován",
+    "Error while importing contact" : "Chyba při importování kontaktu",
+    "Example Content" : "Obsah pro ukázku",
+    "Set example content to be created on new user first login." : "Nastavit obsah pro ukázku, který vytvořit při prvním přihlášení nového uživatele.",
+    "Import contact" : "Importovat kontakt",
+    "Reset to default contact" : "Vrátit na výchozí kontakt",
+    "Import contacts" : "Importovat kontakty",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Naimportování nového .vcf souboru smaže stávající výchozí kontakt a nahradí ho novým. Chcete pokračovat?",
     "There was an error updating your attendance status." : "Vyskytla se chyba při aktualizaci vašeho stavu účasti.",
     "Please contact the organizer directly." : "Kontaktujte organizátora přímo.",
     "Are you accepting the invitation?" : "Přijímáte pozvání?",
     "Tentative" : "Nezávazně",
     "Your attendance was updated successfully." : "Vaše účast byla úspěšně aktualizována.",
-    "To-dos" : "Zbývá udělat",
     "Time:" : "Čas:",
     "Could not open file" : "Nedaří se otevřít soubor",
     "Invalid chunk name" : "Neplatný název pro shluk (chunk)",
-    "Could not rename part file assembled from chunks" : "Nedaří se přejmenovat částečný soubor složený ze shluků",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Když sem zadáte svou pracovní dobu, ostatní uživatelé při rezervování schůzky uvidí, kdy jste mimo kancelář.",
-    "In a %1$s on %2$s for the entire day" : "Na %1$s v %2$s po celý den",
-    "In a %1$s on %2$s between %3$s - %4$s" : "Na %1$s v %2$s mezi %3$s - %4$s",
-    "In %1$s %2$s on %3$s for the entire day" : "Na %1$s %2$s v %3$s po celý den",
-    "In %1$s %2$s on %3$s between %4$s - %5$s" : "V %1$s %2$s na %3$s mezi %4$s - %5$s",
-    "In a %1$s on %2$s" : "V %1$s v %2$s",
-    "In a %1$s on %2$s then on %3$s" : "V %1$s v %2$s, pak v %3$s",
-    "In a %1$s on %2$s then on %3$s and %4$s" : "V %1$s v %2$s, pak v %3$s a %4$s",
-    "In %1$s %2$s on %3$s" : "V %1$s %2$s v %3$s",
-    "In %1$s %2$s on %3$s then on %4$s" : "V %1$s %2$s v %3$s, pak v %4$s",
-    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "V %1$s %2$s v %3$s, pak v %4$s a %5$s"
+    "Could not rename part file assembled from chunks" : "Nedaří se přejmenovat částečný soubor složený ze shluků"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
