@@ -72,6 +72,15 @@ OC.L10N.register(
     "Description: %s" : "Descrizione: %s",
     "Where: %s" : "Dove: %s",
     "%1$s via %2$s" : "%1$s tramite %2$s",
+    "Every Day for the entire day" : "Ogni giorno per l'intero giorno",
+    "Every Day for the entire day until %1$s" : "Ogni Giorno per l'intero giorno fino a %1$s",
+    "Every Day between %1$s - %2$s" : "Ogni giorno tra %1$s-%2$s",
+    "Every Day between %1$s - %2$s until %3$s" : "Ogni giorno tra %1$s -%2$s fino al %3$s",
+    "Every %1$d Days for the entire day" : "Ogni %1$d Giorni per tutto il giorno",
+    "Every %1$d Days for the entire day until %2$s" : "Ogni %1$d Giorni per l'intero giorno fino al %2$s",
+    "Every %1$d Days between %2$s - %3$s" : "Ogni %1$d Giorni tra %2$s-%3$s",
+    "Every Week on %1$s for the entire day" : "Ogni settimana di %1$s per l'intero giorno",
+    "Every Week on %1$s for the entire day until %2$s" : "Ogni settimana di %1$s per l'intero giorno fino al %2$s",
     "Cancelled: %1$s" : "Annullato: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" è stato annullato",
     "Re: %1$s" : "Re: %1$s",
@@ -86,13 +95,34 @@ OC.L10N.register(
     "Organizer:" : "Organizzatore:",
     "Attendees:" : "Partecipanti:",
     "Title:" : "Titolo:",
-    "Time:" : "Ora:",
+    "When:" : "Quando:",
     "Location:" : "Posizione:",
     "Link:" : "Collegamento:",
     "Accept" : "Accetta",
     "Decline" : "Rifiuta",
     "More options …" : "Altre opzioni...",
     "More options at %s" : "Altre opzioni alle %s",
+    "Monday" : "Lunedì",
+    "Tuesday" : "Martedì",
+    "Wednesday" : "Mercoledì",
+    "Thursday" : "Giovedì",
+    "Friday" : "Venerdì",
+    "Saturday" : "Sabato",
+    "Sunday" : "Domenica",
+    "January" : "Gennaio",
+    "February" : "Febbraio",
+    "March" : "Marzo",
+    "April" : "Aprile",
+    "May" : "Maggio",
+    "June" : "Giugno",
+    "July" : "Luglio",
+    "August" : "Agosto",
+    "September" : "Settembre",
+    "October" : "Ottobre",
+    "November" : "Novembre",
+    "December" : "Dicembre",
+    "First" : "Primo",
+    "Last" : "Ultimo",
     "Contacts" : "Contatti",
     "{actor} created address book {addressbook}" : "{actor} ha creato la rubrica {addressbook}",
     "You created address book {addressbook}" : "Hai creato la rubrica {addressbook}",
@@ -101,10 +131,10 @@ OC.L10N.register(
     "{actor} updated address book {addressbook}" : "{actor} ha aggiornato la rubrica {addressbook}",
     "You updated address book {addressbook}" : "Hai aggiornato la rubrica {addressbook}",
     "{actor} shared address book {addressbook} with you" : "{actor} ha condiviso la rubrica {addressbook} con te",
-    "You shared address book {addressbook} with {user}" : "Hai condiviso la rubrica {addressbook} con {actor}",
+    "You shared address book {addressbook} with {user}" : "Hai condiviso la rubrica {addressbook} con {user}",
     "{actor} shared address book {addressbook} with {user}" : "{actor} ha condiviso la rubrica {addressbook} con {user}",
     "{actor} unshared address book {addressbook} from you" : "{actor} ha eliminato la condivisione della rubrica {addressbook} con te",
-    "You unshared address book {addressbook} from {user}" : "Hai eliminato la condivisione della rubrica {addressbook} con {actor}",
+    "You unshared address book {addressbook} from {user}" : "Hai eliminato la condivisione della rubrica {addressbook} con {user}",
     "{actor} unshared address book {addressbook} from {user}" : "{actor} ha eliminato la condivisone della rubrica {addressbook} da {user}",
     "{actor} unshared address book {addressbook} from themselves" : "{actor} ha eliminato la condivisone della rubrica {addressbook} da se stesso",
     "You shared address book {addressbook} with group {group}" : "Hai condiviso la rubrica {addressbook} con il gruppo {group}",
@@ -129,12 +159,9 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "Impossibile rinominare il file di parte in file finale, annullato da hook",
     "Could not rename part file to final file" : "Impossibile rinominare il file di parte in file finale",
     "Failed to check file size: %1$s" : "Verifica della dimensione del file non riuscito: %1$s",
-    "Could not open file" : "Impossibile aprire il file",
     "Encryption not ready: %1$s" : "Cifratura non pronta: %1$s",
     "Failed to open file: %1$s" : "Apertura del file non riuscito: %1$s",
     "Failed to unlink: %1$s" : "Scollegamento non riuscito: %1$s",
-    "Invalid chunk name" : "Nome non valido per lo spezzone",
-    "Could not rename part file assembled from chunks" : "Non è possibile rinominare il file assemblato da più spezzoni",
     "Failed to write file contents: %1$s" : "Scrittura del contenuto del file non riuscita: %1$s",
     "File not found: %1$s" : "File non trovato: %1$s",
     "System is in maintenance mode." : "Il sistema è in modalità di manutenzione.",
@@ -151,43 +178,41 @@ OC.L10N.register(
     "No outstanding DAV system address book sync." : "Nessuna sincronizzazione della rubrica del sistema DAV in sospeso.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "La sincronizzazione della rubrica del sistema DAV non è ancora stata eseguita poiché la tua istanza ha più di 1000 utenti o perché si è verificato un errore. Eseguila a mano chiamando \"occ dav:sync-system-addressbook\".",
     "WebDAV endpoint" : "Terminatore WebDAV",
+    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Impossibile verificare se il server è configurato correttamente per consentire la sincronizzazione di file via WebDAV. Controllalo a mano.",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Il tuo server web non è configurato correttamente per consentire la sincronizzazione dei file, poiché l'interfaccia WebDAV sembra essere danneggiata.",
+    "Your web server is properly set up to allow file synchronization over WebDAV." : "Il tuo server è configurato correttamente per consentire la sincronizzazione di file via WebDAV.",
     "Migrated calendar (%1$s)" : "Calendario migrato (%1$s)",
     "Calendars including events, details and attendees" : "Calendari inclusi eventi, dettagli e partecipanti",
     "Contacts and groups" : "Contatti e gruppi",
     "WebDAV" : "WebDAV",
+    "Absence saved" : "Assenza salvata",
+    "Failed to save your absence settings" : "Impossibile salvare le impostazioni di assenza",
+    "Absence cleared" : "Assenza cancellata",
+    "Failed to clear your absence settings" : "Impossibile cancellare le impostazioni di assenza",
     "First day" : "Primo giorno",
     "Last day (inclusive)" : "Ultimo giorno (inclusivo)",
     "Short absence status" : "Stato di assenza breve",
     "Long absence Message" : "Messaggio di assenza lunga",
     "Save" : "Salva",
     "Disable absence" : "Disattiva assenza",
-    "Absence saved" : "Assenza salvata",
-    "Failed to save your absence settings" : "Impossibile salvare le impostazioni di assenza",
-    "Absence cleared" : "Assenza cancellata",
-    "Failed to clear your absence settings" : "Impossibile cancellare le impostazioni di assenza",
+    "Failed to load availability" : "Caricamento disponibilità non riuscito",
+    "Saved availability" : "Disponibilità salvata",
+    "Failed to save availability" : "Salvataggio disponibilità non riuscito",
     "Time zone:" : "Fuso orario:",
     "to" : "a",
     "Delete slot" : "Elimina slot",
     "No working hours set" : "Orari lavorativi non impostati",
     "Add slot" : "Aggiungi slot",
     "Weekdays" : "Giorni feriali",
-    "Monday" : "Lunedì",
-    "Tuesday" : "Martedì",
-    "Wednesday" : "Mercoledì",
-    "Thursday" : "Giovedì",
-    "Friday" : "Venerdì",
-    "Saturday" : "Sabato",
-    "Sunday" : "Domenica",
     "Pick a start time for {dayName}" : "Scegli un orario di inizio per {dayName}",
     "Pick a end time for {dayName}" : "Scegli un orario di fine per {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Imposta automaticamente lo stato dell'utente su \"Non disturbare\" al di fuori della disponibilità per disattivare tutte le notifiche.",
-    "Failed to load availability" : "Caricamento disponibilità non riuscito",
-    "Saved availability" : "Disponibilità salvata",
-    "Failed to save availability" : "Salvataggio disponibilità non riuscito",
     "Availability" : "Disponibilità",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Se imposti il tuo orario di lavoro, le altre persone potranno vedere quando non sei in ufficio per organizzare una riunione.",
     "Absence" : "Assenza",
     "Configure your next absence period." : "Configura il tuo prossimo periodo di assenza.",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installa anche {calendarappstoreopen}l'applicazione Calendario{linkclose}, o {calendardocopen}connetti il tuo desktop e mobile per la sincronizzazione ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Assicurati di configurare correttamente {emailopen}il server di posta{linkclose}.",
     "Calendar server" : "Server di calendari",
     "Send invitations to attendees" : "Invia gli inviti ai partecipanti",
     "Automatically generate a birthday calendar" : "Genera automaticamente un calendario dei compleanni",
@@ -198,14 +223,17 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Invia notifiche di promemoria anche ai partecipanti al calendario",
     "Reminders are always sent to organizers and attendees." : "I promemoria vengono sempre inviati agli organizzatori e ai partecipanti.",
     "Enable notifications for events via push" : "Abilita notifiche per eventi tramite push",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installa anche {calendarappstoreopen}l'applicazione Calendario{linkclose}, o {calendardocopen}connetti il tuo desktop e mobile per la sincronizzazione ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Assicurati di configurare correttamente {emailopen}il server di posta{linkclose}.",
+    "Cancel" : "Annulla",
+    "Import" : "Importa",
+    "Error while saving settings" : "Errore durante il salvataggio delle impostazioni",
     "There was an error updating your attendance status." : "Si è verificato un errore durante l'aggiornamento dello stato della tua partecipazione.",
     "Please contact the organizer directly." : "Contatta direttamente l'amministratore.",
     "Are you accepting the invitation?" : "Accetti l'invito?",
     "Tentative" : "Provvisorio",
     "Your attendance was updated successfully." : "La tua partecipazione è stata aggiornata correttamente.",
-    "To-dos" : "Da fare",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Se imposti il tuo orario di lavoro, gli altri utenti potranno vedere quando non sei in ufficio per organizzare una riunione."
+    "Time:" : "Ora:",
+    "Could not open file" : "Impossibile aprire il file",
+    "Invalid chunk name" : "Nome non valido per lo spezzone",
+    "Could not rename part file assembled from chunks" : "Non è possibile rinominare il file assemblato da più spezzoni"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
