@@ -72,10 +72,20 @@ OC.L10N.register(
     "Description: %s" : "描述：%s",
     "Where: %s" : "地點：%s",
     "%1$s via %2$s" : "%1$s 由 %2$s",
-    "In a %1$s on %2$s for the entire day" : "%1$s 的 %2$s 整天",
-    "In a %1$s on %2$s between %3$s - %4$s" : "%1$s 的 %2$s 於 %3$s - %4$s 之間",
-    "In %1$s %2$s on %3$s for the entire day" : "%1$s %2$s 的 %3$s 整天",
-    "In %1$s %2$s on %3$s between %4$s - %5$s" : "%1$s %2$s 的 %3$s 於 %4$s - %5$s 之間",
+    "In the past on %1$s for the entire day" : "在過去 %1$s 的整天",
+    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["將在 %n 分鐘之後於 %1$s 整天進行"],
+    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["將在 %n 小時之後於 %1$s 整天進行"],
+    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["將在 %n 天之後於 %1$s 整天進行"],
+    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["將在 %n 星期之後於 %1$s 整天進行"],
+    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["將在 %n 個月之後於 %1$s 整天進行"],
+    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["將在 %n 年之後於 %1$s 整天進行"],
+    "In the past on %1$s between %2$s - %3$s" : "於已經過去的 %1$s %2$s - %3$s 之間進行",
+    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["將在 %n 分鐘之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["將在 %n 小時之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["將在 %n 天之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["將在 %n 星期之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["將在 %n 個月之後於 %1$s %2$s - %3$s 之間進行"],
+    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["將在 %n 年之後於 %1$s %2$s - %3$s 之間進行"],
     "Could not generate when statement" : "無法產生 when 陳述",
     "Every Day for the entire day" : "每天一整天",
     "Every Day for the entire day until %1$s" : "每天一整天，直至 %1$s",
@@ -112,12 +122,27 @@ OC.L10N.register(
     "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "每 %1$d 年於 %2$s 的 %3$s，在 %4$s - %5$s 之間，直至 %6$s",
     "On specific dates for the entire day until %1$s" : "在特定日期的整天，直至 %1$s",
     "On specific dates between %1$s - %2$s until %3$s" : "在 %1$s - %2$s 之間的特定日期，直至 %3$s",
-    "In a %1$s on %2$s" : "在 %1$s 的 %2$s",
-    "In a %1$s on %2$s then on %3$s" : "在 %1$s 的 %2$s，然後 %3$s",
-    "In a %1$s on %2$s then on %3$s and %4$s" : "在 %1$s 的 %2$s，然後 %3$s 與 %4$s",
-    "In %1$s %2$s on %3$s" : "在 %1$s %2$s 的 %3$s",
-    "In %1$s %2$s on %3$s then on %4$s" : "在 %1$s %2$s 的 %3$s，然後 %4$s",
-    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "在 %1$s %2$s 的 %3$s，然後 %4$s 與 %5$s",
+    "In the past on %1$s" : "於已經過去的 %1$s 進行",
+    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["將在 %n 分鐘之後於 %1$s 進行"],
+    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["將在 %n 小時之後於 %1$s 進行"],
+    "_In a day on %1$s_::_In %n days on %1$s_" : ["將在 %n 天之後於 %1$s 進行"],
+    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["將在 %n 星期之後於 %1$s 進行"],
+    "_In a month on %1$s_::_In %n months on %1$s_" : ["將在 %n 個月之後於 %1$s 進行"],
+    "_In a year on %1$s_::_In %n years on %1$s_" : ["將在 %n 年之後於 %1$s 進行"],
+    "In the past on %1$s then on %2$s" : "在過去的 %1$s，然後在 %2$s 進行",
+    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["將在 %n 分鐘之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["將在 %n 小時之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["將在 %n 天之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["將在 %n 星期之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["將在 %n 個月之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["將在 %n 年之後於 %1$s 進行，然後在 %2$s 再次進行"],
+    "In the past on %1$s then on %2$s and %3$s" : "在過去的 %1$s 進行，然後在 %2$s 及 %3$s 再次進行",
+    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["將在 %n 分鐘之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["將在 %n 小時之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["將在 %n 天之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["將在 %n 星期之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["將在 %n 個月之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
+    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["將在 %n 年之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
     "Could not generate next recurrence statement" : "無法產生下一個重複語句",
     "Cancelled: %1$s" : "已取消：%1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" 已被取消",
@@ -164,12 +189,12 @@ OC.L10N.register(
     "Second" : "第二",
     "Third" : "第三",
     "Fourth" : "第四",
-    "Fifty" : "五十",
+    "Fifth" : "第五",
     "Last" : "最後",
     "Second Last" : "尾二",
     "Third Last" : "尾三",
     "Fourth Last" : "尾四",
-    "Fifty Last" : "尾五",
+    "Fifth Last" : "尾五",
     "Contacts" : "聯絡人",
     "{actor} created address book {addressbook}" : "{actor} 創建了通訊錄 {addressbook} ",
     "You created address book {addressbook}" : "您創建了通訊錄 {addressbook} ",
@@ -198,6 +223,7 @@ OC.L10N.register(
     "Accounts" : "帳戶",
     "System address book which holds all accounts" : "包含所有帳戶的系統通訊錄",
     "File is not updatable: %1$s" : "檔案無法更新：%1$s",
+    "Failed to get storage for file" : "無法取得檔案儲存空間",
     "Could not write to final file, canceled by hook" : "無法寫入最終檔案，被掛勾取消",
     "Could not write file contents" : "無法寫入檔案內容",
     "_%n byte_::_%n bytes_" : ["%n 位元組"],
@@ -206,7 +232,8 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "無法將部份檔案重新命名為最終檔案，被掛勾取消",
     "Could not rename part file to final file" : "無法將部份檔案重新命名為最終檔案",
     "Failed to check file size: %1$s" : "檢查檔案大小失敗：%1$s",
-    "Could not open file" : "無法開啟檔案",
+    "Could not open file: %1$s, file does seem to exist" : "無法開啟檔案：%1$s，檔案似乎存在",
+    "Could not open file: %1$s, file doesn't seem to exist" : "無法開啟檔案：%1$s，檔案似乎不存在",
     "Encryption not ready: %1$s" : "尚未準備好加密：%1$s",
     "Failed to open file: %1$s" : "開啟檔案失敗：%1$s",
     "Failed to unlink: %1$s" : "解除連結失敗：%1$s",
@@ -223,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "完成於 %s",
     "Due on %s by %s" : "完成日期為 %s %s",
     "Due on %s" : "完成日期 %s",
+    "System Address Book" : "系統通訊錄",
+    "The system address book contains contact information for all users in your instance." : "系統通訊錄包含您實例中的所有聯絡人資訊。",
+    "Enable System Address Book" : "啟用系統通訊錄",
     "DAV system address book" : "DAV 系統通訊錄",
     "No outstanding DAV system address book sync." : "沒有未完成的 DAV 系統通訊錄同步。",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV 系統通訊錄同步尚未執行，因為您的實例有超過 1000 個用戶，或是因為遇到錯誤。請透過 \"occ dav:sync-system-addressbook\" 手動執行。",
@@ -234,6 +264,10 @@ OC.L10N.register(
     "Calendars including events, details and attendees" : "日曆，包括活動、詳細信息和與會者",
     "Contacts and groups" : "聯絡人和群組",
     "WebDAV" : "WebDAV",
+    "Absence saved" : "缺席時段已儲存",
+    "Failed to save your absence settings" : "無法保存您的缺席設定",
+    "Absence cleared" : "缺席時段已清除",
+    "Failed to clear your absence settings" : "無法清除您的缺席設定",
     "First day" : "第一天",
     "Last day (inclusive)" : "最後一天（含）",
     "Out of office replacement (optional)" : "外出時的替代人員（非強制的）",
@@ -244,10 +278,9 @@ OC.L10N.register(
     "Long absence Message" : "長期缺席訊息",
     "Save" : "保存",
     "Disable absence" : "停用缺席",
-    "Absence saved" : "缺席時段已儲存",
-    "Failed to save your absence settings" : "無法保存您的缺席設定",
-    "Absence cleared" : "缺席時段已清除",
-    "Failed to clear your absence settings" : "無法清除您的缺席設定",
+    "Failed to load availability" : "加載空閒時間失敗",
+    "Saved availability" : "已保存空閒時間",
+    "Failed to save availability" : "未能保存空閒時間",
     "Time zone:" : "時區：",
     "to" : "至",
     "Delete slot" : "刪除欄位",
@@ -257,13 +290,12 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "為 {dayName} 挑選開始時間",
     "Pick a end time for {dayName}" : "為 {dayName} 挑選結束時間",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "在忙碌時，自動將用戶狀態設定為「請勿打擾」以靜音所有通知。",
-    "Failed to load availability" : "加載空閒時間失敗",
-    "Saved availability" : "已保存空閒時間",
-    "Failed to save availability" : "未能保存空閒時間",
     "Availability" : "空閒時間",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他人仕在預約會議時就會知道您何時不在辦公室。",
     "Absence" : "缺席",
     "Configure your next absence period." : "設定您的下一個缺席時段。",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安裝 {calendarappstoreopen}日曆應用程式{linkclose}或安裝{calendardocopen}以連接您的桌面電腦和流動裝置進行同步↗{linkclose}。",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "請確保正確設置{emailopen}電郵伺服器{linkclose}。",
     "Calendar server" : "日曆伺服器",
     "Send invitations to attendees" : "發送邀請函給參加者",
     "Automatically generate a birthday calendar" : "自動生成生日日曆",
@@ -274,17 +306,27 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "也向共享日曆者傳送提醒通告",
     "Reminders are always sent to organizers and attendees." : "一律傳送提醒通知給舉辦者與參與者。",
     "Enable notifications for events via push" : "啟用推送活動通知",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安裝 {calendarappstoreopen}日曆應用程式{linkclose}或安裝{calendardocopen}以連接您的桌面電腦和流動裝置進行同步↗{linkclose}。",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "請確保正確設置{emailopen}電郵伺服器{linkclose}。",
+    "Cancel" : "取消",
+    "Import" : "導入",
+    "Error while saving settings" : "儲存設定時發生錯誤",
+    "Contact reset successfully" : "聯絡人重設成功",
+    "Error while resetting contact" : "重設聯絡人時發生錯誤",
+    "Contact imported successfully" : "成功導入了聯絡人",
+    "Error while importing contact" : "導入聯絡人時發生錯誤",
+    "Example Content" : "範例內容",
+    "Set example content to be created on new user first login." : "設定新用戶首次登入時所建立的範例內容。",
+    "Import contact" : "導入聯絡人",
+    "Reset to default contact" : "重設為默認聯絡人",
+    "Import contacts" : "導入聯絡人",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "導入新的 .vcf 檔案將刪除現有的默認聯絡人並將其替換為新的聯絡人。您想繼續嗎？",
     "There was an error updating your attendance status." : "更新您的參與狀況時發生錯誤",
     "Please contact the organizer directly." : "請直接聯繫絡主辦人",
     "Are you accepting the invitation?" : "接受邀請嗎？",
     "Tentative" : "暫定",
     "Your attendance was updated successfully." : "您的參與狀況成功更新",
-    "To-dos" : "待辦事項",
     "Time:" : "時間：",
+    "Could not open file" : "無法開啟檔案",
     "Invalid chunk name" : "無效的區塊名稱",
-    "Could not rename part file assembled from chunks" : "無法重新命名從區塊組合成的部份檔案",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他用戶在預約會議時就會知道您何時不在辦公室。"
+    "Could not rename part file assembled from chunks" : "無法重新命名從區塊組合成的部份檔案"
 },
 "nplurals=1; plural=0;");
