@@ -43,7 +43,17 @@ OC.L10N.register(
     "Files" : "Tiedostot",
     "A file or folder has been <strong>changed</strong>" : "Tiedostoa tai kansiota on <strong>muutettu</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Suosikkitiedostoa tai -kansiota on <strong>muutettu</strong>",
+    "Failed to authorize" : "Valtuuttaminen epäonnistui",
+    "Invalid folder path" : "Virheellinen kansion polku",
+    "Folder not found" : "Kansiota ei löytynyt",
+    "The file cannot be found" : "Tiedostoa ei löytynyt",
+    "The destination path does not exist: %1$s" : "Kohdepolkua ei ole olemassa: %1$s",
+    "You do not have permission to create a file at the specified location" : "Sinulla ei ole oikeutta luoda tiedostoa määriteltyyn sijaintiin.",
+    "The file could not be converted." : "Tiedostoa ei voitu muuntaa.",
+    "Could not get relative path to converted file" : "Muunnetun tiedoston suhteellista polkua ei voitu hakea",
+    "Favorite files" : "Suosikkitiedostot",
     "No favorites" : "Ei suosikkeja",
+    "More favorites" : "Lisää suosikeja",
     "Upload (max. %s)" : "Lähetys (enintään %s)",
     "Accept" : "Hyväksy",
     "Reject" : "Hylkää",
@@ -57,26 +67,29 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "Kohteen {path} omistajuussiirto käyttäjälle {user} valmistui.",
     "The ownership transfer of {path} from {user} has completed." : "Kohteen {path} omistajuussiirto käyttäjältä {user} valmistui.",
     "in %s" : "polussa %s",
+    "Files compatibility" : "Tiedostojen yhteensopivuus",
+    "Enforce Windows compatibility" : "Pakota Windows-yhteensopivuus",
     "File Management" : "Tiedostohallinta",
-    "Current directory path" : "Nykyisen kansion polku",
     "Home" : "Koti",
     "Target folder does not exist any more" : "Kohdekansiota ei ole enää olemassa",
     "Reload current directory" : "Lataa nykyinen kansio uudelleen",
     "Go to the \"{dir}\" directory" : "Siirry kansioon \"{dir}\"",
-    "Drag and drop files here to upload" : "Vedä ja pudota tiedostot tähän lähettääksesi",
+    "Current directory path" : "Nykyisen kansion polku",
     "Your have used your space quota and cannot upload files anymore" : "Olet käyttänyt tilakiintiösi, joten et voi lähettää enempää tiedostoja",
-    "You don’t have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai kansioiden luomiseen tähän sijaintiin",
+    "You do not have permission to upload or create files here." : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai luomiseen tänne.",
+    "Drag and drop files here to upload" : "Vedä ja pudota tiedostot tähän lähettääksesi",
     "Favorite" : "Suosikki",
     "Back" : "Takaisin",
     "File is loading" : "Tiedostoa ladataan",
     "Folder is loading" : "Kansiota ladataan",
-    "Rename file" : "Nimeä tiedosto uudelleen",
     "Filename" : "Tiedostonimi",
     "Folder name" : "Kansion nimi",
     "Invalid filename." : "Epäkelpo tiedostonimi.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Kohteen \"{oldName}\" uudeksi nimeksi asetettiin \"{newName}\"",
-    "Unknown date" : "Tuntematon päivämäärä",
+    "Rename file" : "Nimeä tiedosto uudelleen",
+    "Folder" : "Kansio",
     "Pending" : "Odottaa",
+    "Unknown date" : "Tuntematon päivämäärä",
     "Clear filter" : "Tyhjennä suodatin",
     "Modified" : "Muokattu",
     "Type" : "Tyyppi",
@@ -84,29 +97,27 @@ OC.L10N.register(
     "Remove filter" : "Poista suodatin",
     "Name" : "Nimi",
     "Size" : "Koko",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massatoiminto suoritettu",
     "Actions" : "Toiminnot",
     "(selected)" : "(valittu)",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massatoiminto suoritettu",
-    "{count} selected" : "{count} valittu",
     "List of files and folders." : "Luettelo tiedostoista ja kansioista.",
+    "You have used your space quota and cannot upload files anymore." : "Olet käyttänyt tilakiintiösi, etkä voi enää ladata tiedostoja.",
     "Column headers with buttons are sortable." : "Painikkeilla varustetut sarakeotsikot ovat järjestettävissä.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Tätä luetteloa ei ole esitetty täysin suorituskykyyn liittyvistä syistä. Tiedostot esitetään sitä mukaa, kun selaat luetteloa.",
     "File not found" : "Tiedostoa ei löytynyt",
-    "Storage information" : "Tallennustilan tiedot",
+    "{count} selected" : "{count} valittu",
     "{usedQuotaByte} used" : "{usedQuotaByte} käytetty",
     "{used} of {quota} used" : "{used}/{quota} käytetty",
     "{relative}% used" : "{relative} % käytetty",
     "Could not refresh storage stats" : "Tallennustilan tilastoja ei voitu päivittää",
     "Your storage is full, files can not be updated or synced anymore!" : "Tallennustila on loppu, tiedostoja ei voi enää päivittää tai synkronoida!",
-    "Create" : "Luo",
+    "Storage information" : "Tallennustilan tiedot",
+    "Storage quota" : "Tallennustilan kiintiö",
     "New folder" : "Uusi kansio",
     "Create new folder" : "Luo uusi kansio",
     "This name is already in use." : "Tämä nimi on jo käytössä.",
+    "Create" : "Luo",
     "Submit" : "Lähetä",
-    "Transfer ownership of a file or folder" : "Siirrä tiedoston tai kansion omistajuus",
-    "Choose file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
-    "Change" : "Muuta",
-    "New owner" : "Uusi omistaja",
     "Choose a file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
     "Transfer" : "Siirrä",
     "Transfer {path} to {userid}" : "Siirrä {path} käyttäjälle {userid}",
@@ -114,61 +125,94 @@ OC.L10N.register(
     "Unknown error" : "Tuntematon virhe",
     "Ownership transfer request sent" : "Pyyntö omistajuuden vaihdosta lähetetty",
     "Cannot transfer ownership of a file or folder you do not own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista",
+    "Transfer ownership of a file or folder" : "Siirrä tiedoston tai kansion omistajuus",
+    "Choose file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
+    "Change" : "Muuta",
+    "New owner" : "Uusi omistaja",
+    "Keep {old}" : "Pidä {old}",
+    "Use {new}" : "Käytä {new}",
+    "Remove extension" : "Poista tiedostopääte",
+    "Change file extension" : "Vaihda tiedostopäätettä",
+    "Do not show this dialog again." : "Älä näytä uudelleen",
     "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
     "Choose {file}" : "Valitse {file}",
-    "Loading current folder" : "Ladataan nykyistä kansiota",
-    "Retry" : "Yritä uudelleen",
-    "No files in here" : "Täällä ei ole tiedostoja",
-    "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
-    "Go back" : "Mene takaisin",
     "Share" : "Jaa",
     "Shared by link" : "Jaettu linkillä",
     "Shared" : "Jaettu",
     "Switch to list view" : "Vaihda taulukkonäkymään",
     "Switch to grid view" : "Vaihda ruudukkonäkymään",
+    "The file could not be found" : "Tiedostoa ei löytynyt",
     "Upload was cancelled by user" : "Käyttäjä peruutti latauksen",
     "Not enough free space" : "Ei tarpeeksi vapaata tilaa",
     "Operation is blocked by access control" : "Pääsynhallinta estää toiminnon",
     "Error during upload: {message}" : "Virhe lähettäessä: {message}",
     "Error during upload, status code {status}" : "Virhe lähettäessä, tilakoodi {status}",
     "Unknown error during upload" : "Tuntematon virhe lähettämisen aikana",
-    "Filter filenames…" : "Suodata tiedostonimiä...",
+    "Loading current folder" : "Ladataan nykyistä kansiota",
+    "Retry" : "Yritä uudelleen",
+    "No files in here" : "Täällä ei ole tiedostoja",
+    "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
+    "Go back" : "Mene takaisin",
+    "Filter file names …" : "Suodata tiedostonimiä…",
     "Views" : "Näkymät",
     "Files settings" : "Tiedostojen asetukset",
-    "File cannot be accessed" : "Tiedostoa ei voi käyttää",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Tiedostoa ei löytynyt tai oikeutesi eivät riitä sen katseluun. Pyydä lähettäjää jakamaan se.",
     "Your files" : "Tiedostot",
     "Open in files" : "Avaa tiedostosovelluksessa",
+    "File cannot be accessed" : "Tiedostoa ei voi käyttää",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Tiedostoa ei löytynyt tai oikeutesi eivät riitä sen katseluun. Pyydä lähettäjää jakamaan se.",
+    "Clipboard is not available" : "Leikepöytä ei ole käytettävissä",
+    "WebDAV URL copied to clipboard" : "WebDAV-osoite kopioitu leikepöydälle",
     "Sort favorites first" : "Järjestä suosikit ensiksi",
     "Sort folders before files" : "Järjestä kansiot ennen tiedostoja",
     "Show hidden files" : "Näytä piilotetut tiedostot",
     "Crop image previews" : "Rajaa kuvien esikatseluja",
     "Enable the grid view" : "Käytä ruudukkonäkymää",
+    "Enable folder tree" : "Ota kansiopuu käyttöön",
     "Additional settings" : "Lisäasetukset",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV:in URL-osoite",
     "Copy to clipboard" : "Kopioi leikepöydälle",
     "Use this address to access your Files via WebDAV" : "Käytä tätä osoitetta yhdistääksesi tiedostosi WebDAV:in kautta",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Jos sinulla on kaksivaiheinen todennus käytössä, sinun täytyy luoda uusi sovellussalasana ja käyttää sitä napsauttamalla tästä.",
+    "Warnings" : "Varoitukset",
     "Keyboard shortcuts" : "Pikanäppäimet",
+    "Speed up your Files experience with these quick shortcuts." : "Nopeuta tiedostonhallinnan kokemusta näillä pikanäppäimillä.",
+    "Open the actions menu for a file" : "Avaa tiedoston toimintovalikko",
+    "Rename a file" : "Nimeä tiedosto uudelleen",
+    "Delete a file" : "Poista tiedosto",
+    "Favorite or remove a file from favorites" : "Lisää tai poista tiedosto suosikeista",
+    "Manage tags for a file" : "Hallinnoi tiedosto tunnisteita",
     "Selection" : "Valinta",
+    "Select all files" : "Valitse kaikki tiedostot",
+    "Deselect all files" : "Poista kaikkien tiedostojen valinta",
+    "Select or deselect a file" : "Valitse tiedosto tai poista sen valinta",
     "Navigation" : "Navigointi",
     "View" : "Näytä",
-    "Clipboard is not available" : "Leikepöytä ei ole käytettävissä",
-    "WebDAV URL copied to clipboard" : "WebDAV-osoite kopioitu leikepöydälle",
+    "Open the sidebar for a file" : "Avaa tiedoston sivupalkki",
+    "You" : "Sinä",
+    "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
+    "Error while loading the file data" : "Virhe tiedostoa ladatessa",
     "Owner" : "Omistaja",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
     "Tags" : "Tunnisteet",
-    "You" : "Sinä",
-    "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
-    "Unable to change the favourite state of the file" : "Suosikki-tilan muuttaminen epäonnistui.",
-    "Error while loading the file data" : "Virhe tiedostoa ladatessa",
+    "Blank" : "Tyhjä",
+    "Unable to create new file from template" : "Uutta tiedostoa mallipohjasta ei voi luoda",
     "Pick a template for {name}" : "Valtise mallipohja tiedostolle {name}",
     "Create a new file with the selected template" : "Luo uusi tiedosto valitulla mallipohjalla",
     "Creating file" : "Luodaan tiedostoa",
-    "Blank" : "Tyhjä",
-    "Unable to create new file from template" : "Uutta tiedostoa mallipohjasta ei voi luoda",
+    "Save as {displayName}" : "Tallenna nimellä {displayName}",
+    "Save as …" : "Tallenna nimellä",
+    "Converting files …" : "Muunnetaan tiedostoja…",
+    "Failed to convert files: {message}" : "Tiedostojen muuntaminen epäonnistui: {message}",
+    "All files failed to be converted" : "Mitään tiedostoista ei voitu muuntaa",
+    "One file could not be converted: {message}" : "Yhtä tiedostoa ei voitu muuntaa: {message}",
+    "Files successfully converted" : "Tiedostot muunnettu onnistuneesti",
+    "Failed to convert files" : "Tiedostojen muuntaminen epäonnistui",
+    "Converting file …" : "Muunnetaan tiedostoa…",
+    "File successfully converted" : "Tiedosto muunnettu onnistuneesti",
+    "Failed to convert file: {message}" : "Tiedoston muuntaminen epäonnistui: {message}",
+    "Failed to convert file" : "Tiedoston muuntaminen epäonnistui",
     "Deletion cancelled" : "Poistaminen peruttu",
     "Leave this share" : "Poistu tästä jaosta",
     "Disconnect storage" : "Katkaise yhteys tallennustilaan",
@@ -184,10 +228,8 @@ OC.L10N.register(
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Olet poistamassa {count} kohteen","Olet poistamassa {count} kohdetta"],
     "Confirm deletion" : "Vahvista poistaminen",
     "Cancel" : "Peruuta",
-    "Edit file locally" : "Muokkaa tiedostoa paikallisesti",
-    "Retry and close" : "Yritä uudelleen ja sulje",
-    "Failed to redirect to client" : "Uudelleenohjaus asiakkaaseen epäonnistui",
-    "Edit locally" : "Muokkaa paikallisesti",
+    "Moving \"{source}\" to \"{destination}\" …" : "Siirretään \"{source}\" kohteeseen \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopioidaan \"{source}\" kohteeseen \"{destination}\" …",
     "(copy)" : "(kopioi)",
     "Move cancelled" : "Siirtäminen peruttu",
     "A file or folder with that name already exists in this folder" : "Tiedosto tai kansio tällä nimellä on jo olemassa tässä kansiossa",
@@ -203,6 +245,10 @@ OC.L10N.register(
     "Cancelled move or copy operation" : "Siirto- tai kopiointitoiminto peruttu",
     "Open folder {displayName}" : "Avaa kansio {displayName}",
     "Open in Files" : "Avaa tiedostosovelluksessa",
+    "Open file locally" : "Avaa tiedosto paikallisesti",
+    "Retry and close" : "Yritä uudelleen ja sulje",
+    "Failed to redirect to client" : "Uudelleenohjaus asiakkaaseen epäonnistui",
+    "Open locally" : "Avaa paikallisesti",
     "Rename" : "Nimeä uudelleen",
     "Open details" : "Avaa yksityiskohdat",
     "View in folder" : "Näe kansiossa",
@@ -222,6 +268,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Kansion luominen peruttu",
     "Created new folder \"{name}\"" : "Luotu uusi kansio \"{name}\"",
     "Unable to initialize the templates directory" : "Mallipohjien kansiota ei voitu alustaa",
+    "Create templates folder" : "Luo mallipohjien kansio",
     "Templates" : "Mallipohjat",
     "New template folder" : "Uusi mallipohjien kansio",
     "In folder" : "Kansiossa",
@@ -241,19 +288,20 @@ OC.L10N.register(
     "This operation is forbidden" : "Tämä toiminto on kielletty",
     "This directory is unavailable, please check the logs or contact the administrator" : "Hakemisto ei ole käytettävissä. Tarkista lokit tai ole yhteydessä ylläpitoon.",
     "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} kansio","{folderCount} kansiota"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} tiedosto","{fileCount} tiedostoa"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 tiedosto ja {folderCount} kansio","1 tiedosto ja {folderCount} kansiota"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} tiedosto ja 1 kansio","{fileCount} tiedostoa ja 1 kansio"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} tiedostoa ja {folderCount} kansiota",
+    "Unexpected error: {error}" : "Odottamaton virhe: {error}",
+    "_%n file_::_%n files_" : ["%n tiedosto","%n tiedostoa"],
+    "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
     "Filename must not be empty." : "Tiedostonimi ei voi olla tyhjä.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ei ole sallittu tiedoston nimessä.",
     "\"{extension}\" is not an allowed filetype." : "\"{extension}\" ei ole sallitttu tiedostotyyppi.",
+    "Filenames must not end with \"{extension}\"." : "Tiedostojen nimet eivät voi päättyä \"{extension}\".",
+    "List of favorite files and folders." : "Luettelo suosikkitiedostoista ja -kansioista.",
     "No favorites yet" : "Ei vielä suosikkeja",
     "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä",
     "All files" : "Kaikki tiedostot",
     "List of your files and folders." : "Luettelo tiedostoistasi ja kansioistasi.",
     "All folders" : "Kaikki kansiot",
-    "Personal Files" : "Henkilökohtaiset tiedostot",
+    "Personal files" : "Henkilökohtaiset tiedostot",
     "List of your files and folders that are not shared." : "Luettelo tiedostoistasi ja kansioistasi, joita ei ole jaettu.",
     "No personal files found" : "Henkilökohtaisia tiedostoja ei löytynyt",
     "Files that are not shared will show up here." : "Tiedostot, joita ei ole jasettu, näkyvät täällä.",
@@ -261,7 +309,6 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Luettelo äskettäin muokatuista tiedostoista ja kansioista.",
     "No recently modified files" : "Ei äskettäin muokattuja tiedostoja",
     "Files and folders you recently modified will show up here." : "Äskettäin muokkaamasi tiedostot ja kansiot näkyvät täällä.",
-    "You do not have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai luomiseen tähän sijaintiin",
     "No entries found in this folder" : "Ei kohteita tässä kansiossa",
     "Select all" : "Valitse kaikki",
     "Upload too large" : "Lähetettävä tiedosto on liian suuri",
@@ -289,6 +336,7 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Virhe koottaessa lohkoja, tilakoodi {status}",
     "Choose target folder" : "Valitse kohdekansio",
     "Set reminder" : "Aseta muistutus",
+    "Edit locally" : "Muokkaa paikallisesti",
     "Open" : "Avaa",
     "Could not load info for file \"{file}\"" : "Ei voida ladata tiedoston \"{file}\" tietoja",
     "Details" : "Tiedot",
@@ -315,10 +363,9 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Virhe poistaessa tiedostoa \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Ei hakutuloksia muissa kansioissa haulla {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Kirjoita enemmän kuin kaksi merkkiä etsiäksesi muista kansioista",
-    "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
-    "_%n file_::_%n files_" : ["%n tiedosto","%n tiedostoa"],
     "{dirs} and {files}" : "{dirs} ja {files}",
     "_including %n hidden_::_including %n hidden_" : ["Sisältäen %n piilotetun","Sisältäen %n piilotettua"],
+    "You do not have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai luomiseen tähän sijaintiin",
     "_Uploading %n file_::_Uploading %n files_" : ["Lähetetään %n tiedosto","Lähetetään %n tiedostoa"],
     "New" : "Uusi",
     "New file/folder menu" : "Uusi tiedosto/kansio -valikko",
@@ -338,32 +385,34 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Erillinen tallennustila \"{mountPoint}\" on melkein täynnä ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Tallennustila on melkein täynnä ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["vastaa \"{filter}\"","vastaa \"{filter}\""],
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Suoralinkki kopioitiin (toimii vain niillä käyttäjillä, joilla on pääsy kyseiseen tiedostoon/kansioon)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Suora linkki kopioitu (toimii vain henkilöillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
     "Path" : "Polku",
     "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
     "Favorited" : "Lisätty suosikkeihin",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopioi suora linkki (toimii vain käyttäjillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopioi suora linkki (toimii vain henkilöillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
     "Upload file" : "Lähetä tiedosto",
     "Not favorited" : "Ei suosikeissa",
     "An error occurred while trying to update the tags" : "Tunnisteiden päivitystä yrittäessä tapahtui virhe",
-    "\"remote user\"" : "\"etäkäyttäjä\"",
-    "{newName} already exists." : "{newName} on jo olemassa.",
-    "Name cannot be empty" : "Nimi ei voi olla tyhjä",
-    "Another entry with the same name already exists" : "Toinen tietue samalla nimellä on jo olemassa",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Kohdetta \"{oldName}\" ei voitu nimetä uudelleen, koska sitä ei ole enää olemassa",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{newName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
-    "Could not rename \"{oldName}\"" : "Ei voitu nimetä uudelleen \"{oldName}\"",
+    "You don't have permission to upload or create files here." : "Sinulla ei ole oikeutta lähettää tai luoda tiedostoja tänne.",
     "Storage informations" : "Tallennustilan tietoja",
     "Choose file" : "Valitse tiedosto",
     "Go to the previous folder" : "Siirry edelliseen kansioon",
     "Open the files app settings" : "Avaa tiedostosovelluksen asetukset",
-    "You might not have have permissions to view it, ask the sender to share it" : "Oikeutesi eivät kenties riitä sen katseluun, pyydä lähettäjää jakamaan se",
-    "The files is locked" : "Tiedosto on lukittu",
+    "Unable to change the favourite state of the file" : "Suosikki-tilan muuttaminen epäonnistui.",
+    "Edit file locally" : "Muokkaa tiedostoa paikallisesti",
     "Create new templates folder" : "Luo uusi mallipohjien kansio",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} kansio","{folderCount} kansiota"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} tiedosto","{fileCount} tiedostoa"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 tiedosto ja {folderCount} kansio","1 tiedosto ja {folderCount} kansiota"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} tiedosto ja 1 kansio","{fileCount} tiedostoa ja 1 kansio"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} tiedostoa ja {folderCount} kansiota",
     "List of favorites files and folders." : "Luettelo suosikkitiedostoista ja -kansioista.",
+    "Personal Files" : "Henkilökohtaiset tiedostot",
     "Text file" : "Tekstitiedosto",
     "New text file.txt" : "Uusi tekstitiedosto.txt",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Suora linkki kopioitu (toimii vain henkilöillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopioi suora linkki (toimii vain henkilöillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)"
+    "Submitting fields…" : "Lähetetään tietoja...",
+    "Filter filenames…" : "Suodata tiedostonimiä...",
+    "{count} files could not be converted" : "{count} tiedostoa ei voitu muuntaa",
+    "{count} files successfully converted" : "{count} tiedostoa muunnettu onnistuneesti"
 },
 "nplurals=2; plural=(n != 1);");
