@@ -46,6 +46,7 @@ OC.L10N.register(
     "Failed to authorize" : "Falhou a autorização",
     "Invalid folder path" : "Caminho da pasta inválido",
     "Folder not found" : "Pasta não encontrada",
+    "No favorites" : "Sem favoritos",
     "Upload (max. %s)" : "Envio (máx. %s)",
     "Accept" : "Aceitar",
     "Reject" : "Rejeitar",
@@ -66,28 +67,27 @@ OC.L10N.register(
     "Enforce Windows compatibility" : "Forçar a compatibilidade com Windows",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : " Isto bloqueará os nomes de ficheiro não válidos nos sistemas Windows, como a utilização de nomes reservados ou carateres especiais. Mas isto não irá impor a compatibilidade da sensibilidade à caixa alta maiúsculas ou baixa minúsculas.",
     "File Management" : "Gestão de ficheiros",
-    "Current directory path" : "Caminho da pasta atual",
     "Home" : "Início",
     "Target folder does not exist any more" : "A pasta de destino já não existe",
     "Reload current directory" : "Recarregar a pasta atual",
     "Go to the \"{dir}\" directory" : "Ir para a pasta \"{dir}\"",
-    "Drag and drop files here to upload" : "Arraste e largue os ficheiros aqui para carregar",
+    "Current directory path" : "Caminho da pasta atual",
     "Your have used your space quota and cannot upload files anymore" : "Utilizou a sua quota de espaço e já não pode carregar mais ficheiros",
-    "You don’t have permission to upload or create files here" : "Não tem permissão para enviar ou criar ficheiros aqui",
+    "Drag and drop files here to upload" : "Arraste e largue os ficheiros aqui para carregar",
     "Favorite" : "Favorito",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ação executada com sucesso ",
-    "\"{displayName}\" action failed" : "\"{displayName}\" a ação falhou",
+    "Back" : "Voltar",
     "Toggle selection for file \"{displayName}\"" : "Alternar a seleção para o ficheiro \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "Alternar a seleção para a pasta \"{displayName}\"",
     "File is loading" : "Ficheiro está a carregar",
     "Folder is loading" : "Pasta está a carregar",
-    "Rename file" : "Renomear ficheiro",
     "Filename" : "Nome do ficheiro",
     "Folder name" : "Nome da pasta",
     "This node is unavailable" : "Este nó não está disponível",
     "Another entry with the same name already exists." : "Já existe outra entrada com o mesmo nome",
     "Invalid filename." : "Nome de ficheiro inválido",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Renomeado de \"{oldName}\" para \"{newName}\"",
+    "Rename file" : "Renomear ficheiro",
+    "Folder" : "Pasta",
     "Pending" : "Pendente",
     "Clear filter" : "Limpar filtro",
     "Modified" : "Modificado",
@@ -95,36 +95,31 @@ OC.L10N.register(
     "Active filters" : "Filtros ativos",
     "Remove filter" : "Remover filtro",
     "Total rows summary" : "Resumo do total de linhas",
+    "Toggle selection for all files and folders" : "Alternar a seleção para todos os ficheiros e pastas",
     "Name" : "Nome",
     "Size" : "Tamanho",
-    "Toggle selection for all files and folders" : "Alternar a seleção para todos os ficheiros e pastas",
+    "\"{displayName}\" batch action executed successfully" : "Ação de lote “{displayName}” executada com sucesso",
+    "\"{displayName}\" action failed" : "\"{displayName}\" a ação falhou",
     "Actions" : "Ações",
     "(selected)" : "(selecionado)",
-    "\"{displayName}\" failed on some elements " : "“{displayName}” falhou em alguns elementos",
-    "\"{displayName}\" batch action executed successfully" : "Ação de lote “{displayName}” executada com sucesso",
-    "{count} selected" : "{count} selecionado ",
     "List of files and folders." : "Lista de ficheiros e pastas.",
     "Column headers with buttons are sortable." : "Os cabeçalhos das colunas com botões são ordenáveis",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Por motivos de desempenho, esta lista não é totalmente processada. Os ficheiros serão processados à medida que navega na lista.",
     "File not found" : "Ficheiro não encontrado",
-    "Storage information" : "Informação de armazenamento",
-    "Storage quota" : "Quota de armazenamento",
+    "{count} selected" : "{count} selecionado ",
     "{usedQuotaByte} used" : "{usedQuotaByte} usado",
     "{used} of {quota} used" : "utilizado {used} de {quota}",
     "{relative}% used" : "{relative}% usado",
     "Could not refresh storage stats" : "Não foi possível atualizar as estatísticas de armazenamento",
     "Your storage is full, files can not be updated or synced anymore!" : "O seu armazenamento está cheio, os ficheiros já não podem ser atualizados ou sincronizados.",
-    "Create" : "Criar",
+    "Storage information" : "Informação de armazenamento",
+    "Storage quota" : "Quota de armazenamento",
     "New folder" : "Nova pasta",
     "Create new folder" : "Criar nova pasta",
     "This name is already in use." : "Este nome já está em uso.",
+    "Create" : "Criar",
     "Fill template fields" : "Preencher campos do modelo",
-    "Submitting fields…" : "Submeter campos…",
     "Submit" : "Submeter",
-    "Transfer ownership of a file or folder" : "Transferir a propriedade de um ficheiro ou pasta",
-    "Choose file or folder to transfer" : "Escolher ficheiro ou pasta para transferir",
-    "Change" : "Mudar",
-    "New owner" : "Novo proprietário",
     "Choose a file or folder to transfer" : "Escolher um ficheiro ou pasta para transferir",
     "Transfer" : "Transfere",
     "Transfer {path} to {userid}" : "Transfere {path} para {userid}",
@@ -132,39 +127,47 @@ OC.L10N.register(
     "Unknown error" : "Erro desconhecido",
     "Ownership transfer request sent" : "Pedido de transferência de propriedade enviado",
     "Cannot transfer ownership of a file or folder you do not own" : "Não é possível transferir a propriedade de um ficheiro ou pasta de que não é proprietário",
-    "New" : "Novo",
-    "Retry" : "Repetir",
-    "No files in here" : "Nenhuns ficheiros aqui",
-    "Upload some content or sync with your devices!" : "Envie algum conteúdo ou sincronize com os seus dispositivos!",
-    "Go back" : "Voltar",
+    "Transfer ownership of a file or folder" : "Transferir a propriedade de um ficheiro ou pasta",
+    "Choose file or folder to transfer" : "Escolher ficheiro ou pasta para transferir",
+    "Change" : "Mudar",
+    "New owner" : "Novo proprietário",
+    "Choose {file}" : "Escolher {file}",
     "Share" : "Partilhar",
     "Shared by link" : "Partilhado por hiperligação",
     "Shared" : "Partilhados",
     "Not enough free space" : "Espaço insuficiente",
     "Operation is blocked by access control" : "A operação está bloqueada pelo controlo de acesso",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ação executada com sucesso ",
+    "Retry" : "Repetir",
+    "No files in here" : "Nenhuns ficheiros aqui",
+    "Upload some content or sync with your devices!" : "Envie algum conteúdo ou sincronize com os seus dispositivos!",
+    "Go back" : "Voltar",
     "Views" : "Vistas",
     "Files settings" : "Definições do Ficheiros",
     "Show hidden files" : "Mostrar ficheiros ocultos",
     "Additional settings" : "Definições adicionais",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Copiar para área de transferência",
+    "Keyboard shortcuts" : "Atalhos de teclado",
+    "Navigation" : "Navegação",
+    "View" : "Ver",
+    "You" : "Vovê",
     "Owner" : "Proprietário",
     "Remove from favorites" : "Remover dos favoritos",
     "Add to favorites" : "Adicionar aos favoritos",
     "Tags" : "Etiquetas",
-    "You" : "Vovê",
-    "Delete permanently" : "Eliminar permanentemente",
     "Leave this share" : "Sair desta partilha",
-    "Disconnect storage" : "Desligue o armazenamento",
+    "Disconnect storage" : "Desligar armazenamento",
+    "Disconnect storages" : "Desligar armazenamentos",
+    "Delete permanently" : "Eliminar permanentemente",
     "Delete file" : "Apagar ficheiro",
     "Delete folder" : "Apagar pasta",
     "Delete" : "Apagar",
     "Cancel" : "Cancelar",
-    "Failed to redirect to client" : "Erro ao redirecionar para o cliente",
-    "Edit locally" : "Editar localmente",
     "Copy" : "Copiar",
     "Move" : "Mover",
     "Move or copy" : "Mover ou copiar",
+    "Failed to redirect to client" : "Erro ao redirecionar para o cliente",
     "Rename" : "Renomear",
     "View in folder" : "Ver na pasta",
     "Today" : "Hoje",
@@ -176,13 +179,13 @@ OC.L10N.register(
     "This operation is forbidden" : "Esta operação é proibida",
     "This directory is unavailable, please check the logs or contact the administrator" : "Esta diretoria está indisponível, por favor, verifique os registos ou contacte o administrador",
     "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
-    "{fileCount} files and {folderCount} folders" : "{fileCount} ficheiros e {folderCount} pastas",
+    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros","%n ficheiros"],
+    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas","%n pastas"],
     "No favorites yet" : "Sem favoritos",
     "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
     "All files" : "Todos os ficheiros",
-    "Personal Files" : "Ficheiros pessoais",
+    "Personal files" : "Ficheiros pessoais",
     "Recent" : "Recentes",
-    "You do not have permission to upload or create files here" : "Não tem permissão para carregar ou criar ficheiros aqui",
     "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
     "Select all" : "Selecionar todos",
     "Upload too large" : "Envio muito grande",
@@ -207,6 +210,7 @@ OC.L10N.register(
     "Uploading that item is not supported" : "O carregamento do item não é suportado",
     "Error when assembling chunks, status code {status}" : "Erro ao agregar partições, código de estado: {status}",
     "Choose target folder" : "Escolher pasta de destino",
+    "Edit locally" : "Editar localmente",
     "Open" : "Abrir",
     "Could not load info for file \"{file}\"" : "Não foi possível carregar informações do ficheiro \"{file}\"",
     "Details" : "Detalhes",
@@ -233,11 +237,11 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Erro ao eliminar o ficheiro \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Nenhum resultado noutras pastas para {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Digite mais de dois caracteres para pesquisar noutras pastas",
-    "_%n folder_::_%n folders_" : ["%n pasta","%n pastas","%n pastas"],
-    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros","%n ficheiros"],
     "{dirs} and {files}" : "{dirs} e {files}",
     "_including %n hidden_::_including %n hidden_" : ["incluindo %n ocultos","incluindo %n ocultos","incluindo %n ocultos"],
+    "You do not have permission to upload or create files here" : "Não tem permissão para carregar ou criar ficheiros aqui",
     "_Uploading %n file_::_Uploading %n files_" : ["A enviar %n ficheiro","A enviar %n ficheiros","A enviar %n ficheiros"],
+    "New" : "Novo",
     "New file/folder menu" : "Novo menu ficheiro/pasta",
     "Select file range" : "Selecionar o intervalo",
     "{used}%" : "{used}%",
@@ -251,16 +255,13 @@ OC.L10N.register(
     "Path" : "Caminho",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
     "Favorited" : "Nos Favoritos",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar hiperligação direta (apenas funciona para os utilizadores que tenham acesso a este ficheiro/pasta)",
     "Upload file" : "Enviar ficheiro",
     "Not favorited" : "Não favorito",
     "An error occurred while trying to update the tags" : "Ocorreu um erro ao tentar atualizar as etiquetas",
-    "\"remote user\"" : "\"utilizador remoto\"",
-    "Name cannot be empty" : "O Nome não pode estar vazio",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Não foi possível renomear “{oldName}”, já não existe",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome “{newName}” já está a ser utilizado na pasta “{dir}”. Por favor, escolha um nome diferente.",
-    "Could not rename \"{oldName}\"" : "Não foi possível renomear \"{oldName}\"",
+    "{fileCount} files and {folderCount} folders" : "{fileCount} ficheiros e {folderCount} pastas",
+    "Personal Files" : "Ficheiros pessoais",
     "Text file" : "Ficheiro de Texto",
-    "New text file.txt" : "Novo texto ficheiro.txt"
+    "New text file.txt" : "Novo texto ficheiro.txt",
+    "Submitting fields…" : "Submeter campos…"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
