@@ -10,12 +10,12 @@ OC.L10N.register(
     "Removed share for group {group}" : "到群组 {group} 的共享已被移除 ",
     "{actor} shared with group {group}" : "{actor}  被共享到群组 {group}",
     "{actor} removed share for group {group}" : "{actor} 删除了群组 {group} 的共享",
-    "Share for group {group} expired" : "给分组 {group} 的共享已过期",
+    "Share for group {group} expired" : "给群组 {group} 的共享已过期",
     "You shared {file} with group {group}" : "您与群组 {group} 共享了 {file} ",
     "You removed group {group} from {file}" : "已从 {file} 移除组 {group}",
     "{actor} shared {file} with group {group}" : "{actor} 与群组 {group} 共享了 {file} ",
     "{actor} removed group {group} from {file}" : "{actor} 从 {file} 删除群组 {group} ",
-    "Share for file {file} with group {group} expired" : "与分组 {group} 的文件共享 {file} 已过期",
+    "Share for file {file} with group {group} expired" : "与群组 {group} 的文件共享 {file} 已过期",
     "Shared as public link" : "共享为公开链接",
     "Removed public link" : "移除公开链接",
     "Public link expired" : "公开链接已过期",
@@ -55,6 +55,7 @@ OC.L10N.register(
     "Share for file {file} with {user} expired" : "与 {user} 的文件共享 {file} 已过期",
     "Share for file {file} expired" : "文件 {file} 的共享已过期",
     "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "通过邮件或公共链接共享的文件或文件夹<strong>已下载</strong>",
+    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "文件<strong>已上传</strong>到通过邮件或公共链接共享的文件夹",
     "A file or folder was shared from <strong>another server</strong>" : "<strong>其它服务器</strong> 中一个文件或者文件夹被共享 ",
     "Sharing" : "共享",
     "A file or folder has been <strong>shared</strong>" : "一个文件或文件夹已<strong>共享</strong>",
@@ -64,30 +65,42 @@ OC.L10N.register(
     "Please specify a file or folder path" : "请指定一个文件或文件夹路径",
     "Wrong path, file/folder does not exist" : "错误的路径，文件/文件夹不存在",
     "Could not create share" : "无法创建共享",
-    "Invalid permissions" : "无效的权限 ",
-    "Invalid date, date format must be YYYY-MM-DD" : "无效的日期，日期格式必须是 YYYY-MM-DD",
-    "Please specify a valid account to share with" : "请指定一个要分享的有效账户",
+    "Please specify a valid account to share with" : "请指定要分享的有效账号",
     "Group sharing is disabled by the administrator" : "群组共享已被管理员禁用",
     "Please specify a valid group" : "请指定一个有效的组",
     "Public link sharing is disabled by the administrator" : "公共链接共享已被管理员禁用",
-    "Public upload disabled by the administrator" : "公共上传已被管理员禁用",
-    "Public upload is only possible for publicly shared folders" : "公共上传仅适用于公共共享文件夹",
     "Please specify a valid email address" : "请指定有效得电子邮箱地址",
     "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud 通话应用没有启用，所以通过 Nextcloud 通话应用发送%s共享密码失败。",
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "共享 %1$s 失败，后端不允许类型为 %2$s 的共享",
-    "Please specify a valid federated account ID" : "请指定一个有效的联合账户 ID",
+    "Please specify a valid federated account ID" : "请指定有效的联合账号 ID",
     "Please specify a valid federated group ID" : "请指定一个有效的联合群组 ID",
+    "You cannot share to a Team if the app is not enabled" : "如果未启用应用，则无法与团队共享",
+    "Please specify a valid team" : "请指定有效团队",
     "Sharing %s failed because the back end does not support room shares" : "由于后端不支持房间共享，所以共享 %s 失败。",
     "Sharing %s failed because the back end does not support ScienceMesh shares" : "共享 %s 失败，因为后端不支持 ScienceMesh 共享。",
     "Unknown share type" : "未知共享类型",
     "Not a directory" : "不是一个目录",
     "Could not lock node" : "无法锁定节点",
-    "Could not lock path" : "无法锁定路径",
-    "Wrong or no update parameter given" : "错误或没有更新参数给出",
+    "Public upload is only possible for publicly shared folders" : "公共上传仅适用于公共共享文件夹",
     "Share must at least have READ or CREATE permissions" : "分享至少具有 READ 或 CREATE 权限",
     "Share must have READ permission if UPDATE or DELETE permission is set" : "分享如果设置了 UPDATE 或 DELETE 权限，则必须具有 READ 权限",
+    "Public upload disabled by the administrator" : "公共上传已被管理员禁用",
+    "Could not lock path" : "无法锁定路径",
+    "no sharing rights on this item" : "此项目没有共享权限",
+    "You are not allowed to edit incoming shares" : "不允许编辑传入共享",
+    "Wrong or no update parameter given" : "错误或没有更新参数给出",
     "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "“通过 Nextcloud 通话应用发送密码”共享文件或文件夹失败了，因为未启用Nextcloud 通话应用",
+    "Custom share link tokens have been disabled by the administrator" : "管理员已禁用自定义共享链接令牌",
+    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "令牌必须至少包含 1 个字符，并且只能包含字母、数字或连字符",
+    "Invalid date. Format must be YYYY-MM-DD" : "日期无效，格式必须为 YYYY-MM-DD",
+    "No sharing rights on this item" : "此项目没有共享权限",
+    "Invalid share attributes provided: \"%s\"" : "提供的共享属性无效：“%s”",
+    "You are not allowed to send mail notifications" : "不允许您发送邮件通知",
+    "No mail notification configured for this share type" : "没有为此共享类型配置邮件通知",
     "Wrong password" : "密码错误",
+    "Error while sending mail notification" : "发送邮件通知时发生错误",
+    "Failed to generate a unique token" : "无法生成唯一令牌",
+    "This share does not exist or is no longer available" : "此共享不存在或不再可用",
     "shared by %s" : "共享者 %s",
     "Download" : "下载",
     "Add to your %s" : "添加到您的 %s",
@@ -100,99 +113,130 @@ OC.L10N.register(
     "You received {share} to group {group} as a share by {user}" : "您收到了来自 {user} 的共享给分组 {group} 的 {share}",
     "Accept" : "接受",
     "Decline" : "拒绝",
+    "Remember to upload the files to %s" : "记得将文件上传到 %s",
+    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "我们想提醒您，您尚未将任何文件上传到共享文件夹。",
+    "Open \"%s\"" : "打开“%s”",
     "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "该应用程序允许用户在 Nextcloud 内部共享文件。启用该应用程序，管理员能够选择哪个群组可以分享文件。然后，适用用户能够分享文件和文件夹给其他用户和群组。除此之外，如果管理员启用共享链接功能，用户能够通过外部链接将文件分享给 Nextcloud 以外的用户。同时，管理员可以强制用户分享时设置密码，分享时效，并且可以启用服务端通过链接分享或从移动设备分享功能。\n关闭此功能，所有共享接收者的服务器上共享的文件和文件夹将被移除，同时也会在同步客户端和移动应用程序上移除。更多信息可查阅 Nextcloud 说明文档。",
-    "People" : "人物",
-    "When should the request expire?" : "请求何时到期？",
-    "Expiration date" : "过期日期 ",
-    "What password should be used for the request?" : "请求应使用什么密码？",
-    "Set a password" : "设置一个密码",
-    "Password" : "密码",
+    "People" : "用户",
+    "Filter accounts" : "筛选账号",
     "The request will expire on {date} at midnight and will be password protected." : "请求将于{date}凌晨过期，并将受到密码保护。",
     "The request will expire on {date} at midnight." : "请求将于{date}凌晨过期。",
     "The request will be password protected." : "请求将受到密码保护。",
-    "Share link" : "共享链接",
-    "Copy to clipboard" : "复制到剪贴板",
-    "Send link via email" : "通过邮件发送链接",
-    "Enter an email address or paste a list" : "输入电子邮箱地址或粘贴一个清单",
-    "Remove email" : "移除电子邮箱",
+    "When should the request expire?" : "请求何时到期？",
+    "Set a submission expiration date" : "设置提交过期日期",
+    "Expiration date" : "过期日期 ",
+    "Select a date" : "选择一个日期",
+    "Your administrator has enforced a {count} days expiration policy." : "管理员已强制执行 {count} 天过期策略。",
+    "What password should be used for the request?" : "请求应使用什么密码？",
+    "Set a password" : "设置一个密码",
+    "Password" : "密码",
+    "Enter a valid password" : "请输入有效密码",
+    "Generate a new password" : "生成新密码",
+    "Your administrator has enforced a password protection." : "您的管理员已强制实施密码保护。",
+    "Automatically copying failed, please copy the share link manually" : "自动复制失败，请手动复制共享链接",
     "Link copied to clipboard" : "链接已复制到剪贴板",
     "Email already added" : "电子邮箱已添加",
     "Invalid email address" : "无效电子邮箱地址",
-    "_1 email address already added_::_{count} email addresses already added_" : ["{count}个电子邮箱地址已添加"],
-    "_1 email address added_::_{count} email addresses added_" : ["{count}电子邮箱地址已添加"],
+    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["以下电子邮箱地址无效：{emails}"],
+    "_{count} email address already added_::_{count} email addresses already added_" : ["已添加 {count} 个电子邮件地址"],
+    "_{count} email address added_::_{count} email addresses added_" : ["已添加 {count} 个电子邮件地址"],
+    "You can now share the link below to allow people to upload files to your directory." : "现在，你可以分享下面的链接，允许人们将文件上传到你的目录。",
+    "Share link" : "共享链接",
+    "Copy to clipboard" : "复制到剪贴板",
+    "Send link via email" : "通过邮件发送链接",
+    "Enter an email address or paste a list" : "输入电子邮箱地址或粘贴一个列表",
+    "Remove email" : "移除电子邮箱",
+    "Select a destination" : "选择目标",
+    "Select" : "选择",
     "What are you requesting?" : "你正在请求什么？",
     "Request subject" : "请求主题",
+    "Birthday party photos, History assignment…" : "生日聚会照片，历史作业…",
+    "Where should these files go?" : "这些文件应该放在哪里？",
+    "Upload destination" : "上传目标",
+    "Revert to default" : "恢复默认值",
+    "The uploaded files are visible only to you unless you choose to share them." : "上传的文件仅对您可见，除非您选择共享它们。",
+    "Add a note" : "添加备注",
+    "Note for recipient" : "接收者的备注",
     "Add a note to help people understand what you are requesting." : "添加备注以帮助他人了解你的请求。",
     "You can add links, date or any other information that will help the recipient understand what you are requesting." : "你可以添加链接、日期或任何其他信息，以帮助收件人了解你的请求。",
-    "Select" : "选择",
-    "Create a file request" : "创建文件请求",
-    "File request created" : "创建了文件请求",
-    "File request" : "文件请求",
-    "Cancel" : "取消",
-    "Cancel the file request creation" : "取消文件请求创建",
-    "Close without sending emails" : "关闭而不发送电子邮件",
     "Close" : "关闭",
-    "Continue" : "继续",
+    "_Send email and close_::_Send {count} emails and close_" : ["发送{count}封电子邮件并关闭"],
+    "Please select a folder, you cannot share the root directory." : "请选择文件夹，您无法分享根目录。",
+    "File request created" : "创建了文件请求",
+    "_File request created and email sent_::_File request created and {count} emails sent_" : ["文件请求已创建，{count}封电子邮件已发送"],
     "Error creating the share: {errorMessage}" : "创建共享失败：{errorMessage}",
     "Error creating the share" : "创建共享时出错",
     "Error sending emails: {errorMessage}" : "发送电子邮件时出错：{errorMessage}",
     "Error sending emails" : "发送电子邮件出错",
-    "_Send email and close_::_Send {count} emails and close_" : ["发送{count}封电子邮件并关闭"],
-    "_File request created and email sent_::_File request created and {count} emails sent_" : ["文件请求已创建，{count}封电子邮件已发送"],
-    "Accept shares from other accounts and groups by default" : "默认允许其他账户和群组的分享",
+    "Create a file request" : "创建文件请求",
+    "Collect files from others even if they do not have an account." : "即使对方没有账号，也可以收集文件。",
+    "To ensure you can receive files, verify you have enough storage available." : "为确保您可以接收文件，请验证您是否有足够的可用存储空间。",
+    "File request" : "文件请求",
+    "Previous step" : "上一步",
+    "Cancel" : "取消",
+    "Cancel the file request creation" : "取消文件请求创建",
+    "Close without sending emails" : "关闭而不发送电子邮件",
+    "Continue" : "继续",
     "Error while toggling options" : "切换选项时出错",
-    "Set default folder for accepted shares" : "设置已接受共享的默认文件夹",
-    "Reset" : "重置",
-    "Reset folder to system default" : "重置文件夹为系统默认值",
+    "Accept shares from other accounts and groups by default" : "默认接受其他账号和群组的分享",
     "Choose a default folder for accepted shares" : "为已接受的共享选择一个默认文件夹",
     "Invalid path selected" : "所选路径无效",
     "Unknown error" : "未知错误",
-    "Open Sharing Details" : "打开分享详细信息",
+    "Set default folder for accepted shares" : "设置已接受共享的默认文件夹",
+    "Reset" : "重置",
+    "Reset folder to system default" : "重置文件夹为系统默认值",
+    "Share expiration: " : "共享有效期‌：",
+    "Share Expiration" : "共享有效期‌",
     "group" : "分组",
     "conversation" : "会话",
     "remote" : "远程",
     "remote group" : "远程分组",
     "guest" : "访客",
+    "by {initiator}" : "由 {initiator}",
     "Shared with the group {user} by {owner}" : "{owner} 共享给分组 {user}",
     "Shared with the conversation {user} by {owner}" : "由{owner}共享给会话{user}",
     "Shared with {user} by {owner}" : "{owner} 共享给 {user}",
+    "Open Sharing Details" : "打开分享详细信息",
     "Added by {initiator}" : "由 {initiator} 添加",
     "Via “{folder}”" : "通过“{folder}”",
     "Unshare" : "取消共享",
-    "Internal link" : "内部链接",
     "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
     "Copy internal link to clipboard" : "复制内部链接到剪贴板",
     "Only works for people with access to this folder" : "仅适用于可以访问该文件夹的用户",
     "Only works for people with access to this file" : "仅适用于可以访问该文件的用户",
     "Link copied" : "已复制链接",
-    "Please enter the following required information before creating the share" : "请在创建共享前输入以下必填信息",
-    "Password protection (enforced)" : "密码保护（强制）",
-    "Password protection" : "密码保护",
-    "Enter a password" : "输入密码",
-    "Expiration date (enforced)" : "过期日期（强制）",
-    "Create share" : "创建共享",
-    "Customize link" : "自定义链接",
-    "Generate QR code" : "生成二维码",
-    "Add another link" : "添加其他链接",
-    "Create a new share link" : "创建新的共享链接",
+    "Internal link" : "内部链接",
     "{shareWith} by {initiator}" : "由 {initiator} 通过 {shareWith} 共享",
     "Shared via link by {initiator}" : "由 {initiator} 通过链接共享",
     "File request ({label})" : "文件请求 ({label})",
     "Mail share ({label})" : "邮件分享（{label}）",
     "Share link ({label})" : "分享链接（{label}）",
+    "Mail share" : "邮件分享",
     "Share link ({index})" : "分享链接（{index}）",
+    "Create public link" : "生成公开链接地址",
     "Actions for \"{title}\"" : "“{title}”的动作",
     "Copy public link of \"{title}\" to clipboard" : "将“{title}”的公开链接复制到剪贴板",
     "Error, please enter proper password and/or expiration date" : "错误，请输入正确的密码和/或过期日期",
     "Link share created" : "已创建链接分享",
     "Error while creating the share" : "创建共享时出错",
+    "Please enter the following required information before creating the share" : "请在创建共享前输入以下必填信息",
+    "Password protection (enforced)" : "密码保护（强制）",
+    "Password protection" : "密码保护",
+    "Enter a password" : "输入密码",
+    "Enable link expiration (enforced)" : "启用链接过期（强制）",
+    "Enable link expiration" : "启用链接过期",
+    "Enter expiration date (enforced)" : "输入过期日期（强制）",
+    "Enter expiration date" : "输入过期日期",
+    "Create share" : "创建共享",
+    "Customize link" : "自定义链接",
+    "Generate QR code" : "生成二维码",
+    "Add another link" : "添加其他链接",
+    "Create a new share link" : "创建新的共享链接",
     "Quick share options, the current selected is \"{selectedOption}\"" : "快速分享选项，当前选择为 “{selectedOption}”",
     "View only" : "仅查看",
     "Can edit" : "可以编辑",
     "Custom permissions" : "自定义权限",
-    "Search for share recipients" : "查找共享参与者",
-    "No recommendations. Start typing." : "没有建议。开始输入。",
-    "Resharing is not allowed" : "不允许二次共享",
+    "Resharing is not allowed" : "不允许再次共享",
     "Name or email …" : "姓名或电子邮件 ...",
     "Name, email, or Federated Cloud ID …" : "名称、电子邮件或联合云 ID ...",
     "Searching …" : "正在搜索 ...",
@@ -206,28 +250,21 @@ OC.L10N.register(
     "Deck board" : "看板",
     "ScienceMesh" : "ScienceMesh",
     "on {server}" : "在 {server} 上",
+    "Enter external recipients" : "输入外部接收者",
+    "Search for internal recipients" : "搜索内部接收者",
+    "Note from" : "备注来自",
+    "Note:" : "备注：",
     "File drop" : "文件拖放",
+    "Upload files to {foldername}." : "将文件上传到 {foldername}。",
+    "By uploading files, you agree to the terms of service." : "上传文件即表示您同意服务条款。",
+    "View terms of service" : "查看服务条款",
     "Terms of service" : "服务条款",
+    "Upload files to {folder}" : "将文件上传到 {folder}",
     "Submit name" : "提交名称",
-    "Allow upload and editing" : "允许上传和编辑",
-    "Allow editing" : "允许编辑",
-    "Upload only" : "仅上传",
-    "Advanced settings" : "高级选项",
-    "Share label" : "分享标签",
-    "Set password" : "设置密码",
-    "Password expires {passwordExpirationTime}" : "密码于 {passwordExpirationTime} 过期",
-    "Password expired" : "密码已过期",
-    "Video verification" : "视频验证",
-    "Set expiration date" : "设置过期日期",
-    "Hide download" : "隐藏下载",
-    "Note to recipient" : "接收人备注",
-    "Enter a note for the share recipient" : "给共享接收人留备注",
-    "Read" : "读取",
-    "Create" : "创建",
-    "Edit" : "编辑",
-    "Share" : "共享",
-    "Delete" : "删除",
-    "Delete share" : "删除共享",
+    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} 与您分享了一个文件夹。",
+    "To upload files, you need to provide your name first." : "要上传文件，您需要先提供名称。",
+    "Name" : "名称",
+    "Enter your name" : "输入你的名字",
     "Share with {userName}" : "分享至 {userName}",
     "Share with email {email}" : "与邮箱 {email} 分享",
     "Share with group" : "分享至群组",
@@ -237,17 +274,58 @@ OC.L10N.register(
     "Share with guest" : "分享至访客",
     "Update share" : "更新分享",
     "Save share" : "保存分享",
+    "Read" : "读取",
+    "Create" : "创建",
+    "Edit" : "编辑",
+    "Share" : "共享",
+    "Delete" : "删除",
+    "Password field cannot be empty" : "密码字段不能为空",
+    "Replace current password" : "替换当前密码",
+    "Failed to generate a new token" : "无法生成新令牌",
+    "Allow upload and editing" : "允许上传和编辑",
+    "Allow editing" : "允许编辑",
+    "Upload only" : "仅上传",
+    "Advanced settings" : "高级选项",
+    "Share label" : "共享标签",
+    "Share link token" : "共享链接令牌",
+    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "将公开共享链接令牌设置为易于记忆的令牌或生成新令牌。不建议对包含敏感信息的共享使用可猜测的令牌。",
+    "Generating…" : "正在生成…",
+    "Generate new token" : "生成新令牌",
+    "Set password" : "设置密码",
+    "Password expires {passwordExpirationTime}" : "密码于 {passwordExpirationTime} 过期",
+    "Password expired" : "密码已过期",
+    "Video verification" : "视频验证",
+    "Expiration date (enforced)" : "过期日期（强制）",
+    "Set expiration date" : "设置过期日期",
+    "Hide download" : "隐藏下载",
+    "Allow download and sync" : "允许下载和同步",
+    "Note to recipient" : "接收者备注",
+    "Enter a note for the share recipient" : "为共享接收者输入备注",
+    "Show files in grid view" : "在网格视图中显示文件",
+    "Delete share" : "删除共享",
     "Others with access" : "其他具有访问权限的人",
     "No other accounts with access found" : "未找到其他拥有访问权限的账号",
     "Toggle list of others with access to this directory" : "切换有权访问此目录的其他人的列表",
     "Toggle list of others with access to this file" : "切换有权访问此文件的其他人的列表",
     "Unable to fetch inherited shares" : "无法获取继承的共享",
+    "Link shares" : "链接共享",
     "Shares" : "共享",
+    "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access." : "使用此方法与组织内的个人或团队共享文件。如果接收者已经可以访问共享，但找不到它，您可以向他们发送内部共享链接以便于访问。",
+    "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID." : "使用此方法与组织外部的个人或组织共享文件。文件和文件夹可以通过公开共享链接和电子邮件地址共享。您还可以使用其联合云 ID 共享给托管在不同实例上的其他 Nextcloud 账号。",
+    "Shares that are not part of the internal or external shares. This can be shares from apps or other sources." : "不属于内部或外部共享的共享，这可以是来自应用或其他来源的共享。",
+    "Share with accounts, teams, federated cloud IDs" : "与账号、团队、联合云 ID 共享",
+    "Share with accounts and teams" : "与账号和团队共享",
+    "Email, federated cloud ID" : "电子邮件、联合云 ID",
     "Unable to load the shares list" : "无法加载共享列表",
     "Expires {relativetime}" : "过期 {relativetime}",
     "this share just expired." : "此共享已过期。",
     "Shared with you by {owner}" : "{owner} 与您共享",
-    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["以下电子邮箱地址无效：{emails}"],
+    "Internal shares" : "内部共享",
+    "Internal shares explanation" : "内部共享说明",
+    "External shares" : "外部共享",
+    "External shares explanation" : "外部共享说明",
+    "Additional shares" : "额外共享",
+    "Additional shares explanation" : "额外共享说明",
     "Link to a file" : "链接到文件",
     "_Accept share_::_Accept shares_" : ["接受共享"],
     "Open in Files" : "在文件中打开",
@@ -257,14 +335,22 @@ OC.L10N.register(
     "Shared by {ownerDisplayName}" : "由 {ownerDisplayName} 分享",
     "Shared multiple times with different people" : "与不同的用户多次分享",
     "Show sharing options" : "显示共享选项",
-    "Shared with others" : "您共享的文件",
+    "Shared with others" : "你的共享",
     "Create file request" : "创建文件请求",
+    "Upload files to {foldername}" : "将文件上传到 {foldername}",
+    "Public file share" : "公开文件共享",
+    "Publicly shared file." : "公开共享的文件。",
+    "No file" : "无文件",
+    "The file shared with you will show up here" : "与您共享的文件将显示在此处",
     "Public share" : "公开共享",
+    "Publicly shared files." : "公开共享的文件。",
+    "No files" : "没有文件",
+    "Files and folders shared with you will show up here" : "与您共享的文件和文件夹将显示在此处",
     "Overview of shared files." : "已分享文件的概览",
     "No shares" : "没有共享",
-    "Files and folders you shared or have been shared with you will show up here" : "您共享或已与您共享的文件与文件夹将显示在此处",
-    "Shared with you" : "共享给您的",
-    "List of files that are shared with you." : "与您共享的文件列表",
+    "Files and folders you shared or have been shared with you will show up here" : "你的共享或已与你共享的文件与文件夹将显示在此处",
+    "Shared with you" : "与你共享",
+    "List of files that are shared with you." : "与你共享的文件列表",
     "Nothing shared with you yet" : "您还没有收到任何共享的文件",
     "Files and folders others shared with you will show up here" : "其他人与您分享的文件与文件夹将显示在此处",
     "List of files that you shared with others." : "你与其他人分享的文件列表。",
@@ -273,14 +359,14 @@ OC.L10N.register(
     "Shared by link" : "通过链接共享",
     "List of files that are shared by link." : "存在分享链接的文件列表",
     "No shared links" : "无共享链接",
-    "Files and folders you shared by link will show up here" : "此处会显示您使用链接分享的文件和文件夹",
+    "Files and folders you shared by link will show up here" : "你通过链接共享的文件和文件夹将显示在此处",
     "File requests" : "文件请求",
     "List of file requests." : "文件请求列表",
     "No file requests" : "没有文件请求",
     "File requests you have created will show up here" : "你已创建的文件请求将显示在这里",
     "Deleted shares" : "已删除的共享",
     "List of shares you left." : "您已退出的分享列表",
-    "No deleted shares" : "没有删除的共享",
+    "No deleted shares" : "没有已删除的共享",
     "Shares you have left will show up here" : "此处会显示您退出的分享",
     "Pending shares" : "待定共享",
     "List of unapproved shares." : "未批准的分享列表",
@@ -290,7 +376,14 @@ OC.L10N.register(
     "Error updating the share" : "更新共享时出错",
     "File \"{path}\" has been unshared" : "文件“{path}”已取消共享",
     "Folder \"{path}\" has been unshared" : "文件夹“{path}”已取消共享",
-    "Share {propertyName} saved" : "共享 {propertyName} 已保存",
+    "Could not update share" : "无法更新共享",
+    "Share saved" : "共享已保存",
+    "Share expiry date saved" : "共享过期日期已保存",
+    "Share hide-download state saved" : "共享隐藏已下载的状态已保存",
+    "Share label saved" : "共享标签已保存",
+    "Share note for recipient saved" : "接收者的共享备注已保存",
+    "Share password saved" : "共享密码已保存",
+    "Share permissions saved" : "共享权限已保存",
     "Shared by" : "共享人",
     "Shared with" : "共享给",
     "Password created successfully" : "密码已创建成功",
@@ -303,6 +396,7 @@ OC.L10N.register(
     "Show list view" : "显示列表视图",
     "Show grid view" : "显示网格视图",
     "Upload files to %s" : "上传文件到 %s",
+    "%s shared a folder with you." : "%s 与您分享了一个文件夹。",
     "Note" : "备注",
     "Select or drop files" : "选择或拖放文件",
     "Uploading files" : "正在上传文件",
@@ -321,32 +415,16 @@ OC.L10N.register(
     "Invalid server URL" : "无效的服务器地址",
     "Failed to add the public link to your Nextcloud" : "添加公开链接到您的Nextcloud失败",
     "Files" : "文件",
-    "Please specify a valid user" : "请指定一个有效的用户",
-    "Please specify a valid federated user ID" : "请指定一个有效的联合用户 ID",
-    "You cannot share to a Circle if the app is not enabled" : "如果这个应用程序不可用，您不能共享到圈子",
-    "Please specify a valid circle" : "请指明一个可用圈子",
     "Download all files" : "下载所有文件",
-    "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "这个应用程序允许用户在 Nextcloud 内部共享文件。如果启用，管理员能够选择哪个组可以共享文件。然后，可用的用户能够共享文件和文件夹给 Nextcloud 中的其他用户和组。另外，如果管理员启用了共享链接功能，能够使用外部链接将文件共享给 Nextcloud 之外的其他用户。管理员也可以强制设置密码，过期日期，并且可以通过共享链接启用服务器到服务器的共享，以及从移动设备共享。\n关闭该功能将删除服务器上所有共享接收者以用同步客户端和移动应用上的共享文件和文件夹。更多信息可查阅 Nextcloud 文档。",
-    "Accept user and group shares by default" : "默认接受用户和分组共享",
-    "Read only" : "只读",
-    "File drop (upload only)" : "文件拖放（仅上传）",
-    "Upload" : "上传",
-    "Bundled permissions" : "权限包",
-    "Only works for users with access to this folder" : "仅适用于有权限访问此文件夹的用户",
-    "Only works for users with access to this file" : "仅适用于有权限访问此文件的用户",
-    "Enter a date" : "输入日期",
-    "Circle" : "圈子",
+    "Search for share recipients" : "查找共享参与者",
+    "No recommendations. Start typing." : "无建议。开始输入。",
+    "Password field can't be empty" : "密码字段不能为空",
     "Allow download" : "允许下载",
-    "No other users with access found" : "找不到其他具有访问权限的用户",
-    "No entries found in this folder" : "在此文件夹中找不到项目",
-    "Name" : "名称",
-    "Share time" : "共享时间",
-    "Sorry, this link does not seem to work anymore." : "抱歉，此链接已失效。",
-    "Reasons might be:" : "可能原因是：",
-    "the item was removed" : "此项已移除",
-    "the link expired" : "链接过期",
-    "sharing is disabled" : "已禁用共享",
-    "For more info, please ask the person who sent this link." : "如需了解更多信息，请联系发给您该链接的人。",
-    "Enter your name" : "输入你的名字"
+    "Share expire date saved" : "共享过期日期已保存",
+    "You are not allowed to edit link shares that you don't own" : "不允许编辑不属于您的链接共享",
+    "_1 email address already added_::_{count} email addresses already added_" : ["{count}个电子邮箱地址已添加"],
+    "_1 email address added_::_{count} email addresses added_" : ["{count}电子邮箱地址已添加"],
+    "Share with accounts, teams, federated cloud id" : "与账号、团队、联合云 ID 共享",
+    "Email, federated cloud id" : "电子邮件、联合云 ID"
 },
 "nplurals=1; plural=0;");
