@@ -6,6 +6,7 @@ OC.L10N.register(
     "No file was uploaded" : "No se cargó el archivo",
     "Missing a temporary folder" : "Falta una carpeta temporal",
     "New text file" : "Nuevo archivo de texto",
+    "File not found" : "Archivo no encontrado",
     "Text" : "Texto",
     "Translate" : "Traducir",
     "Reload" : "Volver a cargar",
@@ -14,6 +15,7 @@ OC.L10N.register(
     "Saved" : "Guardado",
     "Unsaved changes" : "Cambios no guardados",
     "Keyboard shortcuts" : "Atajos del teclado",
+    "Link" : "Liga",
     "Action" : "Acción",
     "Undo" : "Deshacer",
     "Save changes" : "Guardar Cambios",
@@ -22,8 +24,11 @@ OC.L10N.register(
     "Select language" : "Seleccionar idioma",
     "to" : "para",
     "Replace" : "Reemplazar",
+    "Upload" : "Cargar",
     "Edit" : "Editar",
     "Source code" : "Código fuente",
+    "Details" : "Detalles",
+    "Choose" : "Seleccionar",
     "Info" : "Info",
     "Success" : "Éxito",
     "Warning" : "Advertencia"
