@@ -10,9 +10,11 @@ OC.L10N.register(
     "Save changes" : "Ännerunge späicheren",
     "URL" : "URL",
     "to" : "bis",
+    "Upload" : "Eroplueden",
     "Edit" : "Änneren",
+    "Details" : "Detailer",
+    "Choose" : "Auswielen",
     "Info" : "Info",
-    "Warning" : "Warnung",
-    "Details" : "Detailer"
+    "Warning" : "Warnung"
 },
 "nplurals=2; plural=(n != 1);");
