@@ -13,8 +13,6 @@ OC.L10N.register(
     "File not found" : "Fișierul nu a fost găsit",
     "Text" : "Text",
     "Translate" : "Tradu",
-    "Use current version" : "Folosește versiunea curentă",
-    "Use the saved version" : "Folosește versiuna salvată",
     "Reload" : "Reîncarcă",
     "Guest" : "Invitat",
     "Remove link" : "Șterge link-ul",
@@ -28,20 +26,28 @@ OC.L10N.register(
     "Link" : "Legătură",
     "Undo" : "Anulează ultima acțiune",
     "Redo" : "Repetă",
+    "Cannot copy, please copy the link manually" : "Nu s-a putut copia, vă rugăm să copiați link-ul manual",
     "Edit link" : "Editare link",
     "Cancel" : "Anulare",
     "URL" : "URL",
-    "Cannot copy, please copy the link manually" : "Nu s-a putut copia, vă rugăm să copiați link-ul manual",
     "Formatting help" : "Ajutor pentru formatare",
-    "Select file or folder to link to" : "Selectați fișierul sau folderul țintă a link-ului",
     "to" : "către",
     "Replace" : "Înlocuiește",
+    "Upload" : "Încărcare",
     "Edit" : "Editează",
     "Source code" : "Cod sursă",
+    "Done" : "Realizat",
+    "Lists" : "Liste",
+    "Details" : "Detalii",
+    "Formatting" : "Formatare",
+    "Select file or folder to link to" : "Selectați fișierul sau folderul țintă a link-ului",
+    "Choose" : "Alege",
+    "Choose {file}" : "Selectați {file}",
+    "Add folder description" : "Adăugați descrierea directorului",
+    "Use current version" : "Folosește versiunea curentă",
+    "Use the saved version" : "Folosește versiuna salvată",
     "Info" : "Info",
     "Success" : "Succes",
-    "Warning" : "Atenție",
-    "Details" : "Detalii",
-    "Formatting" : "Formatare"
+    "Warning" : "Atenție"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
