@@ -22,21 +22,22 @@ OC.L10N.register(
     "Text" : "文本 ",
     "📝 Collaborative document editing" : "文档协作编辑",
     "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 协作式的文档编辑！**\n\n- **📝 专注的写作：** 无干扰，只有您需要的格式化。\n- **🙋 一起工作：** 与朋友和同事共享协作，无论他们是否使用Nextcloud！\n- **💾 开放标准：** 文件将保存为 [Markdown](https://en.wikipedia.org/wiki/Markdown)，所以您也可以使用任何其他文本应用。\n- **✊ 雄厚基础：** 我们使用 [🐈 tiptap](https://tiptap.scrumpy.io) ，它基于 [🦉 ProseMirror](https://prosemirror.net) – 非常感谢它们！",
+    "Insert result" : "插入结果",
+    "Nextcloud Assistant result copied" : "已复制 Nextcloud 助手结果",
+    "Could not copy result to clipboard" : "无法复制结果至剪切板",
     "Nextcloud Assistant" : "Nextcloud助手",
     "Translate" : "翻译",
     "Show assistant results" : "显示助手结果",
-    "Insert result" : "插入结果",
+    "Assistant results" : "助手结果",
     "Show result" : "显示结果",
     "Delete task" : "删除任务",
-    "Nextcloud Assistant result copied" : "已复制 Nextcloud 助手结果",
-    "Could not copy result to clipboard" : "无法复制结果至剪切板",
-    "Use current version" : "使用当前版本",
-    "Use the saved version" : "使用保存的版本",
+    "Overwrite the file and save the current changes" : "覆盖文件并保存当前更改",
+    "Discard the current changes and load the latest version" : "放弃当前更改并加载最新版本",
     "Reload" : "重载",
-    "Document has been changed outside of the editor. The changes cannot be applied" : "文档已在编辑器外被更改。无法应用更改。",
-    "Document could not be loaded. Please check your internet connection." : "文档无法被加载。请检查你的网络连接。",
+    "The file was overwritten. Your current changes cannot be auto-saved. Please choose how to proceed." : "文件已被覆盖。无法自动保存您当前的更改。请选择如何继续。",
+    "The document could not be loaded. Please check your internet connection." : "无法加载文档。请检查您的互联网连接。",
     "Reconnect" : "重新连接",
-    "Document idle for {timeout} minutes, click to continue editing" : "文档已闲置 {timeout} 分钟，点击以继续编辑",
+    "You've been disconnected from the server." : "您已与服务器断开连接。",
     "This file is opened read-only as it is currently locked by {user}." : "该文件以仅读模式打开，其正被用户 {user} 锁定。",
     "Close outline view" : "关闭大纲视图",
     "Outline" : "大纲",
@@ -44,15 +45,21 @@ OC.L10N.register(
     "Edit guest name" : "编辑访客姓名",
     "Guest" : "访客",
     "Save guest name" : "保存访客姓名",
-    "Insert an attachment" : "插入一个附件",
+    "Uploading multiple attachments failed." : "上传多个附件失败。",
+    "Uploading attachment failed: {error}" : "上传附件失败：{error}",
+    "Uploading attachment failed." : "上传附件失败。",
+    "Insert an attachment" : "插入附件",
+    "Failed to insert from Files" : "无法从文件插入",
+    "Failed to create attachment" : "无法创建附件",
     "Preview options" : "预览选项",
     "Text only" : "仅文字",
     "Show link preview" : "显示链接预览",
+    "Open in new tab" : "在新标签页中打开",
     "Remove link" : "删除链接",
-    "guest" : "访客",
     "Active people" : "活动用户",
-    "Save document" : "保存文档",
-    "Last saved" : "最近保存",
+    "guest" : "访客",
+    "Full width editor" : "全宽编辑器",
+    "Open the Smart Picker" : "打开智能选择器",
     "Offline" : "离线",
     "Offline, changes will be saved when online" : "离线，更改将会在上线后保存",
     "Saving …" : "保存中 …",
@@ -60,7 +67,8 @@ OC.L10N.register(
     "Last saved {lastSave}" : "最近保存 {lastSave}",
     "The document has been changed outside of the editor. The changes cannot be applied." : "本文档在编辑器外被更改。无法应用更改。",
     "Unsaved changes" : "未保存的更改",
-    "Connection failed." : "连接失败。",
+    "Save document" : "保存文档",
+    "Last saved" : "最近保存",
     "Formatting and shortcuts" : "排版和捷径",
     "Speed up your writing with simple shortcuts." : "利用简单快捷键加速写作",
     "Just type the Markdown syntax or use keyboard shortcuts from below." : "只需输入 markdown 语法或从下面使用键盘快捷键。",
@@ -76,7 +84,6 @@ OC.L10N.register(
     "Shift" : "Shift",
     "Bold" : "加粗",
     "Bold text" : "粗文本",
-    "Ctrl" : "Ctrl",
     "Italic" : "斜体",
     "Italicized text" : "斜文本",
     "Strikethrough" : "删除线",
@@ -102,33 +109,34 @@ OC.L10N.register(
     "emoji" : "表情符号",
     "Mention someone" : "提及某人",
     "name" : "名称",
-    "Smart picker" : "Smart Picker",
+    "Smart picker" : "智能选择器",
     "something" : "某些东西",
     "Action" : "操作",
     "Undo" : "撤销",
     "Redo" : "重做",
     "Toggle outline" : "切换大纲",
     "Alt" : "Alt",
+    "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
+    "Copy link to clipboard" : "复制链接到剪贴板",
     "Edit link" : "编辑链接",
     "Save changes" : "保存更改",
     "Cancel" : "取消",
     "URL" : "URL",
-    "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
-    "Copy link to clipboard" : "复制链接到剪贴板",
+    "Attachments cannot be created or uploaded because this file is shared from another cloud." : "无法创建或上传附件，因为此文件是从另一个云共享的。",
     "Upload from computer" : "从电脑上传",
     "Insert from Files" : "从文件插入",
     "Formatting help" : "排版帮助",
     "Link to file or folder" : "链接至文件或文件夹",
     "Link to website" : "链接至网站",
     "Update link" : "更新链接",
-    "Open the Smart Picker" : "打开智能选择器",
-    "Select file or folder to link to" : "选择需要链接的文件或文件夹",
-    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\" 已选择",
     "_%n word_::_%n words_" : ["%n 字"],
     "_%n char_::_%n chars_" : ["%n 字符"],
+    "Remaining actions" : "重命名操作",
     "Editor actions" : "编辑器操作",
     "Formatting menu bar" : "格式化菜单栏",
-    "Remaining actions" : "重命名操作",
+    "Translate from {language}" : "翻译自 {language}",
+    "Translate to {language}" : "翻译至 {language}",
+    "Translation failed" : "翻译失败",
     "To translate individual parts of the text, select it before using the translate function." : "如果你需要翻译部分文字内容，请在使用翻译功能前选中该部分文字",
     "Translate from" : "翻译至",
     "Select language" : "请选择语言",
@@ -138,14 +146,14 @@ OC.L10N.register(
     "Translated text result" : "文字翻译结果",
     "Replace" : "替换",
     "Insert" : "插入",
-    "Detect language" : "检测语言",
-    "Translate from {language}" : "翻译自 {language}",
-    "Translate to {language}" : "翻译至 {language}",
-    "Translation failed" : "翻译失败",
     "No emoji found" : "找不到任何表情",
     "No command found" : "找不到任何命令",
     "No user found" : "找不到任何用户",
     "No suggestion found" : "找不到任何建议",
+    "Uploading attachments is disabled because the file is shared from another cloud." : "上传附件被禁用，因为该文件是从另一个云共享的。",
+    "Upload" : "上传",
+    "Insert Table" : "插入表格",
+    "Smart Picker" : "智能选择器",
     "Edit" : "编辑",
     "Copy code block" : "复制代码块",
     "Copy code" : "复制代码",
@@ -156,10 +164,10 @@ OC.L10N.register(
     "Diagram" : "图标",
     "Both" : "都是",
     "Mermaid documentation" : "Mermaid 文档",
-    "Delete this attachment" : "删除该附件",
-    "Delete this image" : "删除该图片",
     "Failed to load" : "加载失败",
     "Could not find image in attachments list." : "在附件列表内无法找到任何图片。",
+    "Delete this attachment" : "删除该附件",
+    "Delete this image" : "删除该图片",
     "Add row before" : "在之前新增行",
     "Add row after" : "在之后新增行",
     "Delete this row" : "删除该行",
@@ -170,9 +178,11 @@ OC.L10N.register(
     "Add column after" : "在之后新增列",
     "Delete this column" : "删除该列",
     "Delete this table" : "删除该表格",
+    "Add row below" : "在下方添加行",
     "Show folder description" : "显示文件夹描述",
     "Hide outline" : "隐藏大纲",
     "Show outline" : "显示大纲",
+    "Done" : "完成",
     "Headings" : "标题",
     "Heading 2" : "标题 2",
     "Heading 3" : "标题 3",
@@ -180,15 +190,24 @@ OC.L10N.register(
     "Heading 5" : "标题 5",
     "Lists" : "列表",
     "To-Do list" : "代办事项",
+    "Increase indentation" : "增加缩进",
+    "Decrease indentation" : "减少缩进",
+    "Blocks" : "区块",
+    "Info callout" : "信息标注",
+    "Success callout" : "成功标注",
+    "Warning callout" : "警告标注",
+    "Danger callout" : "危险标注",
     "Table" : "表格",
     "Details" : "详情",
     "Insert link" : "插入链接",
     "Insert attachment" : "插入附件",
     "Command" : "命令",
-    "Control" : "控制",
+    "Ctrl" : "Ctrl",
     "Option" : "选项",
     "Formatting" : "格式",
-    "Start writing, or try '/' to add, '@' to mention…" : "开始写作，或尝试用 “/” 添加，用 “@” 提及…",
+    "Select file or folder to link to" : "选择需要链接的文件或文件夹",
+    "Choose" : "选择",
+    "Choose {file}" : "选择 {file}",
     "Add folder description" : "添加文件夹描述",
     "\"{name}\" already exist!" : "\"{name}\" 已存在！",
     "Created \"{name}\"" : "创建 \"{name}\"",
@@ -196,14 +215,22 @@ OC.L10N.register(
     "Could not copy to the clipboard" : "无法复制到剪切板",
     "Front matter" : "前言",
     "Link to this section" : "链接至本节",
+    "Use current version" : "使用当前版本",
+    "Use the saved version" : "使用保存的版本",
+    "Document has been changed outside of the editor. The changes cannot be applied" : "文档已在编辑器外被更改。无法应用更改。",
+    "Document could not be loaded. Please check your internet connection." : "文档无法被加载。请检查你的网络连接。",
+    "Document idle for {timeout} minutes, click to continue editing" : "文档已闲置 {timeout} 分钟，点击以继续编辑",
     "Show author colors" : "显示作者颜色",
     "Author colors are only shown until everyone has closed the document." : "直到所有人都关闭了文档，才会显示作者颜色。",
-    "Callouts" : "标记",
+    "Connection failed." : "连接失败。",
+    "Detect language" : "检测语言",
+    "Callouts" : "标注",
     "Info" : "信息",
     "Success" : "成功",
     "Warning" : "警告",
     "Danger" : "重要",
+    "Control" : "控制",
     "Add notes, lists or links …" : "添加笔记、列表或链接...",
-    "Add description" : "添加描述"
+    "Start writing, or try '/' to add, '@' to mention…" : "开始写作，或尝试用 “/” 添加，用 “@” 提及…"
 },
 "nplurals=1; plural=0;");
