@@ -89,7 +89,7 @@ OC.L10N.register(
     "new" : "novedá",
     "_download %n file_::_download %n files_" : ["baxar %n ficheru","baxar %n ficheros"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "L'anovamientu ta en cursu. Ye posible qu'al colar d'esta páxina s'interrumpa'l procesu en dalgunos entornos.",
-    "Update to {version}" : "Anovar a la versión {versión}",
+    "Update to {version}" : "Anovar a la versión {version}",
     "An error occurred." : "Prodúxose un error.",
     "Please reload the page." : "Volvi cargar la páxina.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "L'anovamientu nun foi correutu. Pa consiguir más información, <a href=\"{url}\">comprueba l'artículu del foru</a> que cubre esti problema.",
@@ -102,62 +102,64 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} avisu","{count} avisos"],
     "No" : "Non",
     "Yes" : "Sí",
+    "Failed to add the public link to your Nextcloud" : "Nun se pue amestar l'enllaz públicu a esta instancia de Nextcloud",
     "Federated user" : "Usuariu federáu",
     "Create share" : "Crear l'elementu compartíu",
-    "Failed to add the public link to your Nextcloud" : "Nun se pue amestar l'enllaz públicu a esta instancia de Nextcloud",
     "Custom date range" : "Intervalu de dates personalizáu",
     "Pick start date" : "Escoyer la data de comienzu",
     "Pick end date" : "Escoyer la data de fin",
     "Search in date range" : "Buscar nun intervalu de dates",
-    "Unified search" : "Busca unificada",
-    "Search apps, files, tags, messages" : "Buscar aplicaciones, ficheros, etiquetes, mensaxes",
-    "Places" : "Llugares",
-    "Date" : "Data",
+    "Searching …" : "Buscando…",
+    "Start typing to search" : "Comienza a escribir pa buscar",
+    "No matching results" : "Nun hai nengún resultáu que concasare",
     "Today" : "Güei",
     "Last 7 days" : "Los últimos 7 díes",
     "Last 30 days" : "Los últimos 30 díes",
     "This year" : "Esti añu",
     "Last year" : "L'añu pasáu",
+    "Unified search" : "Busca unificada",
+    "Search apps, files, tags, messages" : "Buscar aplicaciones, ficheros, etiquetes, mensaxes",
+    "Places" : "Llugares",
+    "Date" : "Data",
     "Search people" : "Buscar persones",
     "People" : "Persones",
     "Filter in current view" : "Peñerar na vista actual",
     "Results" : "Resultaos",
     "Load more results" : "Cargar más resultaos",
     "Search in" : "Buscar en",
-    "Searching …" : "Buscando…",
-    "Start typing to search" : "Comienza a escribir pa buscar",
-    "No matching results" : "Nun hai nengún resultáu que concasare",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Ente'l ${this.dateFilter.startFrom.toLocaleDateString()} y ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Aniciar la sesión",
     "Logging in …" : "Aniciando la sesión…",
-    "Server side authentication failed!" : "¡L'autenticación de llau del sirvidor falló!",
-    "Please contact your administrator." : "Ponte en contautu cola alministración.",
-    "Temporary error" : "Error temporal",
-    "Please try again." : "Volvi tentalo.",
-    "An internal error occurred." : "Prodúxose un error internu.",
-    "Please try again or contact your administrator." : "Volvi tentalo o ponte en contautu cola alministración.",
-    "Password" : "Contraseña",
     "Log in to {productName}" : "Aniciar la sesión en: {productName}",
     "Wrong login or password." : "El nomatu o la contraseña nun son correutos.",
     "This account is disabled" : "Esta cuenta ta desactivada",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dende la to IP, detectemos múltiples intentos d'aniciar la sesión que son inválidos. Poro, el próximu aniciu de la sesión va tardar 30 segundos.",
-    "Account name or email" : "Nome de la cuenta o direición de corréu electrónicu",
+    "Account name or email" : "Nome o direición de corréu de la cuenta",
+    "Server side authentication failed!" : "¡L'autenticación de llau del sirvidor falló!",
+    "Please contact your administrator." : "Ponte en contautu cola alministración.",
+    "An internal error occurred." : "Prodúxose un error internu.",
+    "Please try again or contact your administrator." : "Volvi tentalo o ponte en contautu cola alministración.",
+    "Password" : "Contraseña",
     "Log in with a device" : "Aniciar la sesión con un preséu",
     "Login or email" : "Cuenta o direición de corréu electrónicu",
     "Your account is not setup for passwordless login." : "La cuenta nun ta configurada p'aniciar la sesión ensin contraseñes.",
-    "Browser not supported" : "El restolador nun ye compatible",
-    "Passwordless authentication is not supported in your browser." : "El restolador nun ye compatible cola autenticación ensin contraseñes.",
     "Your connection is not secure" : "La conexón nun ye segura",
     "Passwordless authentication is only available over a secure connection." : "L'autenticación ensin contraseñes namás ta disponible per una conexón segura",
+    "Browser not supported" : "El restolador nun ye compatible",
+    "Passwordless authentication is not supported in your browser." : "El restolador nun ye compatible cola autenticación ensin contraseñes.",
     "Reset password" : "Reaniciu de la contraseña",
+    "Back to login" : "Volver al aniciu de la sesión",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Si esta cuenta esiste, unvióse un mensaxe pa reaniciar la contraseña a esta cuenta. Si nun recibiesti nengún, verifica la direición o la cuenta, comprueba la carpeta de spam o pidi ayuda a l'alministración.",
     "Couldn't send reset email. Please contact your administrator." : "Nun se pudo unviar el mensaxe de reaniciu. Ponte en contautu cola alministración.",
     "Password cannot be changed. Please contact your administrator." : "Nun se pue camudar la contraseña. Ponte en contautu cola alministración.",
-    "Back to login" : "Volver al aniciu de la sesión",
     "New password" : "Contraseña nueva",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Los ficheros tán cifraos. Nun va haber forma de recuperalos dempués de reafitar la contraseña. Si nun sabes qué facer, ponte en contautu cola alministración enantes de siguir. ¿De xuru que quies siguir?",
     "I know what I'm doing" : "Sé lo que faigo",
     "Resetting password" : "Reaniciando la contraseña",
+    "Schedule work & meetings, synced with all your devices." : "Planifica'l trabayu y les reuniones con sincronización colos tos preseos.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Ten a colegues y amigos nun llugar ensin revelar la so información personal",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Una aplicación de corréu electrónicu cenciella que s'integra bien con Ficheros, Contautos y Calendariu.",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos, fueyes de cálculu y presentaciones collaboratives, fechos con Collabora Online.",
+    "Distraction free note taking app." : "Una aplicación pa tomar notes ensin distraiciones.",
     "Recommended apps" : "Aplicaciones aconseyaes",
     "Loading apps …" : "Cargando les aplicaciones…",
     "Could not fetch list of apps from the App Store." : "Nun se pudo dir en cata de la llista d'aplicaciones de la tienda d'aplicaciones",
@@ -167,14 +169,10 @@ OC.L10N.register(
     "Skip" : "Saltar",
     "Installing apps …" : "Instalando les aplicaciones…",
     "Install recommended apps" : "Instalar les aplicaciones aconseyaes",
-    "Schedule work & meetings, synced with all your devices." : "Planifica'l trabayu y les reuniones con sincronización colos tos preseos.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Ten a colegues y amigos nun llugar ensin revelar la so información personal",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Una aplicación de corréu electrónicu cenciella que s'integra bien con Ficheros, Contautos y Calendariu.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Charres, videollamaes, compartición de pantalla, reuniones en llinia y conferencies web; nel restolador y coles aplicaciones móviles.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos, fueyes de cálculu y presentaciones collaboratives, fechos con Collabora Online.",
-    "Distraction free note taking app." : "Una aplicación pa tomar notes ensin distraiciones.",
-    "Settings menu" : "Menú de configuración",
     "Avatar of {displayName}" : "Avatar de: {displayName}",
+    "Settings menu" : "Menú de configuración",
+    "Loading your contacts …" : "Cargando los contautos…",
+    "Looking for {term} …" : "Buscando {term}…",
     "Search contacts" : "Buscar contautos",
     "Reset search" : "Reaniciar la busca",
     "Search contacts …" : "Buscar contautos…",
@@ -182,33 +180,46 @@ OC.L10N.register(
     "No contacts found" : "Nun s'atopó nengun contautu",
     "Show all contacts" : "Amostar tolos contautos",
     "Install the Contacts app" : "Instalar l'aplicación Contautos",
-    "Loading your contacts …" : "Cargando los contautos…",
-    "Looking for {term} …" : "Buscando {term}…",
-    "Search starts once you start typing and results may be reached with the arrow keys" : "La busca comienza namás que comiences a escribir y pues seleicionar los resultaos coles tecles del cursor",
-    "Search for {name} only" : "Buscar «{name}» namás",
-    "Loading more results …" : "Cargando más resultaos…",
     "Search" : "Buscar",
     "No results for {query}" : "Nun hai nengún resultáu pa «{query}»",
     "Press Enter to start searching" : "Primi la tecla «Intro» pa comenzar la busca",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Introduz {minSearchLength} caráuter o más pa buscar","Introduz {minSearchLength} caráuteres o más pa buscar"],
     "An error occurred while searching for {type}" : "Prodúxose un error mentanto se buscaba «{type}»",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "La busca comienza namás que comiences a escribir y pues seleicionar los resultaos coles tecles del cursor",
+    "Search for {name} only" : "Buscar «{name}» namás",
+    "Loading more results …" : "Cargando más resultaos…",
     "Forgot password?" : "¿Escaeciesti la contraseña?",
     "Back to login form" : "Volver al formulariu p'aniciar la sesión",
     "Back" : "Atrás",
     "Login form is disabled." : "El formulariu p'aniciar la sesión ta desactiváu.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulariu p'aniciar la sesión de Nextcloud ta desactiváu. Usa otra opción p'aniciar la sesión si ta disponible o ponte en contautu cola alministración.",
-    "Edit Profile" : "Editar el perfil",
-    "The headline and about sections will show up here" : "Equí apaecen la testera y les seiciones d'información",
-    "You have not added any info yet" : "Nun amestesti nenguna información",
-    "{user} has not added any info yet" : "{user} nun amestó nenguna información",
-    "Error opening the user status modal, try hard refreshing the page" : "Hebo un error al abrir el diálogu modal del estáu d'usuariu, prueba a anovar la páxina",
     "More actions" : "Más aiciones",
+    "Security warning" : "Alvertencia de seguranza",
+    "Storage & database" : "Almacenamientu y base de datos",
+    "Data folder" : "Carpeta de datos",
+    "Install and activate additional PHP modules to choose other database types." : "Instala y activa los módulos PHP adicionales pa escoyer otros tipos de bases de datos.",
+    "For more details check out the documentation." : "Pa consiguir más detalles, revisa la documentación.",
+    "Performance warning" : "Alvertencia tocante al rindimientu",
+    "You chose SQLite as database." : "Escoyesti SQLite como base de datos.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite habría usase namás pa instancies mínimes y de desendolcu. Pa sirvidores en producción aconseyamos usar otru backend de base de datos.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si uses ficheros pa la sincronización de ficheros, l'usu de SQLite nun ye nada aconseyable.",
+    "Database user" : "Usuariu de la base de datos",
+    "Database password" : "Contraseña de la base de datos",
+    "Database name" : "Nome de la base de datos",
+    "Database tablespace" : "Espaciu de tabla de la base de datos",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifica'l númberu de puertu xunto col nome del agospiador (por exemplu, localhost:5432)",
+    "Database host" : "Agospiador de la base de datos",
+    "Installing …" : "Instalando…",
+    "Install" : "Instalar",
+    "Need help?" : "¿Precises ayuda?",
+    "See the documentation" : "Mira la documentación",
+    "{name} version {version} and above" : "{name} versión {version} y superior",
     "This browser is not supported" : "Esti restolador nun ye compatible",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "El restolador nun ye compatible. Anuévalu o instala una versión compatible.",
     "Continue with this unsupported browser" : "SIguir con esti restolador incompatible",
     "Supported versions" : "Versiones compatibles",
-    "{name} version {version} and above" : "{name} versión {version} y superior",
     "Search {types} …" : "Buscar «{types}»…",
-    "Choose {file}" : "Escoyer «{filer}»",
+    "Choose {file}" : "Escoyer «{file}»",
     "Choose" : "Escoyer",
     "Copy to {target}" : "Copiar a {target}",
     "Copy" : "Copiar",
@@ -242,11 +253,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escribi pa buscar proyeutos esistentes",
     "New in" : "Novedá en",
     "View changelog" : "Ver el rexistru de cambeos",
-    "Very weak password" : "La contraseña ye mui poco segura",
-    "Weak password" : "La contraseña ye poco segura",
-    "So-so password" : "La contraseña ye normal",
-    "Good password" : "La contraseña ye segura",
-    "Strong password" : "La contraseña ye mui segura",
     "No action available" : "Nun hai nenguna aición disponible",
     "Error fetching contact actions" : "Hebo un error al dir en cata de les aiciones del contautu",
     "Close \"{dialogTitle}\" dialog" : "Zarrar el diálogu «{dialogTitle}»",
@@ -263,15 +269,12 @@ OC.L10N.register(
     "Admin" : "Alministración",
     "Help" : "Ayuda",
     "Access forbidden" : "Prohíbese l'accesu",
-    "Profile not found" : "Nun s'atopó'l perfil",
-    "The profile does not exist." : "El perfil nun esiste.",
-    "Back to %s" : "Volver a «%s»",
     "Page not found" : "Nun s'atopó la páxina",
     "The page could not be found on the server or you may not be allowed to view it." : "Nun se pudo atopar la páxina nel sirvidor o ye posible que nun tengas permisu pa vela.",
+    "Back to %s" : "Volver a «%s»",
     "Too many requests" : "Milenta solicitúes",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ficiéronse milenta solicitúes dende la to rede. Volvi tentalo dempués o ponte en contautu cola alministración si esti mensaxe ye un error.",
     "Error" : "Error",
-    "Previous" : "Anterior",
     "Internal Server Error" : "Error internu del sirvidor",
     "The server was unable to complete your request." : "El sirividor nun foi a completar la solicitú.",
     "If this happens again, please send the technical details below to the server administrator." : "Si vuelve asoceder, unvia los detalles téunicos d'abaxo a l'alministración del sirvidor.",
@@ -285,32 +288,6 @@ OC.L10N.register(
     "File: %s" : "Ficheru: %s",
     "Line: %s" : "Llinia: %s",
     "Trace" : "Rastru",
-    "Security warning" : "Alvertencia de seguranza",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ye probable que'l to direutoriu de datos y los ficheros seyan accesibles dende internet porque'l ficheru .htaccess nun funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pa consiguir más información tocante a cómo configurar afayadizamente'l sirvidor, mira la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
-    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta pa l'alministración</strong>",
-    "Show password" : "Amosar la contraseña",
-    "Toggle password visibility" : "Alternar la visibilidá de la contraseña",
-    "Storage & database" : "Almacenamientu y base de datos",
-    "Data folder" : "Carpeta de datos",
-    "Configure the database" : "Configurar la base de datos",
-    "Only %s is available." : "Namás hai disponible %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Instala y activa los módulos PHP adicionales pa escoyer otros tipos de bases de datos.",
-    "For more details check out the documentation." : "Pa consiguir más detalles, revisa la documentación.",
-    "Database account" : "Cuenta de la base de datos",
-    "Database password" : "Contraseña de la base de datos",
-    "Database name" : "Nome de la base de datos",
-    "Database tablespace" : "Espaciu de tabla de la base de datos",
-    "Database host" : "Agospiador de la base de datos",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifica'l númberu de puertu xunto col nome del agospiador (por exemplu, localhost:5432)",
-    "Performance warning" : "Alvertencia tocante al rindimientu",
-    "You chose SQLite as database." : "Escoyesti SQLite como base de datos.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite habría usase namás pa instancies mínimes y de desendolcu. Pa sirvidores en producción aconseyamos usar otru backend de base de datos.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si uses ficheros pa la sincronización de ficheros, l'usu de SQLite nun ye nada aconseyable.",
-    "Install" : "Instalar",
-    "Installing …" : "Instalando…",
-    "Need help?" : "¿Precises ayuda?",
-    "See the documentation" : "Mira la documentación",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Paez que tentes de volver instalar Nextcloud. Por embargu, falta'l ficheru «CAN_INSTALL» nel ficheru de configuración. Crealu pa siguir.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nun se pudo quitar el ficheru «CAN_INSTALL» de la carpeta de configuración. Quítalu manualmente.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "L'aplicación rique JavaScript pa funcionar correutamente. {linkstart}Activa JavaScript{linkend} y volvi cargar la páxina.",
@@ -330,6 +307,7 @@ OC.L10N.register(
     "Account connected" : "Cuenta conectada",
     "Your client should now be connected!" : "¡La cuenta habría tar conectada!",
     "You can close this window." : "Pues zarrar esta ventana.",
+    "Previous" : "Anterior",
     "This share is password-protected" : "Esti secrete ta protexíu con una contraseña",
     "The password is wrong or expired. Please try again or request a new one." : "La contraseña ye incorreuta o caducó. Volvi tentalo o solicita una nueva.",
     "Please type in your email address to request a temporary password" : "Escribi la to direición de corréu electrónicu pa solicitar una contraseña temporal",
@@ -368,30 +346,29 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s ta nel mou de caltenimientu y pue talo un tiempu",
     "This page will refresh itself when the instance is available again." : "Esta páxina va anovase sola cuando la instancia vuelva tar disponible.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Ponte en contautu cola alministración del sistema si esti mensaxe sigue apaeciendo o apaez inesperadamente.",
-    "The user limit of this instance is reached." : "Algamóse la llende d'usuarios d'esta instancia.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Introduz la clave de la soscripción n'aplicación de sofitu p'aumentar la llende d'usuarios. Esta aición tamién te concede tolos beneficios que Nextcloud Enterprise ufre, que son mui aconseyables pa compañes.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "El sirividor web nun ta configuráu afayadizamente pa permitir la sincronización de ficheros porque la interfaz WebDAV paez tar estropiada.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "El sirvidor web nun ta configuráu correutamente pa resolver «{url}». Pues atopar más información na {linkstart}documentación ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "El sirvidor web nun se configuró afayadizamente pa resolver «{url}». Ye posible qu'esto tea rellacionao con una configuración del sirvidor que nun s'anovó pa entregar esta carpeta direutamente. Compara'l to ficheru de configuración col forníu, volvi escribir les regles nel ficheru «.htaccess» d'Apache o'l forníu na documentación de Nginx que ta na so {linkstart}páxina de documentación ↗{linkend}. En Nginx, normalmente son les llinies que comiencen per «location ~» son les que precisen un anovamientu.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "El sirvidor web nun ta configuráu afayadizamente pa entregar ficheros .woff2. Esto, polo xeneral, ye un problema cola configuración de Nginx. Pa Nextcloud 15 tamién tienes de facer cambeos pa entregar ficheros .woff2. Compara la configuración de Nginx cola aconseyada na {linkstart}documentación ↗{linkend}",
-    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Ye probable que'l to direutoriu de datos y los ficheros seyan accesibles dende internet. El ficheru .httaccess nun funciona. Ye mui aconseyable que configures el sirvidor web pa que yá nun se pueda acceder al direutoriu de datos o movi los datos del direutoriu fuera del raigañu de documentos del sirvidor web.",
     "Currently open" : "Abierto",
-    "Wrong username or password." : "El nome d'usuariu o la contraseña son incorreutos",
-    "User disabled" : "L'usuariu ta desactiváu",
     "Login with username or email" : "Aniciar la sesión col nomatu o la direición de corréu electrónicu",
     "Login with username" : "Aniciar la sesión col nomatu",
-    "Username or email" : "Nome d'usuariu o direición de corréu electrónicu",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Si esta cuenta esiste, unvióse un mensaxe pa reaniciar la contraseña a la so direición de corréu electrónicu. Si nun recibes nengún, verifica la direición y/o'l nome de la cuenta, comprueba la carpeta Spam o pidi ayuda a l'alministración.",
-    "Apps and Settings" : "Aplicaciones y configuración",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Charres, videollamaes, compartición de pantalla, reuniones en llinia y conferencies web; nel restolador y coles aplicaciones móviles.",
+    "You have not added any info yet" : "Nun amestesti nenguna información",
+    "{user} has not added any info yet" : "{user} nun amestó nenguna información",
+    "Error opening the user status modal, try hard refreshing the page" : "Hebo un error al abrir el diálogu modal del estáu d'usuariu, prueba a anovar la páxina",
+    "Edit Profile" : "Editar el perfil",
+    "The headline and about sections will show up here" : "Equí apaecen la testera y les seiciones d'información",
     "Error loading message template: {error}" : "Hebo un error al cargar la plantía del mensaxe: {error}",
-    "Users" : "Usuarios",
-    "Username" : "Nome d'usuariu",
-    "Database user" : "Usuariu de la base de datos",
-    "This action requires you to confirm your password" : "Esta aición rique que confirmes la contraseña",
-    "Confirm your password" : "Comfirmar la contraseña",
-    "Confirm" : "Confirmar",
-    "App token" : "Pase de l'aplicación",
-    "Alternative log in using app token" : "Aniciu de la sesión alternativu col pase de l'aplicación",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Usa l'anovador de la llinia de comandos porque tienes una instancia grande con más de 50 usuarios."
+    "Very weak password" : "La contraseña ye mui poco segura",
+    "Weak password" : "La contraseña ye poco segura",
+    "So-so password" : "La contraseña ye normal",
+    "Good password" : "La contraseña ye segura",
+    "Strong password" : "La contraseña ye mui segura",
+    "Profile not found" : "Nun s'atopó'l perfil",
+    "The profile does not exist." : "El perfil nun esiste.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ye probable que'l to direutoriu de datos y los ficheros seyan accesibles dende internet porque'l ficheru .htaccess nun funciona.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pa consiguir más información tocante a cómo configurar afayadizamente'l sirvidor, mira la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
+    "Show password" : "Amosar la contraseña",
+    "Toggle password visibility" : "Alternar la visibilidá de la contraseña",
+    "Configure the database" : "Configurar la base de datos",
+    "Only %s is available." : "Namás hai disponible %s.",
+    "Database account" : "Cuenta de la base de datos"
 },
 "nplurals=2; plural=(n != 1);");
