@@ -29,6 +29,7 @@ OC.L10N.register(
     "Your login token is invalid or has expired" : "Innskráningartákn er ógilt eða útrunnið",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Þessi samfélagsútgáfa Nextcloud kemur ekki með neinni opinberri aðstoð og rauntímatilkynningar eru takmarkaðar.",
     "Login" : "Innskráning",
+    "Unsupported email length (>255)" : "Óstudd lengd tölvupósts (>255)",
     "Password reset is disabled" : "Endurstilling lykilorðs er óvirk",
     "Could not reset password because the token is expired" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið er útrunnið",
     "Could not reset password because the token is invalid" : "Gat ekki endurstillt lykilorðið vegna þess að teiknið er ógilt",
@@ -38,9 +39,11 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Smelltu á eftirfarandi hnapp til að endurstilla lykilorðið þitt. Ef þú hefur ekki beðið um endurstillingu lykilorðs, skaltu hunsa þennan tölvupóst.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Smelltu á eftirfarandi tengil til að endurstilla lykilorðið þitt. Ef þú hefur ekki beðið um endurstillingu lykilorðs, skaltu hunsa þennan tölvupóst.",
     "Reset your password" : "Endurstilltu lykilorðið þitt",
+    "The given provider is not available" : "Uppgefin þjónustuveita er ekki tiltæk",
     "Task not found" : "Verk fannst ekki",
     "Internal error" : "Innri villa",
     "Not found" : "Fannst ekki",
+    "Bad request" : "Ógild beiðni",
     "Requested task type does not exist" : "Umbeðin tegund verks er ekki til",
     "Necessary language model provider is not available" : "Nauðsynleg tungumálslíkanaþjónusta er tiltæk",
     "No text to image provider is available" : "Engin texti-í-mynd þjónusta er tiltæk",
@@ -51,6 +54,8 @@ OC.L10N.register(
     "Nextcloud Server" : "Nextcloud þjónn",
     "Some of your link shares have been removed" : "Sumir tenglar þínir á sameignir hafa verið fjarlægðir",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Vegna öryggisgalla hafa sumir tenglar þínir á sameignir hafa verið fjarlægðir. Skoðaðu tengilinn til að sjá frekari upplýsingar.",
+    "The account limit of this instance is reached." : "Hámarksfjölda aðganga á þessu tilviki er náð.",
+    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Settu inn áskriftarlykilinn þinn í aðstoðarforritið til að lyfta takmörkum á aðgangnum þínum. Þetta gefur þér einnig alla viðbótareiginleikana sem Nextcloud Enterprise fyrirtækjaáskrift býður, enda er sterklega mælt með þeim fyrir verklag í fyrirtækjum.",
     "Learn more ↗" : "Kanna nánar ↗",
     "Preparing update" : "Undirbý uppfærslu",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -98,55 +103,75 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} tilkynning","{count} tilkynningar"],
     "No" : "Nei",
     "Yes" : "Já",
-    "Create share" : "Búa til sameign",
+    "The remote URL must include the user." : "Fjartengda vefslóðin þarf að innihalda notandanafnið.",
+    "Invalid remote URL." : "Ógild fjartengd slóð.",
     "Failed to add the public link to your Nextcloud" : "Mistókst að bæta opinberum tengli í þitt eigið Nextcloud",
+    "Federated user" : "Notandi í skýjasambandi",
+    "user@your-nextcloud.org" : "notandi@þitt-nextcloud.org",
+    "Create share" : "Búa til sameign",
+    "Direct link copied to clipboard" : "Beinn tengill afritaður á klippispjald",
+    "Please copy the link manually:" : "Afritaðu tengilinn handvirkt:",
     "Custom date range" : "Sérsniðið dagsetningabil",
     "Pick start date" : "Veldu upphafsdagsetningu",
     "Pick end date" : "Veldu lokadagsetningu",
     "Search in date range" : "Leita í dagsetningabili",
-    "Search apps, files, tags, messages" : "Leita í forritum, skrám, merkjum, skilaboðum",
-    "Places" : "Staðir",
-    "Date" : "Dagsetning",
+    "Search in current app" : "Leita í núverandi forriti",
+    "Clear search" : "Hreinsa leit",
+    "Search everywhere" : "Leita allsstaðar",
+    "Searching …" : "Leita …",
+    "Start typing to search" : "Skrifaðu hér til að leita",
+    "No matching results" : "Engar samsvarandi niðurstöður",
     "Today" : "Í dag",
     "Last 7 days" : "Síðustu 7 daga",
     "Last 30 days" : "Síðustu 30 daga",
     "This year" : "Á þessu ári",
     "Last year" : "Á síðasta ári",
+    "Unified search" : "Sameinuð leit",
+    "Search apps, files, tags, messages" : "Leita í forritum, skrám, merkjum, skilaboðum",
+    "Places" : "Staðir",
+    "Date" : "Dagsetning",
     "Search people" : "Leita að fólki",
     "People" : "Fólk",
     "Filter in current view" : "Sía í núverandi sýn",
+    "Results" : "Niðurstöður",
     "Load more results" : "Hlaða inn fleiri niðurstöðum",
     "Search in" : "Leita í",
-    "Searching …" : "Leita …",
-    "Start typing to search" : "Skrifaðu hér til að leita",
-    "No matching results" : "Engar samsvarandi niðurstöður",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Á milli ${this.dateFilter.startFrom.toLocaleDateString()} og ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Skrá inn",
     "Logging in …" : "Skrái inn …",
+    "Log in to {productName}" : "Skrá inn í {productName}",
+    "Wrong login or password." : "Rangur notandi eða lykilorð.",
+    "This account is disabled" : "Þessi notandaaðgangur er óvirkur",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Við urðum vör við margar misheppnaðar innskráningar í röð frá IP-vistfanginu þínu. Þar með verður næsta innskráning tafin (throttled) um 30 sekúndur.",
+    "Account name or email" : "Heiti aðgangs eða tölvupóstfang",
+    "Account name" : "Heiti notandaaðgangs",
     "Server side authentication failed!" : "Auðkenning af hálfu þjóns tókst ekki!",
     "Please contact your administrator." : "Hafðu samband við kerfisstjóra.",
-    "Temporary error" : "Tímabundin villa",
-    "Please try again." : "Endilega reyndu aftur.",
+    "Session error" : "Villa í setu",
     "An internal error occurred." : "Innri villa kom upp.",
     "Please try again or contact your administrator." : "Reyndu aftur eða hafðu samband við kerfisstjóra.",
     "Password" : "Lykilorð",
-    "Log in to {productName}" : "Skrá inn í {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Við urðum vör við margar misheppnaðar innskráningar í röð frá IP-vistfanginu þínu. Þar með verður næsta innskráning tafin (throttled) um 30 sekúndur.",
-    "Account name or email" : "Heiti aðgangs eða tölvupóstfang",
     "Log in with a device" : "Skrá inn með tæki",
+    "Login or email" : "Notandanafn eða lykilorð",
     "Your account is not setup for passwordless login." : "Aðgangur þinn er ekki uppsettur með lykilorðalausri innskráningu.",
-    "Browser not supported" : "Það er ekki stuðningur við vafrann",
-    "Passwordless authentication is not supported in your browser." : "Lykilorðalaus auðkenning er ekki studd í vafranum þínum.",
     "Your connection is not secure" : "Tengingin þín er ekki örugg",
     "Passwordless authentication is only available over a secure connection." : "Lykilorðalaus auðkenning er aðeins tiltæk í gegnum örugga tengingu.",
+    "Browser not supported" : "Það er ekki stuðningur við vafrann",
+    "Passwordless authentication is not supported in your browser." : "Lykilorðalaus auðkenning er ekki studd í vafranum þínum.",
     "Reset password" : "Endursetja lykilorð",
+    "Back to login" : "Til baka í innskráningu",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Ef þessi aðgangur fyrirfinnst, þá hafa skilaboð um endurstillingu lykilorðs verið send á tölvupóstfang aðgangsins. Ef þú hefur ekki fengið slík skilaboð, skaltu athuga tölvupóstfangið þitt og/eða notandanafnið, skoða vel í möppur fyrir ruslpóst/rusl eða beðið kerfisstjórnendur þína um aðstoð.",
     "Couldn't send reset email. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti. Hafðu samband við kerfisstjóra.",
     "Password cannot be changed. Please contact your administrator." : "Ekki er hægt að breyta lykilorði. Hafðu samband við kerfisstjóra.",
-    "Back to login" : "Til baka í innskráningu",
     "New password" : "Nýtt lykilorð",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Skrárnar þínar eru dulritaðar. Það er engin leið til að fá gögnin þín til baka eftir lykilorðið þitt er endurstillt. Ef þú ert ekki viss hvað eigi að gera, skaltu hafa samband við kerfisstjórann áður en þú heldur áfram. Viltu halda áfram?",
     "I know what I'm doing" : "Ég veit hvað ég er að gera",
     "Resetting password" : "Endurstilli lykilorð",
+    "Schedule work & meetings, synced with all your devices." : "Áætlun vinnu og stefnumóta, samstillt við öll tækin þín.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Hafðu samstarfsfólk og vini á einum stað án þess að leka einkaupplýsingum þeirra.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Einfalt og stílhreint tölvupóstforrit sem virkar með skráaforritinu, tengiliðum og dagatalinu.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Spjall, myndfundir, skjádeiling, netfundir og vefráðstefnur – í vafranum þínum og með farsímaforritum.",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Skjöl í samstarfsvinnslu, töflureiknar og kynningar, byggt á Collabora Online.",
+    "Distraction free note taking app." : "Glósuforrit án truflana.",
     "Recommended apps" : "Ráðlögð forrit",
     "Loading apps …" : "Hleð inn forritum …",
     "Could not fetch list of apps from the App Store." : "Gat ekki sótt lista yfir forrit úr App Store.",
@@ -156,14 +181,10 @@ OC.L10N.register(
     "Skip" : "Sleppa",
     "Installing apps …" : "Set upp forrit …",
     "Install recommended apps" : "Setja upp ráðlögð forrit",
-    "Schedule work & meetings, synced with all your devices." : "Áætlun vinnu og stefnumóta, samstillt við öll tækin þín.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Hafðu samstarfsfólk og vini á einum stað án þess að leka einkaupplýsingum þeirra.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Einfalt og stílhreint tölvupóstforrit sem virkar með skráaforritinu, tengiliðum og dagatalinu.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Spjall, myndfundir, skjádeiling, netfundir og vefráðstefnur – í vafranum þínum og með farsímaforritum.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Skjöl í samstarfsvinnslu, töflureiknar og kynningar, byggt á Collabora Online.",
-    "Distraction free note taking app." : "Glósuforrit án truflana.",
-    "Settings menu" : "Stillingavalmynd",
     "Avatar of {displayName}" : "Auðkennismynd fyrir {displayName}",
+    "Settings menu" : "Stillingavalmynd",
+    "Loading your contacts …" : "Hleð inn tengiliðalistum ...",
+    "Looking for {term} …" : "Leita að {term} …",
     "Search contacts" : "Leita í tengiliðum",
     "Reset search" : "Núllstilla leit",
     "Search contacts …" : "Leita í tengiliðum ",
@@ -171,30 +192,60 @@ OC.L10N.register(
     "No contacts found" : "Engir tengiliðir fundust",
     "Show all contacts" : "Birta alla tengiliði ...",
     "Install the Contacts app" : "Setja upp tengiliðaforritið",
-    "Loading your contacts …" : "Hleð inn tengiliðalistum ...",
-    "Looking for {term} …" : "Leita að {term} …",
-    "Search starts once you start typing and results may be reached with the arrow keys" : "Leitin hefst um leið og byrjað er að skrifa og er hægt að flakka um leitarniðurstöður með örvalyklunum",
-    "Search for {name} only" : "Leita einungis að {name}",
-    "Loading more results …" : "Hleð inn fleiri niðurstöðum …",
     "Search" : "Leita",
     "No results for {query}" : "Engar niðurstöður fyrir {query}",
     "Press Enter to start searching" : "Ýttu á Enter til að hefja leit",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Settu inn {minSearchLength} staf eða fleiri til að leita","Settu inn {minSearchLength} stafi eða fleiri til að leita"],
     "An error occurred while searching for {type}" : "Villa kom upp við leit að {type}",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "Leitin hefst um leið og byrjað er að skrifa og er hægt að flakka um leitarniðurstöður með örvalyklunum",
+    "Search for {name} only" : "Leita einungis að {name}",
+    "Loading more results …" : "Hleð inn fleiri niðurstöðum …",
     "Forgot password?" : "Gleymdirðu lykilorði?",
     "Back to login form" : "Til baka í innskráningarform",
     "Back" : "Til baka",
     "Login form is disabled." : "Innskráningarform er óvirkt.",
-    "Edit Profile" : "Breyta sniði",
-    "The headline and about sections will show up here" : "Fyrirsögnin og hlutar um hugbúnaðinn munu birtast hér",
-    "You have not added any info yet" : "Þú hefur ekki bætt við neinum upplýsingum ennþá",
-    "{user} has not added any info yet" : "{user} hefur ekki bætt við neinum upplýsingum ennþá",
-    "Error opening the user status modal, try hard refreshing the page" : "Villa við að opna stöðuglugga notandans, prófaðu að þvinga endurlestur síðunnar",
+    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Innskráningarform Nextcloud er óvirkt. Notaðu aðra aðferð til innskráningar ef slíkt er í boði eða hafðu samband við kerfisstjórnanda.",
     "More actions" : "Fleiri aðgerðir",
+    "Password is too weak" : "Lykilorð er of veikt",
+    "Password is weak" : "Lykilorð er veikt",
+    "Password is average" : "Lykilorð er í meðallagi",
+    "Password is strong" : "Lykilorð er sterkt",
+    "Password is very strong" : "Lykilorð er mjög sterkt",
+    "Password is extremely strong" : "Lykilorð er einstaklega sterkt",
+    "Unknown password strength" : "Óþekktur styrkur lykilorðs",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að <code>.htaccess</code> skráin er ekki virk.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Til að fá upplýsingar hvernig á að stilla miðlara almennilega, skaltu skoða {linkStart}hjálparskjölin{linkEnd}",
+    "Autoconfig file detected" : "Fann autoconfig-uppsetningarskrá",
+    "Security warning" : "Öryggisviðvörun",
+    "Create administration account" : "Búa til stjórnunaraðgang",
+    "Administration account name" : "Heiti kerfisstjóraaðgangs",
+    "Administration account password" : "Lykilorð kerfisstjóraaðgangs",
+    "Storage & database" : "Geymsla & gagnagrunnur",
+    "Data folder" : "Gagnamappa",
+    "Database configuration" : "Uppsetning gagnagrunns",
+    "Only {firstAndOnlyDatabase} is available." : "Aðeins {firstAndOnlyDatabase} er laust.",
+    "Install and activate additional PHP modules to choose other database types." : "Setja upp og virkja viðbótar PHP-einingar til að geta valið aðrar tegundir gagnagrunna.",
+    "For more details check out the documentation." : "Frekari upplýsingar eru í hjálparskjölum.",
+    "Performance warning" : "Afkastaviðvörun",
+    "You chose SQLite as database." : "Þú valdir SQLite sem gagnagrunn.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ætti aðeins að nota fyrir lágmarksuppsetningar og til prófana. Fyrir stærri uppsetningar mælum við með að velja annan gagnagrunnsbakenda.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ef verið er að nota biðlaraforrit til að samstilla skrár, þá er ekki mælt með notkun SQLite.",
+    "Database user" : "Notandi gagnagrunns",
+    "Database password" : "Lykilorð gagnagrunns",
+    "Database name" : "Heiti gagnagrunns",
+    "Database tablespace" : "Töflusvæði gagnagrunns",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Taktu fram númer gáttar ásamt nafni hýsilvélar (t.d., localhost:5432).",
+    "Database host" : "Netþjónn gagnagrunns",
+    "localhost" : "localhost",
+    "Installing …" : "Set upp…",
+    "Install" : "Setja upp",
+    "Need help?" : "Þarftu hjálp?",
+    "See the documentation" : "Sjá hjálparskjölin",
+    "{name} version {version} and above" : "{name} útgáfa {version} og hærri",
     "This browser is not supported" : "Það er ekki stuðningur við þennan vafra",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Það er ekki stuðningur við vafrann þinn. Endilega uppfærðu í nýrri útgáfu eða vafra sem er studdur.",
     "Continue with this unsupported browser" : "Halda áfram með þessum óstudda vafra",
     "Supported versions" : "Studdar útgáfur",
-    "{name} version {version} and above" : "{name} útgáfa {version} og hærri",
     "Search {types} …" : "Leita að {types} …",
     "Choose {file}" : "Veldu {file}",
     "Choose" : "Veldu",
@@ -230,14 +281,10 @@ OC.L10N.register(
     "Type to search for existing projects" : "Skrifaðu hér til að leita að fyrirliggjandi verkefnum",
     "New in" : "Nýtt í",
     "View changelog" : "Skoða breytingaannál",
-    "Very weak password" : "Mjög veikt lykilorð",
-    "Weak password" : "Veikt lykilorð",
-    "So-so password" : "Miðlungs lykilorð",
-    "Good password" : "Gott lykilorð",
-    "Strong password" : "Sterkt lykilorð",
     "No action available" : "Engin aðgerð tiltæk",
     "Error fetching contact actions" : "Villa við að sækja aðgerðir tengiliða",
     "Close \"{dialogTitle}\" dialog" : "Loka \"{dialogTitle}\"-glugga",
+    "Email length is at max (255)" : "Lengd tölvupósts er að hámarki (255)",
     "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
     "Restricted" : "Takmarkað",
     "Invisible" : "Ósýnilegt",
@@ -245,24 +292,23 @@ OC.L10N.register(
     "Rename" : "Endurnefna",
     "Collaborative tags" : "Samstarfsmerkingar",
     "No tags found" : "Engin merki fundust",
+    "Clipboard not available, please copy manually" : "Klippispjald er ekki tiltækt, afritaðu handvirkt",
     "Personal" : "Einka",
     "Accounts" : "Notandaaðgangar",
     "Admin" : "Stjórnun",
     "Help" : "Hjálp",
     "Access forbidden" : "Aðgangur bannaður",
-    "Profile not found" : "Sniðið finnst ekki",
-    "The profile does not exist." : "Sniðið er ekki til.",
-    "Back to %s" : "Til baka í %s",
     "Page not found" : "Síða fannst ekki",
     "The page could not be found on the server or you may not be allowed to view it." : "Síðan fannst ekki á netþjóninum eða að þér er ekki heimilt að skoða hana.",
+    "Back to %s" : "Til baka í %s",
     "Too many requests" : "Of margar beiðnir",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Það komu of margar beiðnir frá netkerfinu þínu. Reyndu aftur eða hafðu samband við kerfisstjóra ef þetta er ekki rétt.",
     "Error" : "Villa",
-    "Previous" : "Fyrra",
     "Internal Server Error" : "Innri villa",
     "The server was unable to complete your request." : "Þjóninum tókst ekki að afgreiða beiðnina þína.",
     "If this happens again, please send the technical details below to the server administrator." : "Ef þetta gerist aftur, sendu tæknilegu lýsinguna hér fyrir neðan til kerfisstjóra þjónsins.",
     "More details can be found in the server log." : "Nánari upplýsingar er að finna í atburðaskrá (annál) þjónsins.",
+    "For more details see the documentation ↗." : "Frekari upplýsingar má sjá í hjálparskjölunum ↗.",
     "Technical details" : "Tæknilegar upplýsingar",
     "Remote Address: %s" : "fjartengt vistfang: %s",
     "Request ID: %s" : "Beiðni um auðkenni: %s",
@@ -272,31 +318,7 @@ OC.L10N.register(
     "File: %s" : "Skrá: %s",
     "Line: %s" : "Lína: %s",
     "Trace" : "Rekja",
-    "Security warning" : "Öryggisviðvörun",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að .htaccess skrá er ekki virk.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Til að fá upplýsingar hvernig á að stilla miðlarann almennilega, skaltu skoða <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">hjálparskjölin</a>.",
-    "Create an <strong>admin account</strong>" : "Útbúa <strong>kerfisstjóraaðgang</strong>",
-    "Show password" : "Sýna lykilorð",
-    "Toggle password visibility" : "Breyta sýnileika lykilorðs",
-    "Storage & database" : "Geymsla & gagnagrunnur",
-    "Data folder" : "Gagnamappa",
-    "Configure the database" : "Stilla gagnagrunninn",
-    "Only %s is available." : "Aðeins %s eru laus.",
-    "Install and activate additional PHP modules to choose other database types." : "Setja upp og virkja viðbótar PHP-einingar til að geta valið aðrar tegundir gagnagrunna.",
-    "For more details check out the documentation." : "Frekari upplýsingar eru í hjálparskjölum.",
-    "Database password" : "Lykilorð gagnagrunns",
-    "Database name" : "Heiti gagnagrunns",
-    "Database tablespace" : "Töflusvæði gagnagrunns",
-    "Database host" : "Netþjónn gagnagrunns",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Taktu fram númer gáttar ásamt nafni hýsilvélar (t.d., localhost:5432).",
-    "Performance warning" : "Afkastaviðvörun",
-    "You chose SQLite as database." : "Þú valdir SQLite sem gagnagrunn.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ætti aðeins að nota fyrir lágmarksuppsetningar og til prófana. Fyrir stærri uppsetningar mælum við með að velja annan gagnagrunnsbakenda.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ef verið er að nota biðlaraforrit til að samstilla skrár, þá er ekki mælt með notkun SQLite.",
-    "Install" : "Setja upp",
-    "Installing …" : "Set upp…",
-    "Need help?" : "Þarftu hjálp?",
-    "See the documentation" : "Sjá hjálparskjölin",
+    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Það lítur út fyrir að þú sért að reyna að setja Nextcloud upp aftur. Hinsvegar vantar skrána CAN_INSTALL í grunnstillingamöppuna þína (config directory). Búðu til skrána CAN_INSTALL í grunnstillingamöppunni til að halda áfram.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Gat ekki fjarlægt CAN_INSTALL úr stillingamöppunni. Fjarlægðu þessa skrá handvirkt.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Þetta forrit krefst JavaScript fyrir rétta virkni. {linkstart} virkjaðu JavaScript {linkend} og endurlestu síðan síðuna.",
     "Skip to main content" : "Sleppa og fara í meginefni",
@@ -306,13 +328,16 @@ OC.L10N.register(
     "Connect to your account" : "Tengdu við notandaaðganginn þinn",
     "Please log in before granting %1$s access to your %2$s account." : "Skráðu þig inn áður en þú leyfir %1$s aðgang að %2$s notandaaðgangnum þínum.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ef þú ert ekki að reyna að setja upp nýtt tæki eða forrit, þá er einhver annar að reyna að gabba þig til að gefa þeim aðgang að gögnunum þínum. Ef svo er, skaltu ekki halda áfram í þessu ferli og hafa strax samband við kerfisstjórann þinn.",
+    "App password" : "Lykilorð forrits",
     "Grant access" : "Veita aðgengi",
+    "Alternative log in using app password" : "Önnur innskráning með lykilorði forrits",
     "Account access" : "Aðgangur að notandaaðgangi",
     "Currently logged in as %1$s (%2$s)." : "Í augnablikinu er skráð inn sem %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Þú ert að fara að leyfa \"%1$s\" aðgang að %2$s notandaaðgangnum þínum.",
     "Account connected" : "Aðgangur er tengdur",
     "Your client should now be connected!" : "Biðlaraforritið þitt ætti núna að vera tengt!",
     "You can close this window." : "Þú mátt loka þessum glugga.",
+    "Previous" : "Fyrra",
     "This share is password-protected" : "Þessi sameign er varin með lykilorði",
     "The password is wrong or expired. Please try again or request a new one." : "Lykilorðið er rangt eða útrunnið. Prófaðu aftur eða biddu um nýtt lykilorð.",
     "Please type in your email address to request a temporary password" : "Settu inn tölvupóstfangið þitt til að biðja um bráðabirgðalykilorð",
@@ -343,6 +368,7 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Til að forðast að falla á tímamörkum með stærri uppsetningar, getur þú í staðinn keyrt eftirfarandi skipun úr uppsetningarmöppunni:",
     "Detailed logs" : "Ítarlegar atvikaskrár",
     "Update needed" : "Þarfnast uppfærslu",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Endilega notaðu uppfærslutólið af skipanalínu, því þú ert með mjög stóra uppsetningu með fleiri en 50 notendaaðgöngum.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Til að fá hjálp er best að skoða fyrst  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">hjálparskjölin</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Ég veit að ef ég held uppfærslunni áfram í gegnum vefviðmótið, þá er sú áhætta fyrir hendi að beiðnin falli á tímamörkum, sem aftur gæti valdið gagnatapi - en ég á öryggisafrit og veit hvernig ég get endurheimt uppsetninguna mína ef aðgerðin misferst.",
     "Upgrade via web on my own risk" : "Uppfæra með vefviðmóti á mína eigin ábyrgð",
@@ -350,30 +376,32 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Þessi %s er nú í viðhaldsham, sem getur tekið smá stund.",
     "This page will refresh itself when the instance is available again." : "Þessi síða mun uppfæra sig þegar tilvikið er í boði á ný.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hafðu samband við kerfisstjóra ef þessi skilaboð eru viðvarandi eða birtust óvænt.",
-    "The user limit of this instance is reached." : "Hámarksfjölda notenda á þessu tilviki er náð.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Vefþjónninn er ekki enn sett upp á réttan hátt til að leyfa skráasamstillingu því WebDAV viðmótið virðist vera skemmt.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Vefþjónninn þinn er ekki uppsettur þannig að hann geti leyst \"{url}\". Frekari upplýsingar er að finna í {linkstart}hjálparskjölum ↗{linkend} okkar.",
-    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Gagnamappan og skrárnar þínar eru líklega aðgengilegar öllum af internetinu vegna þess að .htaccess skrá er ekki virk. Við mælum eindregið með að þú stillir vefþjóninn þinn á þann hátt að gagnamappa er ekki lengur aðgengileg eða þú færir gagnamöppu út fyrir skjalarót vefþjóns.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn er ekki stilltur á \"{expected}\". Þetta er möguleg áhætta varðandi  öryggi og gagnaleynd, við mælum með því að laga þessa stillingu.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn er ekki stilltur á \"{expected}\". Einhverjir eiginleikar gætu virkað ekki rétt, við mælum með því að laga þessa stillingu.",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn inniheldur ekki \"{expected}\". Þetta er möguleg áhætta varðandi öryggi og gagnaleynd, við mælum með því að laga þessa stillingu.",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP-hausinn \"{header}\" er ekki stilltur á \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" eða \"{val5}\" Þetta getur lekið upplýsingum um kerfið. Skoðaðu hvað {linkstart}W3C mælir með ↗{linkend}.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "\"Strict-Transport-Security\" HTTP-hausinn er ekki stilltur á að minnsta kosti \"{seconds}\" sekúndur. Fyrir aukið öryggi mælum við með því að virkja HSTS eins og lýst er í {linkstart}öryggisleiðbeiningunum ↗ {linkend}.",
-    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Þú ert að tengjast þessu vefsvæði með óöruggu HTTP. Við mælum eindregið með að þú stillir þjóninn á að krefjast HTTPS í staðinn eins og lýst er í {linkstart}öryggisleiðbeiningunum ↗{linkend} okkar. Án þess munu ýmsir mikilvægir eiginleikar vefsíðna ekki virka, eins og \"afrita á klippispjald\" eða \"þjónustuferli / service workers\"!",
     "Currently open" : "Opið núna",
-    "Wrong username or password." : "Rangt notandanafn eða lykilorð.",
-    "User disabled" : "Notandi óvirkur",
-    "Username or email" : "Notandanafn eða tölvupóstur",
-    "Apps and Settings" : "Forrit og stillingar",
+    "Login with username or email" : "Skrá inn með notandanafni eða tölvupóstfangi",
+    "Login with username" : "Skrá inn með notandanafni",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Spjall, myndfundir, skjádeiling, netfundir og vefráðstefnur – í vafranum þínum og með farsímaforritum.",
+    "You have not added any info yet" : "Þú hefur ekki bætt við neinum upplýsingum ennþá",
+    "{user} has not added any info yet" : "{user} hefur ekki bætt við neinum upplýsingum ennþá",
+    "Error opening the user status modal, try hard refreshing the page" : "Villa við að opna stöðuglugga notandans, prófaðu að þvinga endurlestur síðunnar",
+    "Edit Profile" : "Breyta sniði",
+    "The headline and about sections will show up here" : "Fyrirsögnin og hlutar um hugbúnaðinn munu birtast hér",
     "Error loading message template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skilaboð: {error}",
-    "Users" : "Notendur",
-    "Username" : "Notandanafn",
-    "Database user" : "Notandi gagnagrunns",
-    "This action requires you to confirm your password" : "Þessi aðgerð krefst þess að þú staðfestir lykilorðið þitt",
-    "Confirm your password" : "Staðfestu lykilorðið þitt",
-    "Confirm" : "Staðfesta",
-    "App token" : "Teikn forrits",
-    "Alternative log in using app token" : "Önnur innskráning með forritsteikni",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Endilega notaðu uppfærslutólið af skipanalínu, því þú ert með mjög stóra uppsetningu með fleiri en 50 notendum."
+    "Very weak password" : "Mjög veikt lykilorð",
+    "Weak password" : "Veikt lykilorð",
+    "So-so password" : "Miðlungs lykilorð",
+    "Good password" : "Gott lykilorð",
+    "Strong password" : "Sterkt lykilorð",
+    "Profile not found" : "Sniðið finnst ekki",
+    "The profile does not exist." : "Sniðið er ekki til.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að .htaccess skrá er ekki virk.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Til að fá upplýsingar hvernig á að stilla miðlarann almennilega, skaltu skoða <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">hjálparskjölin</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Útbúa kerfisstjóraaðgang</strong>",
+    "New admin account name" : "Nýtt heiti kerfisstjóraaðgangs",
+    "New admin password" : "Nýtt lykilorð kerfisstjóra",
+    "Show password" : "Sýna lykilorð",
+    "Toggle password visibility" : "Breyta sýnileika lykilorðs",
+    "Configure the database" : "Stilla gagnagrunninn",
+    "Only %s is available." : "Aðeins %s eru laus.",
+    "Database account" : "Gagnagrunnsaðgangur"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
