@@ -27,22 +27,34 @@ OC.L10N.register(
     "Could not complete login" : "Não foi possível concluir a autenticação",
     "State token missing" : "O código de estado está em falta",
     "Your login token is invalid or has expired" : "O seu código de autenticação é inválido ou expirou",
-    "This community release of Nextcloud is unsupported and push notifications are limited." : "A versão comunitária da Nextcloud não tem suporte e as notificações a pedido são limitadas.",
+    "This community release of Nextcloud is unsupported and push notifications are limited." : "A versão comunitária de Nextcloud não tem suporte e as notificações a pedido são limitadas.",
     "Login" : "Iniciar sessão",
+    "Unsupported email length (>255)" : "Comprimento do e-mail não suportado (>255)",
     "Password reset is disabled" : "A reposição da senha está desativada",
-    "Could not reset password because the token is expired" : "Não foi possível redefinir a palavra-passe porque o token expirou",
-    "Could not reset password because the token is invalid" : "Não foi possível redefinir a palavra-passe porque o token é inválido",
-    "Password is too long. Maximum allowed length is 469 characters." : "A senha é muito longa. O comprimento máximo permitido é de 469 caracteres.",
+    "Could not reset password because the token is expired" : "Não foi possível redefinir a palavra-passe porque o código expirou",
+    "Could not reset password because the token is invalid" : "Não foi possível redefinir a palavra-passe porque o código é inválido",
+    "Password is too long. Maximum allowed length is 469 characters." : "A palavra-passe é muito longa. O comprimento máximo permitido é de 469 carateres.",
     "%s password reset" : "%s reposição de palavra-passe",
     "Password reset" : "Reposição da senha",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Clique no seguinte botão para repor a sua senha. Se não solicitou a reposição da senha, ignore este e-mail.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clique na seguinte hiperligação para repor a sua senha. Se não solicitou a reposição da senha, ignore este e-mail.",
     "Reset your password" : "Repor a senha",
+    "The given provider is not available" : "O fornecedor indicado não está disponível",
+    "Task not found" : "Tarefa não encontrada",
     "Internal error" : "Erro interno",
-    "Not found" : "Não foi encontrado",
+    "Not found" : "Não  encontrado",
+    "Bad request" : "Pedido incorreto",
+    "Necessary language model provider is not available" : "O fornecedor do modelo linguístico necessário não está disponível",
+    "No text to image provider is available" : "Não está disponível nenhum fornecedor de texto para imagem",
+    "Image not found" : "Imagem não encontrada",
+    "No translation provider available" : "Nenhum fornecedor de tradução disponível",
+    "Could not detect language" : "Não foi possível detetar o idioma",
+    "Unable to translate" : "Não é possível traduzir",
     "Nextcloud Server" : "Nextcloud Server",
     "Some of your link shares have been removed" : "Algumas das suas partilhas de hiperligação foram removidas",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Devido a bugs de segurança tivemos que remover algumas das suas ligações às partilhas.\nPor favor veja o link para mais informação.",
+    "The account limit of this instance is reached." : "O limite da conta desta instância foi atingido.",
+    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Introduza a sua chave de subscrição na aplicação de suporte para aumentar o limite da conta. Isto também lhe concede todos os benefícios adicionais que o Nextcloud Enterprise oferece e é altamente recomendado para a operação em empresas.",
     "Learn more ↗" : "Saiba mais ↗",
     "Preparing update" : "A preparar a atualização",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -50,6 +62,7 @@ OC.L10N.register(
     "Repair info:" : "Informação da reparação:",
     "Repair warning:" : "Aviso de reparação:",
     "Repair error:" : "Erro de reparação:",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Utilize o atualizador da linha de comandos porque a atualização através do navegador está desativada no seu config.php.",
     "Turned on maintenance mode" : "Ativou o modo de manutenção",
     "Turned off maintenance mode" : "Desativou o modo de manutenção",
     "Maintenance mode is kept active" : "O modo de manutenção é mantido ativo",
@@ -66,6 +79,7 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "As seguintes aplicações foram desativadas: %s",
     "Already up to date" : "Já está atualizado",
     "Error occurred while checking server setup" : "Ocorreu um erro durante a verificação da configuração do servidor",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Para mais pormenores, consultar o {linkstart}documentação ↗{linkend}.",
     "unknown text" : "texto desconhecido",
     "Hello world!" : "Olá, mundo!",
     "sunny" : "soalheiro",
@@ -74,80 +88,102 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Resultados da pesquisa<script>alert(1)</script></strong>",
     "new" : "novo",
     "_download %n file_::_download %n files_" : ["transferir %n ficheiro","transferir %n ficheiros","transferir %n ficheiros"],
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "A actualização está a decorrer. Se deixar esta página o processo pode ser interrompido.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em progresso. Se sair desta página poderá interromper o processo em alguns ambientes.",
     "Update to {version}" : "Atualizar para {version}",
     "An error occurred." : "Ocorreu um erro.",
     "Please reload the page." : "Por favor, recarregue a página.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização falhou. Para mais informação <a href=\"{url}\">consulte o nosso artigo do fórum</a> sobre como resolver este problema.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi bem sucedida. Por favor, informe este problema à <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade Nextcloud</a>.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi bem sucedida. Por favor, reporte este problema à <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade de Nextcloud</a>.",
     "Continue to {productName}" : "Continuar para {productName}",
+    "Applications menu" : "Menu de Aplicações",
     "Apps" : "Aplicações",
-    "More apps" : "Mais apps",
+    "More apps" : "Mais aplicações",
+    "_{count} notification_::_{count} notifications_" : ["{count} notificação","{count} notificações","{count} notificações"],
     "No" : "Não",
     "Yes" : "Sim",
     "Failed to add the public link to your Nextcloud" : "Não foi possível adicionar a hiperligação pública ao seu Nextcloud",
-    "Date" : "Data",
+    "Federated user" : "Utilizador federado",
+    "Searching …" : "A procurar…",
+    "Start typing to search" : "Comece a digitar para procurar",
     "Today" : "Hoje",
-    "Last year" : "Ultimo ano",
+    "Last year" : "Ano passado",
+    "Places" : "Locais",
+    "Date" : "Data",
+    "People" : "Pessoas",
     "Results" : "Resultados",
-    "Load more results" : "Mostrar mais resultados...",
-    "Searching …" : "À procura …",
-    "Start typing to search" : "Digitar para pesquisar",
+    "Load more results" : "Mostrar mais resultados",
     "Log in" : "Iniciar sessão",
-    "Logging in …" : "A entrar...",
+    "Logging in …" : "A iniciar a sessão...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Nós detetamos múltiplas tentativas falhadas de autenticação com o seu IP. Por isso, a sua próxima autenticação será adiada até 30 segundos. ",
     "Server side authentication failed!" : "Autenticação do lado do servidor falhou!",
     "Please contact your administrator." : "Por favor, contacte o seu administrador.",
     "An internal error occurred." : "Ocorreu um erro interno.",
     "Please try again or contact your administrator." : "Por favor, tente novamente ou contacte o seu administrador.",
     "Password" : "Palavra-passe",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos múltiplas tentativas falhadas de login do seu IP. Por esse motivo, o seu próximo login será adiado por, até, 30 segundos. ",
     "Your account is not setup for passwordless login." : "A sua conta não está configurada para autenticação sem palavra-passe.",
-    "Browser not supported" : "Navegador não suportado",
-    "Passwordless authentication is not supported in your browser." : "O seu navegador não suporta autenticação sem palavra-passe.",
     "Your connection is not secure" : "A sua ligação não é segura",
     "Passwordless authentication is only available over a secure connection." : "A autenticação sem palavra-passe só está disponível através de uma ligação segura.",
+    "Browser not supported" : "Navegador não suportado",
+    "Passwordless authentication is not supported in your browser." : "O seu navegador não suporta autenticação sem palavra-passe.",
     "Reset password" : "Repor palavra-passe",
+    "Back to login" : "Voltar à autenticação",
     "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar a mensagem de reposição. Por favor, contacte o seu administrador.",
-    "Password cannot be changed. Please contact your administrator." : "A senha não pode ser alterada. Contacte o seu administrador.",
-    "Back to login" : "Voltar à entrada",
+    "Password cannot be changed. Please contact your administrator." : "A palavra-passe não pode ser alterada. Por favor, contacte o seu administrador.",
     "New password" : "Nova palavra-passe",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Os seus ficheiros estão cifrados. Não será possível aceder aos seus dados após a palavra-passe ser alterada. Se não tiver a certeza do que fazer, contacte o administrador do sistema antes de continuar. Tem a certeza que quer continuar?",
     "I know what I'm doing" : "Eu sei o que eu estou a fazer",
-    "Resetting password" : "A fazer reset à palavra passe",
+    "Resetting password" : "Redefinir a palavra passe",
+    "Schedule work & meetings, synced with all your devices." : "Agende trabalho e reuniões, sincronizando com todos os seus dispositivos.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Mantenha os seus colegas e amigos no mesmo lugar sem divulgar as suas informações privadas.",
     "Recommended apps" : "Aplicações recomendadas",
     "Loading apps …" : "A carregar aplicações...",
     "App download or installation failed" : "A transferência ou a instalação desta aplicação falhou",
     "Cannot install this app because it is not compatible" : "Não é possível instalar esta aplicação por não ser compatível",
     "Cannot install this app" : "Não é possível instalar esta aplicação",
-    "Skip" : "Saltar",
+    "Skip" : "Ignorar",
     "Installing apps …" : "A instalar aplicações ...",
     "Install recommended apps" : "Instalar aplicações recomendadas",
-    "Schedule work & meetings, synced with all your devices." : "Agende trabalho e reuniões, sincronizando com todos os seus dispositivos.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Mantenha os seus colegas e amigos no mesmo lugar sem divulgar as suas informações privadas.",
-    "Settings menu" : "Menu de configurações",
+    "Settings menu" : "Menu de definições",
+    "Loading your contacts …" : "A carregar os seus contactos...",
+    "Looking for {term} …" : "A procurar por {term} …",
     "Reset search" : "Redefinir pesquisa",
-    "Search contacts …" : "Pesquisar contactos...",
+    "Search contacts …" : "Procurar contactos...",
     "Could not load your contacts" : "Não foi possível carregar os seus contactos",
     "No contacts found" : "Não foram encontrados contactos",
-    "Install the Contacts app" : "Instalar a app Contactos",
-    "Loading your contacts …" : "A carregar os seus contactos",
-    "Looking for {term} …" : "Procurando por {term} …",
-    "Search for {name} only" : "Pesquisar apenas por {name}",
-    "Loading more results …" : "A carregar mais resultados...",
+    "Install the Contacts app" : "Instalar a aplicação de Contactos",
     "Search" : "Procurar",
     "No results for {query}" : "Nenhum resultado para {query}",
     "An error occurred while searching for {type}" : "Ocorreu um erro enquanto pesquisava por {type}",
+    "Search for {name} only" : "Pesquisar apenas por {name}",
+    "Loading more results …" : "A carregar mais resultados...",
     "Forgot password?" : "Senha esquecida?",
     "Back" : "Anterior",
-    "Edit Profile" : "Editar perfil",
-    "You have not added any info yet" : "Ainda não adicionou qualquer informação ",
-    "More actions" : "Mais acções",
-    "This browser is not supported" : "O seu navegador não é suportado.",
-    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "A versão do seu navegador não é suportada. Por favor atualize para uma versão mais recente ou para uma que seja suportada.",
-    "Continue with this unsupported browser" : "Continuar com uma versão não suportada do navegador",
-    "Supported versions" : "Versões suportadas",
+    "More actions" : "Mais ações",
+    "Security warning" : "Aviso de segurança",
+    "Storage & database" : "Armazenamento e base de dados",
+    "Data folder" : "Pasta de dados",
+    "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos PHP adicionais para escolher outros tipos de base de dados.",
+    "For more details check out the documentation." : "Para mais detalhes consulte a documentação.",
+    "Performance warning" : "Aviso de desempenho",
+    "You chose SQLite as database." : "Escolheu SQLite como base de dados",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se utiliza clientes para a sincronização de ficheiros, a utilização de SQLite é altamente desencorajada.",
+    "Database user" : "Utilizador da base de dados",
+    "Database password" : "Palavra-passe da base de dados",
+    "Database name" : "Nome da base de dados",
+    "Database tablespace" : "Tablespace da base de dados",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor, especifique o número da porta com o nome do anfitrião (por exemplo, localhost:5432).",
+    "Database host" : "Anfitrião da base de dados",
+    "Installing …" : "A instalar...",
+    "Install" : "Instalar",
+    "Need help?" : "Precisa de ajuda?",
+    "See the documentation" : "Consulte a documentação",
     "{name} version {version} and above" : "{name} versão {version} e superior",
+    "This browser is not supported" : "Este navegador não é suportado",
+    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "O seu navegador não é suportado. Por favor, atualize para uma versão mais recente ou para um suportado.",
+    "Continue with this unsupported browser" : "Continuar com este navegador não suportado",
+    "Supported versions" : "Versões suportadas",
     "Search {types} …" : "Pesquisar {types}...",
+    "Choose {file}" : "Escolher {file}",
     "Choose" : "Escolher",
     "Copy" : "Copiar",
     "Move" : "Mover",
@@ -167,7 +203,7 @@ OC.L10N.register(
     "Saving …" : "A guardar...",
     "seconds ago" : "segundos atrás",
     "Connection to server lost" : "Ligação perdida ao servidor",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema a carregar a página. A recarregar dentro de %n segundos","Problema ao carregar a página. A recarregar dentro de %n segundos","Problema ao carregar a página. A recarregar dentro de %n segundos"],
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema a carregar a página. A recarregar em %n segundo","Problema ao carregar a página. A recarregar em  %n segundos","Problema ao carregar a página. A recarregar em %n segundos"],
     "Add to a project" : "Adicionar a um projeto",
     "Show details" : "Mostrar detalhes",
     "Hide details" : "Ocultar detalhes",
@@ -178,88 +214,59 @@ OC.L10N.register(
     "Connect items to a project to make them easier to find" : "Ligar itens a um projeto para poderem ser mais facilmente encontrados",
     "Type to search for existing projects" : "Digite para procurar por projetos existentes",
     "New in" : "Novo em",
-    "View changelog" : "Ver Registo de alterações",
-    "Very weak password" : "Palavra-passe muito fraca",
-    "Weak password" : "Palavra-passe fraca",
-    "So-so password" : "Palavra-passe aceitável",
-    "Good password" : "Palavra-passe boa",
-    "Strong password" : "Palavra-passe forte",
-    "No action available" : "Nenhuma acção disponível",
-    "Error fetching contact actions" : "Erro ao obter acções dos contactos",
+    "View changelog" : "Ver registo de alterações",
+    "No action available" : "Nenhuma ação disponível",
+    "Error fetching contact actions" : "Erro ao obter ações dos contactos",
     "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
     "Restricted" : "Restrito",
     "Invisible" : "Invisível ",
     "Delete" : "Eliminar",
     "Rename" : "Renomear",
     "Collaborative tags" : "Etiquetas colaborativas",
-    "No tags found" : "Etiquetas não encontradas",
+    "No tags found" : "Não foram encontradas etiquetas",
     "Personal" : "Pessoal",
     "Admin" : "Administração",
     "Help" : "Ajuda",
     "Access forbidden" : "Acesso proibido",
-    "Profile not found" : "Perfil não encontrado",
-    "The profile does not exist." : "O perfil não existe.",
-    "Back to %s" : "Voltar a %s",
     "Page not found" : "Página não encontrada",
+    "Back to %s" : "Voltar para %s",
     "Too many requests" : "Muitos pedidos",
     "Error" : "Erro",
-    "Previous" : "Anterior",
     "Internal Server Error" : "Erro Interno do Servidor",
-    "The server was unable to complete your request." : "O servidor não conseguiu completar o seu pedido.",
+    "The server was unable to complete your request." : "O servidor não conseguiu concluir o seu pedido.",
     "If this happens again, please send the technical details below to the server administrator." : "Se voltar a  acontecer, por favor envie os detalhes técnicos abaixo ao administrador do servidor.",
-    "More details can be found in the server log." : "Mais detalhes podem ser encontrados no log do servidor.",
+    "More details can be found in the server log." : "Mais detalhes podem ser encontrados no registo do servidor.",
     "Technical details" : "Detalhes técnicos",
     "Remote Address: %s" : "Endereço remoto: %s",
-    "Request ID: %s" : "ID do pedido: %s",
+    "Request ID: %s" : "Id. do pedido: %s",
     "Type: %s" : "Tipo: %s",
     "Code: %s" : "Código: %s",
     "Message: %s" : "Mensagem: %s",
     "File: %s" : "Ficheiro: %s",
     "Line: %s" : "Linha: %s",
     "Trace" : "Rastreio",
-    "Security warning" : "Aviso de Segurança",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "A pasta de dados e os respetivos ficheiros estão provavelmente acessíveis a partir da internet pois o ficheiro .htaccess não funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter informações de como configurar correctamente o servidor, veja em: <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentação</a>.",
-    "Create an <strong>admin account</strong>" : "Criar uma <strong>conta administrativa</strong>",
-    "Show password" : "Mostrar senha",
-    "Toggle password visibility" : "Altere a visibilidade da palavra-passe",
-    "Storage & database" : "Armazenamento e base de dados",
-    "Data folder" : "Pasta de dados",
-    "Configure the database" : "Configure a base de dados",
-    "Only %s is available." : "Só está disponível %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos PHP adicionais para escolher outros tipos de base de dados.",
-    "For more details check out the documentation." : "Para mais detalhes consulte a documentação.",
-    "Database password" : "Palavra-passe da base de dados",
-    "Database name" : "Nome da base de dados",
-    "Database tablespace" : "Tablespace da base de dados",
-    "Database host" : "Anfitrião da base de dados",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor, especifique o número da porta com o nome do anfitrião (por exemplo, localhost:5432).",
-    "Performance warning" : "Aviso de desempenho",
-    "You chose SQLite as database." : "Escolheu SQLite como base de dados",
-    "Install" : "Instalar",
-    "Installing …" : "A instalar...",
-    "Need help?" : "Precisa de ajuda?",
-    "See the documentation" : "Consulte a documentação",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicação requer JavaScript para funcionar corretamente. Por favor, {linkstart}ative o JavaScript{linkend} e recarregue a página.",
-    "Skip to main content" : "Saltar para conteúdo principal",
-    "Skip to navigation of app" : "Saltar para navegação da aplicação",
+    "Skip to main content" : "Ir para o conteúdo principal",
+    "Skip to navigation of app" : "Ir para a navegação da aplicação",
     "Go to %s" : "Ir para %s",
     "Get your own free account" : "Obtenha a sua própria conta grátis",
     "Connect to your account" : "Ligar à sua conta",
     "Please log in before granting %1$s access to your %2$s account." : "Por favor, autentique-se antes de permitir o acesso de %1$s à sua conta %2$s.",
     "Grant access" : "Conceder acesso",
     "Account access" : "Acesso à conta",
-    "You are about to grant %1$s access to your %2$s account." : "Está prestes a permitir a %1$s aceder à sua conta conta %2$s. ",
+    "You are about to grant %1$s access to your %2$s account." : "Está prestes a permitir que %1$s aceda à sua conta %2$s. ",
     "Account connected" : "Conta ligada",
+    "Your client should now be connected!" : "O seu cliente deveria agora estar ligado!",
     "You can close this window." : "Pode fechar esta janela.",
-    "This share is password-protected" : "Esta partilha está protegida por senha",
-    "Email address" : "Endereço de email",
+    "Previous" : "Anterior",
+    "This share is password-protected" : "Esta partilha está protegida por palavra-passe",
+    "Email address" : "Endereço de E-mail",
     "Two-factor authentication" : "Autenticação de dois fatores",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "A segurança reforçada foi ativada para a sua conta. Por favor, escolha um segundo fator de autenticação.",
-    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Não foi possível carregar pelo menos um dos métodos de autenticação de dois passos activados. Por favor, contacte o seu administrador.",
+    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Não foi possível carregar pelo menos um dos métodos de autenticação de dois passos ativados. Por favor, contacte o seu administrador.",
     "Set up two-factor authentication" : "Configurar autenticação de dois fatores",
     "Use backup code" : "Usar código de cópia de segurança",
-    "Cancel login" : "Cancelar login",
+    "Cancel login" : "Cancelar início de sessão",
     "Error while validating your second factor" : "Erro ao validar o segundo fator",
     "Access through untrusted domain" : "Aceder através de um domínio não confiável",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacte o seu administrador. Se é um administrador, edite a definição \"trusted_domains\" no config/config.php como no exemplo em config.sample.php.",
@@ -280,25 +287,21 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está atualmente no modo de manutenção, o que poderá demorar algum tempo.",
     "This page will refresh itself when the instance is available again." : "Esta página irá ser atualizada quando a instância ficar novamente disponível.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte o seu administrador do sistema se esta mensagem persistir ou apareceu inesperadamente.",
-    "The user limit of this instance is reached." : "O limite de utilizador desta instância foi atingido",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "O seu servidor da Web não está configurado corretamente para permitir a sincronização de ficheiros, porque a interface WebDAV parece estar com problemas.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "O seu webserver não está configurado correctamente resolver \"{url}\". Pode encontrar mais informações na documentação {linkstart} ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "O seu servidor web não está configurado correctamente para resolver \"{url}\". Provavelmente, isso está relacionado a uma configuração do servidor web que não foi actualizada para entregar essa pasta directamente. Compare a sua configuração com as regras de reescrita disponibilizadas em \".htaccess\" para Apache ou as fornecida na documentação para Nginx na {linkstart}página de documentação ↗{linkend}. No Nginx essas são normalmente as linhas que começam com \"location ~\" que precisam de uma actualização. ",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "O seu servidor web não está configurado correctamente para entregar arquivos .woff2. Normalmente, esse é um problema com a configuração do Nginx. Para o Nextcloud 15, é necessário um ajuste para entregar também arquivos .woff2. Compare sua configuração Nginx com a configuração recomendada na nossa {linkstart}documentação ↗{linkend}.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não está definido como \"{expected}\". Isto é um potencial risco de segurança ou privacidade, pelo que recomendamos que ajuste esta opção em conformidade.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não está definido como \"{expected}\". Algumas funcionalidades poderão não funcionar correctamente, pelo que recomendamos que ajuste esta opção em conformidade.",
-    "Wrong username or password." : "Nome de utilizador ou palavra passe errados",
-    "User disabled" : "Utilizador desativado",
-    "Username or email" : "Utilizador ou e-mail",
+    "You have not added any info yet" : "Ainda não adicionou qualquer informação ",
+    "Edit Profile" : "Editar perfil",
     "Error loading message template: {error}" : "Ocorreu um erro ao carregar o modelo: {error}",
-    "Users" : "Utilizadores",
-    "Username" : "Nome de utilizador",
-    "Database user" : "Utilizador da base de dados",
-    "This action requires you to confirm your password" : "Esta ação requer a confirmação da senha",
-    "Confirm your password" : "Confirmar senha",
-    "Confirm" : "Confirmar",
-    "App token" : "Token da aplicação",
-    "Alternative log in using app token" : "Autenticação alternativa usando token da aplicação",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Por favor, use o atualizador da linha de comandos porque tem uma instância grande com mais de 50 utilizadores."
+    "Very weak password" : "Palavra-passe muito fraca",
+    "Weak password" : "Palavra-passe fraca",
+    "So-so password" : "Palavra-passe aceitável",
+    "Good password" : "Palavra-passe boa",
+    "Strong password" : "Palavra-passe forte",
+    "Profile not found" : "Perfil não encontrado",
+    "The profile does not exist." : "O perfil não existe.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "A pasta de dados e os respetivos ficheiros estão provavelmente acessíveis a partir da internet pois o ficheiro .htaccess não funciona.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter informações de como configurar corretamente o servidor, veja em: <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentação</a>.",
+    "Show password" : "Mostrar senha",
+    "Toggle password visibility" : "Altere a visibilidade da palavra-passe",
+    "Configure the database" : "Configure a base de dados",
+    "Only %s is available." : "Só está disponível %s."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
