@@ -60,7 +60,7 @@ OC.L10N.register(
     "Update app \"%s\" from App Store" : "Agiorna s'aplicatzione \"%s\" dae sa butega de is aplicatziones",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Averguende si s'ischema de sa base de datos de %s faghet a dd'agiornare (podet trigare segundu sa mannària de sa base de datos)",
     "Updated \"%1$s\" to %2$s" : "Agiornadu \"%1$s\" a %2$s",
-    "Set log level to debug" : "Imposta livellu de registratzione de currègere",
+    "Set log level to debug" : "Cunfigura su livellu de registratzione de currègere",
     "Reset log level" : "Reseta livellu de registratzione",
     "Starting code integrity check" : "Cumintzende su controllu de integridade de còdighe",
     "Finished code integrity check" : "Controllu de integridade de còdighe agabbadu",
@@ -91,55 +91,55 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} notìfica","{count} notìficas"],
     "No" : "No",
     "Yes" : "Eja",
-    "Create share" : "Crea cumpartzidura",
     "Failed to add the public link to your Nextcloud" : "No at fatu a agiùnghere su ligòngiu pùblicu in Nextcloud",
+    "Create share" : "Crea cumpartzidura",
     "Custom date range" : "Perìodu personalizadu",
     "Pick start date" : "Sèbera una data de cumintzu",
     "Pick end date" : "Sèbera una data de acabbu",
     "Search in date range" : "Chirca in su perìodu de datas",
-    "Unified search" : "Chirca unificada",
-    "Search apps, files, tags, messages" : "Chirca in is aplicatziones, archìvios, etichetas e messàgios",
-    "Date" : "Data",
+    "Searching …" : "Chirchende …",
+    "Start typing to search" : "Cumintza a iscrìere pro chircare",
+    "No matching results" : "Nissunu resurtadu",
     "Today" : "Oe ",
     "Last 7 days" : "Ùrtimas 7 dies",
     "Last 30 days" : "Ùrtimas 30 dies",
     "This year" : "Ocannu",
     "Last year" : "S'annu passadu",
+    "Unified search" : "Chirca unificada",
+    "Search apps, files, tags, messages" : "Chirca in is aplicatziones, archìvios, etichetas e messàgios",
+    "Date" : "Data",
     "Search people" : "Chirca persones",
     "People" : "Gente",
     "Results" : "Resurtados",
     "Load more results" : "Càrriga àteros resurtados",
     "Search in" : "Chirca in",
-    "Searching …" : "Chirchende …",
-    "Start typing to search" : "Cumintza a iscrìere pro chircare",
-    "No matching results" : "Nissunu resurtadu",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Intre ${this.dateFilter.startFrom.toLocaleDateString()} e ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Intra",
     "Logging in …" : "Intrende ...",
+    "Log in to {productName}" : "Identìfica·ti in {productName}",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Amus agatadu tentativos meda de atzessu dae s'IP tuo. Duncas s'atzessu tuo imbeniente dd'as a pòdere fàghere intre 30 segundos.",
+    "Account name or email" : "Nùmene de su contu o indiritzu de posta",
     "Server side authentication failed!" : "Autenticatzione de s'ala de su serbidore faddida!",
     "Please contact your administrator." : "Cuntata s'amministratzione.",
-    "Temporary error" : "Errore temporàneu",
-    "Please try again." : "Torra·nce a proare",
     "An internal error occurred." : "B'at àpidu un'errore internu.",
     "Please try again or contact your administrator." : "Torra a proare o cuntata s'amministratzione.",
     "Password" : "Crae",
-    "Log in to {productName}" : "Identìfica·ti in {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Amus agatadu tentativos meda de atzessu dae s'IP tuo. Duncas s'atzessu tuo imbeniente dd'as a pòdere fàghere intre 30 segundos.",
-    "Account name or email" : "Nòmine de su contu o indiritzu de posta",
     "Log in with a device" : "Autentica·ti cun unu dispositivu",
     "Your account is not setup for passwordless login." : "Su contu tuo no est fatu pro autenticatziones chene crae.",
-    "Browser not supported" : "Navigadore non suportadu",
-    "Passwordless authentication is not supported in your browser." : "S'autenticatzione chene crae no est suportada in su navigadore tuo.",
     "Your connection is not secure" : "Sa connessione tua no est segura",
     "Passwordless authentication is only available over a secure connection." : "S'autenticatzione chene crae est a disponimentu isceti cun connessiones seguras.",
+    "Browser not supported" : "Navigadore non suportadu",
+    "Passwordless authentication is not supported in your browser." : "S'autenticatzione chene crae no est suportada in su navigadore tuo.",
     "Reset password" : "Riprìstina sa crae",
+    "Back to login" : "Torra a s'autenticatzione",
     "Couldn't send reset email. Please contact your administrator." : "No at fatu a ripristinare sa posta eletrònica. Cuntata s'amministratzione.",
     "Password cannot be changed. Please contact your administrator." : "Sa crae non faghet a dda cambiare. Cuntata s'amministratzione.",
-    "Back to login" : "Torra a s'autenticatzione",
     "New password" : "Crae noa",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Is archìvios sunt critografados. Non ddoe at a èssere manera pro tènnere is datos a pustis de su riprìstinu de sa crae. Si tenes dudas, cuntata s'amministratzione in antis. A beru boles sighire?",
     "I know what I'm doing" : "Giai dd'isco ite so faghinde",
     "Resetting password" : "Ripristinende sa crae",
+    "Schedule work & meetings, synced with all your devices." : "Programma atividades e addòbios, sincronizados cun is dispositivos tuos.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Mantene is collegas e is amistades tuas in unu logu chene mustrare is datos privados issoro.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicatzione de posta eletrònica simpre e integrada bene cun Archìvios, Cuntatos e Calendàriu.",
     "Recommended apps" : "Aplicatziones racumandadas",
     "Loading apps …" : "Carrighende aplicatziones ...",
     "Could not fetch list of apps from the App Store." : "No at fatu a recuperare sa lista dae sa butega de is aplicatziones.",
@@ -149,11 +149,9 @@ OC.L10N.register(
     "Skip" : "Brinca",
     "Installing apps …" : "Installende aplicatziones ...",
     "Install recommended apps" : "Installa is aplicatziones racumandadas",
-    "Schedule work & meetings, synced with all your devices." : "Programma atividades e addòbios, sincronizados cun is dispositivos tuos.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Mantene is collegas e is amistades tuas in unu logu chene mustrare is datos privados issoro.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicatzione de posta eletrònica simpre e integrada bene cun Archìvios, Cuntatos e Calendàriu.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tzarradas, video mutidas, cumpartzidura de s'ischermu, reuniones in lìnia e vìdeo-cunferèntzias – in su navigadore tuo e cun aplicatziones mòbiles.",
     "Settings menu" : "Menù de cunfiguratzione",
+    "Loading your contacts …" : "Carrighende is cuntatos...",
+    "Looking for {term} …" : "Chirchende {term} …",
     "Search contacts" : "Chirca cuntatos",
     "Reset search" : "Riprìstina chirca",
     "Search contacts …" : "Chirca cuntatos ...",
@@ -161,25 +159,42 @@ OC.L10N.register(
     "No contacts found" : "Perunu cuntatu agatadu",
     "Show all contacts" : "Mustra totu is cuntatos",
     "Install the Contacts app" : "Installa s'aplicatzione de is cuntatos",
-    "Loading your contacts …" : "Carrighende is cuntatos...",
-    "Looking for {term} …" : "Chirchende {term} …",
-    "Search for {name} only" : "Chirca pro {name} ebbia",
-    "Loading more results …" : "Carrighende àteros resurtados ...",
     "Search" : "Chirca",
     "No results for {query}" : "Perunu resurtadu pro {query}",
     "Press Enter to start searching" : "Preme Enter pro cumintzare sa chirca",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Inserta {longàriaMinChirca} o prus caràteres pro chircare","Inserta·nche {minSearchLength} o prus caràteres pro chircare"],
     "An error occurred while searching for {type}" : "B'at àpidu un'errore in sa chirca de {type}",
-    "Forgot password?" : "Crae iscaressida?",
+    "Search for {name} only" : "Chirca pro {name} ebbia",
+    "Loading more results …" : "Carrighende àteros resurtados ...",
+    "Forgot password?" : "As ismentigadu sa crae?",
     "Back to login form" : "Torra a su formulàriu de identificatzione",
     "Back" : "A coa",
     "Login form is disabled." : "Su mòdulu de atzessu est disativadu.",
-    "Edit Profile" : "Modìfica su profilu",
     "More actions" : "Àteras atziones",
+    "Security warning" : "Avisu de seguresa",
+    "Storage & database" : "Depòsitu e base de datos",
+    "Data folder" : "Cartella de datos",
+    "Install and activate additional PHP modules to choose other database types." : "Installa e ativa àteros mòdulos PHP pro seberare àteras genias de base de datos.",
+    "For more details check out the documentation." : "Pro àteros detàllios controlla sa documentatzione.",
+    "Performance warning" : "Avisu de atuatzione",
+    "You chose SQLite as database." : "As seberadu SQLite comente base de datos.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite diat èssere impreadu isceti pro istàntzias mìnimas e de isvilupu. Pro sa produtzione cussigiamus un'àtera base de datos de palas.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Chi impreas clientes pro sa sincronizatzione de is archìvios, SQLite no est cussigiadu pro nudda.",
+    "Database user" : "Utente base de datos",
+    "Database password" : "Crae base de datos",
+    "Database name" : "Nùmene base de datos",
+    "Database tablespace" : "Logu de sa tauledda de sa base de datos",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Ispetzìfica su nùmeru de sa gianna aintru de su nùmene de su retzidore (p.e., retzidorelocale:5432).",
+    "Database host" : "Retzidore de sa base de datos",
+    "Installing …" : "Installende ...",
+    "Install" : "Installa",
+    "Need help?" : "Boles agiudu?",
+    "See the documentation" : "Càstia sa documentatzione",
+    "{name} version {version} and above" : "{name} versione {version} e superiores",
     "This browser is not supported" : "Custu navigadore no est cumpatìbile",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Su navigadore tuo no est cumpatìbile. Atualiza·ddu a una versione noa o càmbia a unu navigadore cumpatìbile.",
     "Continue with this unsupported browser" : "Abarra in custu navigadore non cumpatìbile",
     "Supported versions" : "Versiones cumpatìbiles",
-    "{name} version {version} and above" : "{name} versione {version} e superiores",
     "Search {types} …" : "Chirca {types} …",
     "Choose {file}" : "Sèbera {file}",
     "Choose" : "Sèbera",
@@ -215,11 +230,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Iscrie pro chircare is progetos chi ddoe sunt giai",
     "New in" : "Prima borta in",
     "View changelog" : "Càstia su registru de is càmbios",
-    "Very weak password" : "Crae dèbile meda",
-    "Weak password" : "Crae dèbile",
-    "So-so password" : "Crae aici aici",
-    "Good password" : "Crae bona",
-    "Strong password" : "Crae bona a beru",
     "No action available" : "Peruna atzione a disponimentu",
     "Error fetching contact actions" : "Errore in su recùperu de is atziones de cuntatu",
     "Close \"{dialogTitle}\" dialog" : "Serra su cuadru de diàlogu \"{dialogTitle}\"",
@@ -234,14 +244,11 @@ OC.L10N.register(
     "Admin" : "Amministratzione",
     "Help" : "Agiudu",
     "Access forbidden" : "Atzessu proibidu",
-    "Profile not found" : "Profilu no agatadu",
-    "The profile does not exist." : "Su profilu no esistit.",
-    "Back to %s" : "A coa a %s",
     "Page not found" : "Pàgina no agatada",
+    "Back to %s" : "A coa a %s",
     "Too many requests" : "Tropu dimandas",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Tropu rechestas sunt arribadas dae sa rete tua. Torra a proare prus a tardu o cuntata s'amministradore tuo chi ddoe at un'errore.",
     "Error" : "Errore",
-    "Previous" : "Pretzedente",
     "Internal Server Error" : "Errore serbidore internu",
     "The server was unable to complete your request." : "Su serbidore no at pòdidu cumpletare sa rechesta tua.",
     "If this happens again, please send the technical details below to the server administrator." : "Si torrat a capitare, imbia is detàllios tècnicos in bàsciu a s'amministratzione de su serbidore.",
@@ -255,31 +262,6 @@ OC.L10N.register(
     "File: %s" : "Archìviu: %s",
     "Line: %s" : "Lìnia: %s",
     "Trace" : "Arrasta",
-    "Security warning" : "Avisu de seguresa",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is cartellas de datos e is archìvios tuos fortzis sunt atzessìbiles dae s'internet ca s'archìviu .htaccess no est funtzionende.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pro informatziones subra de comente cunfigurare su serbidore tuo, càstia in sa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatzione</a>.",
-    "Create an <strong>admin account</strong>" : "Crea unu <strong>contu de amministratzione</strong>",
-    "Show password" : "Mustra crae",
-    "Toggle password visibility" : "Càmbia sa visibilidade de sa crae",
-    "Storage & database" : "Depòsitu e base de datos",
-    "Data folder" : "Cartella de datos",
-    "Configure the database" : "Cunfigura sa base de datos",
-    "Only %s is available." : "%s isceti est a disponimentu.",
-    "Install and activate additional PHP modules to choose other database types." : "Installa e ativa àteros mòdulos PHP pro seberare àteras genias de base de datos.",
-    "For more details check out the documentation." : "Pro àteros detàllios controlla sa documentatzione.",
-    "Database password" : "Crae base de datos",
-    "Database name" : "Nùmene base de datos",
-    "Database tablespace" : "Logu de sa tauledda de sa base de datos",
-    "Database host" : "Retzidore de sa base de datos",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Ispetzìfica su nùmeru de sa gianna aintru de su nùmene de su retzidore (p.e., retzidorelocale:5432).",
-    "Performance warning" : "Avisu de atuatzione",
-    "You chose SQLite as database." : "As seberadu SQLite comente base de datos.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite diat èssere impreadu isceti pro istàntzias mìnimas e de isvilupu. Pro sa produtzione cussigiamus un'àtera base de datos de palas.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Chi impreas clientes pro sa sincronizatzione de is archìvios, SQLite no est cussigiadu pro nudda.",
-    "Install" : "Installa",
-    "Installing …" : "Installende ...",
-    "Need help?" : "Boles agiudu?",
-    "See the documentation" : "Càstia sa documentatzione",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Paret chi ses chirchende de torrare a installare Nextcloud. In cada manera, mancat s'archìviu CAN_INSTALL in sa cartella de cunfiguratzione. Crea s'archìviu CAN_INSTALL in sa cartella de cunfiguratzione pro sighire.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "No at fatu a nche bogare CAN_INSTALL dae sa cartella de cunfiguratzione. Boga custu archìviu a manu.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Custa aplicatzione rechedet JavaScript pro un'operatzione curreta. {linkstart} Ativa JavaScript{linkend} e torra a carrigare sa pàgina.",
@@ -288,8 +270,8 @@ OC.L10N.register(
     "Go to %s" : "Bae a %s",
     "Get your own free account" : "Otene su contu tuo a gratis",
     "Connect to your account" : "Connete·ti a su contu tuo",
-    "Please log in before granting %1$s access to your %2$s account." : "Faghe s'atzessu prima de permìtere a %1$s de intrare a su %2$s contu tuo.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Chi non ses chirchende de impostare unu dispositivu o un'aplicatzione noa, calecunu est proende a si fàghere dare atzessu a is datos tuos. In custu casu, no sigast e cuntata s'amministradore de sistema tuo.",
+    "Please log in before granting %1$s access to your %2$s account." : "Faghe s'atzessu prima de permìtere a %1$s de intrare a su contu tuo de %2$s.",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si non ses chirchende de cunfigurare unu dispositivu o un'aplicatzione noa, un'àtera persone est proende a si fàghere dare atzessu a is datos tuos. In custu casu, non sigas e cuntata s'amministratzione de su sistema tuo.",
     "App password" : "Crae de s'aplicatzione",
     "Grant access" : "Dona atzessu",
     "Alternative log in using app password" : "Identificatzione alternativa cun crae de s'aplicatzione",
@@ -298,6 +280,7 @@ OC.L10N.register(
     "Account connected" : "Contu collegadu",
     "Your client should now be connected!" : "Su cliente tuo immoe diat dèpere èssere collegadu!",
     "You can close this window." : "Podes serrare custa ventana",
+    "Previous" : "Pretzedente",
     "This share is password-protected" : "Custa cumpartzidura est amparada dae una crae",
     "Email address" : "Indiritzu de posta eletrònica",
     "Password sent!" : "Crae imbiada.",
@@ -310,7 +293,7 @@ OC.L10N.register(
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "S'est imposta s'autenticatzione a duos fatores ma non s'est cunfigurada in su contu tuo. Pro intrare imprea unu de is còdighes pro sa còpia de seguresa o cuntata s'amministratzione.",
     "Use backup code" : "Imprea su còdighe de sa còpia de seguresa",
     "Cancel login" : "Annulla atzessu",
-    "Enhanced security is enforced for your account. Choose which provider to set up:" : "S'est impostu unu megioru de seguresa in su contu tuo. Sèbera su frunidore chi boles impostare:",
+    "Enhanced security is enforced for your account. Choose which provider to set up:" : "S'est impostu unu megioru de seguresa in su contu tuo. Sèbera su frunidore chi boles cunfigurare:",
     "Error while validating your second factor" : "Errore in sa validatzione de su seguntu fatore tuo",
     "Access through untrusted domain" : "Atzessu cun domìniu non seguru",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php.",
@@ -329,33 +312,28 @@ OC.L10N.register(
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Giai dd'isco ca chi sigu cun s'agiornamentu via internet UI ddoe at s'arriscu chi sa rechesta arribet a una pasada e podet causare sa pèrdida de is datos, ma tèngio una còpia de seguresa e isco comente recuperare s'istàntzia in casu de errore.",
     "Upgrade via web on my own risk" : "Agiorna via web suta responsabilidade mia",
     "Maintenance mode" : "Modalidade de mantenidura",
-    "This %s instance is currently in maintenance mode, which may take a while." : "Immoe custa %s istàntzia est in modalidade de mantenidura, e podet trigare unu pagu.",
+    "This %s instance is currently in maintenance mode, which may take a while." : "Immoe custa istàntzia de %s est in modalidade de mantenidura, e podet trigare unu pagu.",
     "This page will refresh itself when the instance is available again." : "Custa pàgina s'at a atualizare cando s'istàntzia at a èssere torra a disponimentu.",
-    "Contact your system administrator if this message persists or appeared unexpectedly." : "Cuntata s'amministratzione de sistema si custu messàgiu abarrat o torrat a cumpàrrere",
-    "The user limit of this instance is reached." : "S'est lòmpidu su lìmite de utèntzia pro custa istàntzia.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Su serbidore tuo no est impostadu pro permìtere sa sincronizatzione de is archìvios, ca s'interfache WebDAV paret arrogada.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Si serbidore tuo no est impostadu pro risòlvere \"{url}\". Podes agatare àteras informatziones in sa {linkstart} documentatzione ↗{linkend}..",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Su serbidore internet tuo no est cunfiguradu comente si depet pro resòlvere \"{url}\". Est probàbile chi custu dipendat dae una cunfiguratzione de su serbidore no agiornada pro cunsignare deretu custa cartella. Cunfronta sa cunfiguratzione tua cun is règulas de re-iscritura imbiadas in \".htaccess\" pro Apache o cussa frunida in sa documentatzione pro Nginx in sa  {linkstart}pàgina de documentatzione ↗{linkend}. In Nginx giai semper sunt is lìneas chi incarrerant cun \"location ~\" chi tenent bisòngiu de un'agiornamentu.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Su serbidore internet tuo no est cunfiguradu comente si depet pro produire archìvios .woff2. Custu est giai semper unu problema de sa cunfiguratzione Nginx. Pro Nextcloud 15 tocat de dd'adecuare pro produire puru archìvios .woff2. Cunfronta sa cunfiguratzione Nginx tua cun sa cunfiguratzione cussigiada in sa {linkstart}documentation ↗{linkend} nostra.",
-    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Ses faghende s'atzessu a s'istàntzia dae una connessione segura, ma in cada manera s'istàntzia est generende URLs no seguros. Est meda probàbile chi siast a palas de unu serbidore intermèdiu e is variàbiles de sa cunfiguratzione de sa subra-iscritura no siant impostadas in sa manera curreta. Leghe {linkstart}sa pàgina de sa documentatzione subra de custu ↗{linkend}.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "S'intestatzione HTTP \"{header}\" no est cunfigurada comente \"{expected}\". Custu est un'arriscu possìbile de seguresa o riservadesa, tando est cussigiadu a arrangiare custa cunfiguratzione.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "S'intestatzione HTTP \"{header}\" no est cunfigurada comente \"{expected}\". Calicunu elementu diat pòdere no funtzionare in sa manera curreta, tando est cussigiadu a arrangiare custa cunfiguratzione.",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "S'intestatzione HTTP \"{header}\" no est impostada cun \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" o \"{val5}\". Custu podet fàghere essire informatziones de s'orìgine. Càstia sa {linkstart}W3C 1Racumandatzione ↗{linkend}.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "S'intestatzione HTTP \"Seguresa-Strinta-deTràmuda\" no est impostada pro a su mancu \"{seconds}\" segundos. Pro megiorare sa seguresa, est cussigiadu a ativare HSST comente descritu in is {linkstart}impòsitos de seguresa ↗{linkend}.",
+    "Contact your system administrator if this message persists or appeared unexpectedly." : "Cuntata s'amministratzione de sistema si custu messàgiu abarrat o torrat a cumpàrrere.",
     "Currently open" : "Abertos immoe",
-    "Wrong username or password." : "Nùmene utente o crae isballiada.",
-    "User disabled" : "Utèntzia disativada",
-    "Username or email" : "Nùmene utente o indiritzu de posta",
-    "Apps and Settings" : "Aplicatziones e cunfiguratziones",
+    "Login with username or email" : "Atzede cun nùmene de utente o indiritzu de posta eletrònica",
+    "Login with username" : "Atzede cun nùmene de utente",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tzarradas, video mutidas, cumpartzidura de s'ischermu, reuniones in lìnia e vìdeo-cunferèntzias – in su navigadore tuo e cun aplicatziones mòbiles.",
+    "Edit Profile" : "Modìfica su profilu",
+    "The headline and about sections will show up here" : "Is setziones de tìtulu e informatziones ant a èssere ammustradas inoghe",
     "Error loading message template: {error}" : "Errore in su carrigamentu de su modellu de messàgiu: {error}",
-    "Users" : "Utentes",
-    "Username" : "Nùmene utente",
-    "Database user" : "Utente base de datos",
-    "This action requires you to confirm your password" : "Pro custa atzione ti tocat de cunfirmare sa crae",
-    "Confirm your password" : "Cunfirma sa crae",
-    "Confirm" : "Cunfirma",
-    "App token" : "Autenticadore de s'aplicatzione",
-    "Alternative log in using app token" : "Atzessu alternativu cun s'autenticadore de s'aplicatzione",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Imprea s'atualizadore a lìnia de cummandu ca tenes un'istàntzia manna cun prus de 50 utentes."
+    "Very weak password" : "Crae dèbile meda",
+    "Weak password" : "Crae dèbile",
+    "So-so password" : "Crae aici aici",
+    "Good password" : "Crae bona",
+    "Strong password" : "Crae bona a beru",
+    "Profile not found" : "Profilu no agatadu",
+    "The profile does not exist." : "Su profilu no esistit.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is cartellas de datos e is archìvios tuos fortzis sunt atzessìbiles dae s'internet ca s'archìviu .htaccess no est funtzionende.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pro informatziones subra de comente cunfigurare su serbidore tuo, càstia in sa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatzione</a>.",
+    "Show password" : "Mustra crae",
+    "Toggle password visibility" : "Càmbia sa visibilidade de sa crae",
+    "Configure the database" : "Cunfigura sa base de datos",
+    "Only %s is available." : "%s isceti est a disponimentu."
 },
 "nplurals=2; plural=(n != 1);");
