@@ -52,6 +52,7 @@ OC.L10N.register(
     "Avatar image is not square" : "Η εικόνα του άβαταρ δεν είναι τετράγωνη",
     "Files" : "Αρχεία",
     "View profile" : "Προβολή προφίλ",
+    "_%nh_::_%nh_" : ["%nω","%nω"],
     "Local time: %s" : "Τοπική ώρα: %s",
     "today" : "σήμερα",
     "tomorrow" : "αύριο",
@@ -106,10 +107,10 @@ OC.L10N.register(
     "Headline" : "Τίτλος",
     "Organisation" : "Οργανισμός",
     "Role" : "Ρόλος/Θέση",
+    "Pronouns" : "Αντωνυμίες",
     "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
     "You need to enter details of an existing account." : "Χρειάζεται να εισάγετε λεπτομέρειες από υπάρχοντα λογαριασμό.",
     "Oracle connection could not be established" : "Αδυναμία σύνδεσης Oracle",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Το Mac OS X δεν υποστηρίζεται και το %s δεν θα λειτουργήσει σωστά σε αυτή την πλατφόρμα. Χρησιμοποιείτε με δική σας ευθύνη!",
     "For the best results, please consider using a GNU/Linux server instead." : "Για καλύτερα αποτελέσματα, παρακαλούμε εξετάστε την μετατροπή σε έναν διακομιστή GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Φαίνεται ότι η εγκατάσταση %s εκτελείται σε περιβάλλον 32-bit PHP και η επιλογή open_basedir έχει ρυθμιστεί στο αρχείο php.ini. Αυτό θα οδηγήσει σε προβλήματα με αρχεία πάνω από 4 GB και δεν συνίσταται.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Παρακαλούμε αφαιρέστε την ρύθμιση open_basedir μέσα στο αρχείο php.ini ή αλλάξτε σε 64-bit PHP.",
@@ -118,14 +119,8 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Το σύστημα διαμοιρασμού %s πρέπει να υλοποιεί την διεπαφή OCP\\Share_Backend",
     "Sharing backend %s not found" : "Το σύστημα διαμοιρασμού %s δεν βρέθηκε",
     "Sharing backend for %s not found" : "Το σύστημα διαμοιρασμού για το %s δεν βρέθηκε",
-    "%1$s shared »%2$s« with you" : "Ο/η %1$s διαμοιράστηκε το »%2$s« με εσάς.",
-    "%1$s shared »%2$s« with you." : "Ο/η %1$s διαμοιράστηκε »%2$s« με εσάς.",
-    "Click the button below to open it." : "Κάντε κλικ στο παρακάτω κουμπί για να το ανοίξετε.",
-    "Open »%s«" : "Άνοιγμα »%s«",
+    "Open %s" : "Άνοιγμα %s",
     "%1$s via %2$s" : "%1$s μέσω %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "Ο %1$s διαμοιράστηκε το »%2$s« με εσάς και θέλει να προσθέσει:",
-    "%1$s shared »%2$s« with you and wants to add" : "Ο %1$s διαμοιράστηκε το »%2$s« με εσάς και θέλει να προσθέσει",
-    "»%s« added a note to a file shared with you" : "Ο »%s« πρόσθεσε μια σημείωση στο κοινόχρηστο αρχείο",
     "Unknown share type" : "Άγνωστος τύπος διαμοιρασμού",
     "You are not allowed to share %s" : "Δεν σας επιτρέπεται ο διαμοιρασμός %s",
     "Cannot increase permissions of %s" : "Αδυναμία αύξησης των δικαιωμάτων του/της %s",
@@ -136,6 +131,7 @@ OC.L10N.register(
     "Sharing is only allowed with group members" : "Η κοινή χρήση επιτρέπεται μόνο με μέλη της ομάδας",
     "The requested share does not exist anymore" : "Το διαμοιρασμένο που ζητήθηκε δεν υπάρχει πλέον",
     "Could not find category \"%s\"" : "Αδυναμία εύρεσης κατηγορίας \"%s\"",
+    "Input text" : "Κείμενο εισόδου",
     "Sunday" : "Κυριακή",
     "Monday" : "Δευτέρα",
     "Tuesday" : "Τρίτη",
@@ -185,8 +181,6 @@ OC.L10N.register(
     "Login canceled by app" : "Η είσοδος ακυρώθηκε από την εφαρμογή",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Η εφαρμογή \"%1$s\" δεν μπορεί να εγκατασταθεί επειδή δεν πληρούνται τα προαπαιτούμενα: %2$s",
     "a safe home for all your data" : "ένα ασφαλές μέρος για όλα τα δεδομένα σας",
-    "File is currently busy, please try again later" : "Το αρχείο χρησιμοποιείται αυτή τη στιγμή, παρακαλούμε προσπαθήστε αργότερα",
-    "Cannot download file" : "Δεν είναι δυνατή η λήψη του αρχείου",
     "Application is not enabled" : "Δεν ενεργοποιήθηκε η εφαρμογή",
     "Authentication error" : "Σφάλμα πιστοποίησης",
     "Token expired. Please reload page." : "Το αναγνωριστικό έληξε. Παρακαλούμε φορτώστε ξανά την σελίδα.",
@@ -227,33 +221,32 @@ OC.L10N.register(
     "Storage connection error. %s" : "Σφάλμα σύνδεσης με αποθηκευτικό χώρο. %s",
     "Storage is temporarily not available" : "Ο χώρος αποθήκευσης δεν είναι διαθέσιμος προσωρινά",
     "Storage connection timeout. %s" : "Λήξη χρονικού ορίου σύνδεσης με αποθηκευτικό χώρο.%s",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Για να επιτρέψετε αυτόν τον έλεγχο, πρέπει να βεβαιωθείτε ότι ο διακομιστής σας μπορεί να συνδεθεί με τον εαυτό του. Επομένως, πρέπει να μπορεί να επιλύσει και να συνδεθεί με τουλάχιστον ένα από τα `trusted_domains` ή το `overwrite.cli.url`. Αυτή η αποτυχία μπορεί να οφείλεται σε αντιστοιχία DNS από την πλευρά του διακομιστή ή σε κανόνα τείχους προστασίας εξερχομένων.",
+    "Confirmation" : "Επιβεβαίωση",
+    "Generated response" : "Δημιουργημένη απάντηση",
+    "Change Tone" : "Αλλαγή Τόνου",
+    "Write a text that you want the assistant to rewrite in another tone." : "Γράψτε ένα κείμενο που θέλετε ο βοηθός να ξαναγράψει σε διαφορετικό τόνο.",
+    "Desired tone" : "Επιθυμητός τόνος",
+    "In which tone should your text be rewritten?" : "Σε ποιον τόνο πρέπει να ξαναγραφεί το κείμενό σας;",
+    "The rewritten text in the desired tone, written by the assistant:" : "Το ξαναγραμμένο κείμενο στον επιθυμητό τόνο, γραμμένο από τον βοηθό:",
+    "Text" : "Κείμενο",
     "Summary" : "Σύνοψη",
     "Translate" : "Μετάφραση",
     "Result" : "Αποτέλεσμα",
     "Education Edition" : "Εκπαιδευτική Έκδοση",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Ο συνδεδεμένος χρήστης πρέπει να είναι διαχειριστής, υποδιαχειριστής ή να έχει ειδικό δικαίωμα πρόσβασης σε αυτήν τη ρύθμιση",
-    "Logged in user must be an admin or sub admin" : "Ο συνδεδεμένος χρήστης πρέπει να είναι admin ή subadmin",
-    "Logged in user must be an admin" : "Ο συνδεδεμένος χρήστης πρέπει να είναι διαχειριστής",
     "File name is a reserved word" : "Το όνομα αρχείου είναι λέξη που έχει δεσμευτεί",
     "File name contains at least one invalid character" : "Το όνομα αρχείου περιέχει έναν τουλάχιστον μη έγκυρο χαρακτήρα",
     "File name is too long" : "Το όνομα αρχείου είναι πολύ μεγάλο",
-    "Help" : "Βοήθεια",
     "Users" : "Χρήστες",
-    "Unknown user" : "Άγνωστος χρήστης",
-    "MySQL username and/or password not valid" : "Το όνομα χρήστη και/'η ο κωδικός πρόσβασης MySQL δεν είναι σωστά",
-    "Oracle username and/or password not valid" : "Μη έγκυρος χρήστης και/ή συνθηματικό της Oracle",
-    "PostgreSQL username and/or password not valid" : "Μη έγκυρος χρήστης και/ή συνθηματικό της PostgreSQL",
-    "Set an admin username." : "Εισάγετε όνομα χρήστη διαχειριστή.",
-    "Sharing %s failed, because this item is already shared with user %s" : "Η κοινή χρήση του %s απέτυχε, επειδή αυτό το στοιχείο είναι ήδη κοινόχρηστο με τον χρήστη %s",
-    "The username is already being used" : "Το όνομα χρήστη είναι κατειλημμένο",
-    "Could not create user" : "Αδυναμία δημιουργίας χρήστη",
-    "A valid username must be provided" : "Πρέπει να δοθεί έγκυρο όνομα χρήστη",
-    "Username contains whitespace at the beginning or at the end" : "Το όνομα χρήστη περιέχει κενό διάστημα στην αρχή ή στο τέλος",
-    "Username must not consist of dots only" : "Το όνομα χρήστη δεν πρέπει να περιέχει μόνο τελείες",
-    "Username is invalid because files already exist for this user" : "Το όνομα χρήστη δεν είναι έγκυρο, επειδή υπάρχουν ήδη αρχεία για αυτόν τον χρήστη",
-    "User disabled" : "Ο χρήστης απενεργοποιήθηκε",
-    "Your data directory is readable by other users." : "Ο κατάλογος δεδομένων σας είναι αναγνώσιμος από άλλους χρήστες.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Παρακαλούμε αλλάξτε τις ρυθμίσεις σε 0770 έτσι ώστε ο κατάλογος να μην μπορεί να προβάλλεται από άλλους χρήστες.",
+    "%1$s shared »%2$s« with you and wants to add:" : "Ο %1$s διαμοιράστηκε το »%2$s« με εσάς και θέλει να προσθέσει:",
+    "%1$s shared »%2$s« with you and wants to add" : "Ο %1$s διαμοιράστηκε το »%2$s« με εσάς και θέλει να προσθέσει",
+    "»%s« added a note to a file shared with you" : "Ο »%s« πρόσθεσε μια σημείωση στο κοινόχρηστο αρχείο",
+    "Open »%s«" : "Άνοιγμα »%s«",
+    "%1$s shared »%2$s« with you" : "Ο/η %1$s διαμοιράστηκε το »%2$s« με εσάς.",
+    "%1$s shared »%2$s« with you." : "Ο/η %1$s διαμοιράστηκε »%2$s« με εσάς.",
+    "Click the button below to open it." : "Κάντε κλικ στο παρακάτω κουμπί για να το ανοίξετε.",
+    "File is currently busy, please try again later" : "Το αρχείο χρησιμοποιείται αυτή τη στιγμή, παρακαλούμε προσπαθήστε αργότερα",
+    "Cannot download file" : "Δεν είναι δυνατή η λήψη του αρχείου",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Εξασφαλίστε ότι υπάρχει ένα αρχείο με όνομα \".ocdata\" στον βασικό κατάλογο του καταλόγου δεδομένων."
 },
 "nplurals=2; plural=(n != 1);");
