@@ -65,7 +65,6 @@ OC.L10N.register(
     "Additional settings" : "Configuraciones adicionales",
     "You need to enter details of an existing account." : "Necesitas ingresar los detalles de una cuenta existente.",
     "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "OS X de Mac no está soportado y %s no funcionará correctamente en esta plataforma ¡Úsalo bajo tu propio riesgo!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para mejores resultados, por favor cosidera usar en su lugar un servidor GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Al parecer esta instancia %s está corriendo en un ambiente PHP de 32-bits y el open_basedir ha sido configurado en el archivo php.ini. Esto generará problemas con archivos de más de 4GB de tamaño y es altamente desalentado. ",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor elimina el ajuste open_basedir de tu archivo php.ini o cambia a PHP de 64 bits. ",
@@ -73,8 +72,6 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "No fue encontrado el Backend que comparte %s ",
     "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
-    "Click the button below to open it." : "Haz click en el botón inferior para abrirlo. ",
-    "Open »%s«" : "Abrir »%s«",
     "Unknown share type" : "Tipo de elemento compartido desconocido",
     "You are not allowed to share %s" : "No tienes permitido compartir %s",
     "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
@@ -129,7 +126,6 @@ OC.L10N.register(
     "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
     "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
     "a safe home for all your data" : "un lugar seguro para todos tus datos",
-    "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, por favor intentalo más tarde. ",
     "Application is not enabled" : "La aplicación está deshabilitada",
     "Authentication error" : "Error de autenticación",
     "Token expired. Please reload page." : "La ficha ha expirado. Por favor recarga la página.",
@@ -148,28 +144,18 @@ OC.L10N.register(
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
+    "Text" : "Texto",
     "Summary" : "Resumen",
     "Translate" : "Traducir",
     "Result" : "Resultado",
     "Education Edition" : "Edición Educativa",
-    "Logged in user must be an admin" : "El usuario firmado debe ser un administrador",
     "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
     "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
     "File name is too long" : "El nombre del archivo es demasiado largo",
-    "Help" : "Ayuda",
     "Users" : "Usuarios",
-    "Unknown user" : "Ususario desconocido",
-    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
-    "PostgreSQL username and/or password not valid" : "El Usuario y/o Contraseña de PostgreSQL inválido(s)",
-    "Set an admin username." : "Establecer un Usuario administrador",
-    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
-    "The username is already being used" : "Ese usuario ya está en uso",
-    "Could not create user" : "No fue posible crear el usuario",
-    "A valid username must be provided" : "Debes proporcionar un nombre de usuario válido",
-    "Username contains whitespace at the beginning or at the end" : "El usuario contiene un espacio en blanco al inicio o al final",
-    "Username must not consist of dots only" : "El usuario no debe consistir de solo puntos. ",
-    "User disabled" : "Usuario deshabilitado",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambia los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. ",
+    "Open »%s«" : "Abrir »%s«",
+    "Click the button below to open it." : "Haz click en el botón inferior para abrirlo. ",
+    "File is currently busy, please try again later" : "El archivo se encuentra actualmente en uso, por favor intentalo más tarde. ",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegurate de que exista una archivo llamado \".ocdata\" en la raíz del directorio de datos. "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
