@@ -118,7 +118,6 @@ OC.L10N.register(
     "You cannot use dots in the database name %s" : "데이터베이스 이름에 점(.)을 사용할 수 없습니다 %s",
     "You need to enter details of an existing account." : "존재하는 계정 정보를 입력해야 합니다.",
     "Oracle connection could not be established" : "Oracle 연결을 수립할 수 없습니다.",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X은 지원하지 않으며 %s이(가) 이 플랫폼에서 올바르게 작동하지 않을 수도 있습니다. 본인 책임으로 사용하십시오! ",
     "For the best results, please consider using a GNU/Linux server instead." : "더 좋은 결과를 얻으려면 GNU/Linux 서버를 사용하는 것을 권장합니다.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "%s 인스턴스가 32비트 PHP 환경에서 실행 중이고 php.ini에 open_basedir이 설정되어 있습니다. 4GB 이상의 파일 처리에 문제가 생길 수 있으므로 추천하지 않습니다.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini의 open_basedir 설정을 삭제하거나 64비트 PHP로 전환하십시오.",
@@ -127,14 +126,7 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "공유 백엔드 %s에서 OCP\\Share_Backend 인터페이스를 구현해야 함",
     "Sharing backend %s not found" : "공유 백엔드 %s을(를) 찾을 수 없음",
     "Sharing backend for %s not found" : "%s의 공유 백엔드를 찾을 수 없음",
-    "%1$s shared »%2$s« with you" : "%1$s 님이 »%2$s« 항목을 공유했습니다",
-    "%1$s shared »%2$s« with you." : "%1$s 님이 »%2$s« 항목을 공유했습니다",
-    "Click the button below to open it." : "아래 단추를 눌러서 열 수 있습니다.",
-    "Open »%s«" : "%s 열기",
     "%1$s via %2$s" : "%1$s(%2$s 경유)",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s님이 %2$s을(를) 당신과 공유하며, 다음을 추가하고자 함:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s님이 %2$s을(를) 당신과 공유하며 다음을 추가하고자 함",
-    "»%s« added a note to a file shared with you" : "%s님이 당신과 공유한 파일에 메모를 추가함",
     "Unknown share type" : "알 수 없는 공유 형식",
     "You are not allowed to share %s" : "%s을(를) 공유할 수 있는 권한이 없습니다",
     "Cannot increase permissions of %s" : "%s의 권한을 늘릴 수 없습니다.",
@@ -199,8 +191,6 @@ OC.L10N.register(
     "Login canceled by app" : "앱에서 로그인 취소함",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "앱 \"%1$s\"이(가) 다음 의존성을 만족하지 않아 설치될 수 없습니다: %2$s",
     "a safe home for all your data" : "내 모든 데이터의 안전한 저장소",
-    "File is currently busy, please try again later" : "파일이 현재 사용 중, 나중에 다시 시도하십시오",
-    "Cannot download file" : "파일을 다운로드할 수 없음",
     "Application is not enabled" : "앱이 활성화되지 않았습니다",
     "Authentication error" : "인증 오류",
     "Token expired. Please reload page." : "토큰이 만료되었습니다. 페이지를 새로 고치십시오.",
@@ -243,6 +233,7 @@ OC.L10N.register(
     "Storage is temporarily not available" : "저장소를 임시로 사용할 수 없음",
     "Storage connection timeout. %s" : "저장소 연결 시간이 초과되었습니다. %s",
     "Audio input" : "음성 입력",
+    "Confirmation" : "확인",
     "Context write" : "컨텍스트 쓰기",
     "Writes text in a given style based on the provided source material." : "제공된 소스 자료를 기반으로 특정 스타일로 텍스트를 작성합니다.",
     "Writing style" : "작문 스타일",
@@ -251,6 +242,7 @@ OC.L10N.register(
     "Prompt" : "프롬프트",
     "Chat" : "대화",
     "Generates a possible headline for a text." : "내용에 대한 헤드라인을 생성하십시오.",
+    "Text" : "텍스트",
     "Summarize" : "요약",
     "Summary" : "요약",
     "Extract topics" : "주제 추출",
@@ -260,32 +252,19 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "중요 정보로 내용을 축약하십시오.",
     "Extracts topics from a text and outputs them separated by commas." : "내용에서 주요 주제를 추출하고 쉼표로 이를 구분하십시오.",
     "Education Edition" : "교육용 에디션",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "로그인된 사용자가 관리자, 부 관리자, 또는 이 설정에 접근할 수 있는 권한을 부여받은 사용자일 것입니다.",
-    "Logged in user must be an admin or sub admin" : "로그인한 사용자는 관리자 또는 부 관리자여야 합니다.",
-    "Logged in user must be an admin" : "로그인한 사용자는 관리자여야 합니다.",
     "File name is a reserved word" : "파일 이름이 예약된 단어임",
     "File name contains at least one invalid character" : "파일 이름에 잘못된 글자가 한 자 이상 있음",
     "File name is too long" : "파일 이름이 너무 김",
-    "Help" : "도움말",
     "Users" : "사용자",
-    "Unknown user" : "알려지지 않은 사용자",
-    "Enter the database username and name for %s" : "%s에 대한 데이터베이스 사용자 이름과 이름을 입력하십시오",
-    "Enter the database username for %s" : "%s에 대한 데이터베이스 사용자 이름을 입력하십시오",
-    "MySQL username and/or password not valid" : "MySQL 사용자 이름 또는 암호가 잘못되었습니다",
-    "Oracle username and/or password not valid" : "Oracle 사용자 이름이나 암호가 잘못되었습니다.",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL 사용자 이름 또는 암호가 잘못되었습니다",
-    "Set an admin username." : "관리자의 사용자 이름을 설정합니다.",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s을(를) 공유할 수 없습니다. 이 항목을 이미 %s 님과 공유하고 있습니다",
-    "The username is already being used" : "사용자 이름이 이미 존재합니다",
-    "Could not create user" : "사용자를 만들 수 없습니다",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "사용자 이름에는 다음 문자만 사용할 수 있습니다: \"a-z, \"A-Z\", \"0-9\", 공백, \"_.@-'\"",
-    "A valid username must be provided" : "올바른 사용자 이름을 입력해야 합니다",
-    "Username contains whitespace at the beginning or at the end" : "사용자 이름의 시작이나 끝에 공백이 있습니다",
-    "Username must not consist of dots only" : "사용자 이름에 마침표만 있으면 안 됩니다",
-    "Username is invalid because files already exist for this user" : "무효한 사용자이름. 이미 존재함",
-    "User disabled" : "사용자 비활성화됨",
-    "Your data directory is readable by other users." : "현재 데이터 디렉토리를 다른 사람이 읽을 수 있습니다.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "권한을 0770으로 변경하여 다른 사용자가 읽을 수 없도록 하십시오.",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s님이 %2$s을(를) 당신과 공유하며, 다음을 추가하고자 함:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s님이 %2$s을(를) 당신과 공유하며 다음을 추가하고자 함",
+    "»%s« added a note to a file shared with you" : "%s님이 당신과 공유한 파일에 메모를 추가함",
+    "Open »%s«" : "%s 열기",
+    "%1$s shared »%2$s« with you" : "%1$s 님이 »%2$s« 항목을 공유했습니다",
+    "%1$s shared »%2$s« with you." : "%1$s 님이 »%2$s« 항목을 공유했습니다",
+    "Click the button below to open it." : "아래 단추를 눌러서 열 수 있습니다.",
+    "File is currently busy, please try again later" : "파일이 현재 사용 중, 나중에 다시 시도하십시오",
+    "Cannot download file" : "파일을 다운로드할 수 없음",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "데이터 디렉터리의 최상위 디렉터리에 \".ocdata\" 파일이 있는지 확인하십시오."
 },
 "nplurals=1; plural=0;");
