@@ -51,6 +51,7 @@ OC.L10N.register(
     "Avatar image is not square" : "Slika podobe ni kvadratna",
     "Files" : "Datoteke",
     "View profile" : "Pokaži profil",
+    "_%nh_::_%nh_" : ["%nh","%nh","%nh","%nh"],
     "Local time: %s" : "Krajevni čas: %s",
     "today" : "danes",
     "tomorrow" : "jutri",
@@ -74,6 +75,7 @@ OC.L10N.register(
     "Empty file" : "Prazna datoteka",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul z ID: %s ne obstaja. Omogočite ga med nastavitvami, ali pa stopite v stik s skrbnikom sistema.",
     "Dot files are not allowed" : "Skrite datoteke niso dovoljene",
+    "Filenames must not end with \"%1$s\"." : "Imena datotek se naj ne končajo s \"%1$s\".",
     "File already exists" : "Datoteka že obstaja",
     "Invalid path" : "Neveljavna pot",
     "Failed to create file from template" : "Ustvarjanje datoteke iz predloge je spodletelo",
@@ -113,7 +115,6 @@ OC.L10N.register(
     "You cannot use dots in the database name %s" : "V imenu podatkovne zbirke %s ni dovoljeno uporabljati pik.",
     "You need to enter details of an existing account." : "Vpisati je treba podrobnosti obstoječega računa.",
     "Oracle connection could not be established" : "Povezave s sistemom Oracle ni mogoče vzpostaviti.",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Sistem Mac OS X ni podprt, zato %s v tem okolju ne bo deloval zanesljivo. Program uporabljate na lastno odgovornost! ",
     "For the best results, please consider using a GNU/Linux server instead." : "Za najboljše rezultate je priporočljivo uporabljati strežnik GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Kaže, da je dejavna seja %s zagnana v 32-bitnem okolju PHP in, da je v datoteki php.ini nastavljen open_basedir . Tako delovanje ni priporočljivo, saj se lahko pojavijo težave z datotekami, večjimi od 4GB.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraniti je treba nastavitev open_basedir v datoteki php.ini ali pa preklopiti na 64-bitno okolje PHP.",
@@ -122,14 +123,7 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Souporaba ozadnjega programa %s mora vsebovati tudi vmesnik OCP\\Share_Backend",
     "Sharing backend %s not found" : "Ozadnjega programa %s za souporabo ni mogoče najti",
     "Sharing backend for %s not found" : "Ozadnjega programa za souporabo za %s ni mogoče najti",
-    "%1$s shared »%2$s« with you" : "%1$s vam omogoča souporabo »%2$s«",
-    "%1$s shared »%2$s« with you." : "%1$s vam omogoča souporabo »%2$s«.",
-    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
-    "Open »%s«" : "Odpri »%s«",
     "%1$s via %2$s" : "%1$s prek %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s vam omogoča souporabo »%2$s« in želi dodati:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s vam omogoča souporabo »%2$s« in želi dodati",
-    "»%s« added a note to a file shared with you" : "»%s« doda opombo k datoteki v souporabi",
     "Unknown share type" : "Neznana vrsta mesta souporabe",
     "You are not allowed to share %s" : "Omogočanje souporabe %s brez ustreznih dovoljenj ni mogoče.",
     "Cannot increase permissions of %s" : "Ni mogoče povečati dovoljen %s",
@@ -189,8 +183,6 @@ OC.L10N.register(
     "Login canceled by app" : "Program onemogoča prijavo",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Programa »%1$s« ni mogoče namestiti zaradi nerešenih odvisnosti: %2$s",
     "a safe home for all your data" : "Varno okolje za vaše podatke!",
-    "File is currently busy, please try again later" : "Datoteka je trenutno v uporabi. Poskusite znova kasneje.",
-    "Cannot download file" : "Datoteke ni mogoče prejeti",
     "Application is not enabled" : "Program ni omogočen",
     "Authentication error" : "Napaka overjanja",
     "Token expired. Please reload page." : "Žeton je pretekel. Stran je treba ponovno naložiti.",
@@ -229,38 +221,29 @@ OC.L10N.register(
     "Storage connection error. %s" : "Napaka povezave do shrambe. %s",
     "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
     "Storage connection timeout. %s" : "Povezava do shrambe je časovno potekla. %s",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Če želite omogočiti izvajanje tega preverjanja, je treba zagotoviti, da se spletni strežnik lahko poveže sam s seboj. Zato mora biti nastavljen za povezovanje z vsaj eno od določenih »varnih domen« (trusted_domains) ali naslovov za prepis »vmesnika ukazne vrstice« (overwrite.cli.url). Spodletelo preverjanje je lahko posledica neujemanja imen DNS na strani strežnika oziroma pravila požarnega zidu.",
+    "Confirmation" : "Potrjevanje",
     "Writing style" : "Slog pisanja",
     "Generate image" : "Ustvari sliko",
+    "Text" : "Besedilo",
     "Summary" : "Povzetek",
     "Translate" : "Prevedi",
     "Target language" : "Ciljni jezik",
     "Result" : "Rezultat",
     "Education Edition" : "Izobraževalna različica",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prijavljen uporabnik mora biti določen za skrbnika, pomočnika skrbnika ali pa mora imeti dodeljene posebna dovoljenja za dostop do nastavitve.",
-    "Logged in user must be an admin or sub admin" : "Prijavljen uporabnik mora imeti dovoljenja skrbnika ali podpornega skrbnika",
-    "Logged in user must be an admin" : "Prijavljen uporabnik mora biti tudi skrbnik",
     "File name is a reserved word" : "Ime datoteke je zadržana beseda",
     "File name contains at least one invalid character" : "Ime datoteke vsebuje vsaj en nedovoljen znak.",
     "File name is too long" : "Ime datoteke je predolgo",
-    "Help" : "Pomoč",
     "Users" : "Uporabniki",
-    "Unknown user" : "Neznan uporabnik",
-    "Enter the database username and name for %s" : "Vpis uporabniškega imena in imena podatkovne zbirke za %s.",
-    "Enter the database username for %s" : "Vpis uporabniškega imena podatkovne zbirke za %s.",
-    "MySQL username and/or password not valid" : "Uporabniško ime ali geslo MySQL ni veljavno",
-    "Oracle username and/or password not valid" : "Uporabniško ime ali geslo Oracle ni veljavno",
-    "PostgreSQL username and/or password not valid" : "Uporabniško ime ali geslo PostgreSQL ni veljavno",
-    "Set an admin username." : "Nastavi uporabniško ime skrbnika.",
-    "Sharing %s failed, because this item is already shared with user %s" : "Nastavljanje souporabe %s je spodletelo, ker je predmet že v souporabi z uporabnikom %s.",
-    "The username is already being used" : "Vpisano uporabniško ime je že v uporabi",
-    "Could not create user" : "Uporabnika ni mogoče ustvariti",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "V uporabniškem imenu je dovoljeno uporabiti le znake: »a–z«, »A–Z«, »0–9«, presledki in »_.@-«\".",
-    "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
-    "Username contains whitespace at the beginning or at the end" : "Uporabniško ime vsebuje presledni znak na začetku ali na koncu imena.",
-    "Username must not consist of dots only" : "Uporabniško ime ne sme biti zgolj iz pik",
-    "Username is invalid because files already exist for this user" : "Uporabniško ime ni veljavno, ker za tega uporabnika že obstajajo datoteke",
-    "User disabled" : "Uporabnik je onemogočen",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Spremenite dovoljenja mape na 0770 in s tem onemogočite branje vsebine drugim uporabnikom.",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s vam omogoča souporabo »%2$s« in želi dodati:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s vam omogoča souporabo »%2$s« in želi dodati",
+    "»%s« added a note to a file shared with you" : "»%s« doda opombo k datoteki v souporabi",
+    "Open »%s«" : "Odpri »%s«",
+    "%1$s shared »%2$s« with you" : "%1$s vam omogoča souporabo »%2$s«",
+    "%1$s shared »%2$s« with you." : "%1$s vam omogoča souporabo »%2$s«.",
+    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
+    "File is currently busy, please try again later" : "Datoteka je trenutno v uporabi. Poskusite znova kasneje.",
+    "Cannot download file" : "Datoteke ni mogoče prejeti",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Prepričajte se, da je datoteka ».ocdata« v korenu podatkovne mape."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
