@@ -12,7 +12,6 @@ OC.L10N.register(
     "Apps" : "ایپز",
     "Settings" : "سیٹینگز",
     "Log out" : "لاگ آؤٹ",
-    "Users" : "یوزرز",
     "Email" : "email",
     "Sunday" : "اتوار",
     "Monday" : "سوموار",
@@ -33,6 +32,6 @@ OC.L10N.register(
     "October" : "اکتوبر",
     "November" : "نومبر",
     "December" : "دسمبر",
-    "Help" : "مدد"
+    "Users" : "یوزرز"
 },
 "nplurals=2; plural=(n != 1);");
